/*****************************************************************************
 *  Rohde&Schwarz SMx RF Signal Generator
 *
 *  Original Release: November 2017
 *  By: Jiri Kominek
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *
 *  Modification History:
 *     see ChangeLog
 *
 *****************************************************************************/

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include "rssmx.h"
#include "rssmx_utility.h"

#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
#define ANSI
#endif
#ifndef ANSI                /* UNIX compatible */
    #include <sys/timeb.h>
    #include <sys/types.h>
    #include <unistd.h>
    #define Sleep sleep
#else                       /* ANSI compatible */
#include <Windows.h>
#endif
#if defined (_CVI_)
    #include <utility.h>
#endif

/*****************************************************************************
 *- Value Definition and Range Tables ---------------------------------------*
 *****************************************************************************/
static ViString gs_SensorChannelArr[] = {"UNM", "SENS1", "SENS2", "SENS3", "SENS4", NULL};

/*****************************************************************************
 * Function: rssmx_init
 * Purpose:  VXIplug&play required function. Calls the
 *           rssmx_InitWithOptions function.
 *****************************************************************************/

ViStatus _VI_FUNC rssmx_init(ViRsrc resourceName, ViBoolean IDQuery,
                             ViBoolean resetDevice, ViSession* newInstrSession)
{
    ViStatus error = VI_SUCCESS;

    if (newInstrSession == NULL)
    {
        (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER,
                                  VI_ERROR_PARAMETER4, "Null address for Instrument Handle");

        checkErr(RS_ERROR_INVALID_PARAMETER);
    }

    checkErr(rssmx_InitWithOptions (resourceName, IDQuery, resetDevice, "", newInstrSession));

Error:
    return error;
}

/*****************************************************************************
 * Function: rssmx_InitWithOptions
 * Purpose:  This function creates a new RS session and calls the
 *           RsInit function.
 *****************************************************************************/
ViStatus _VI_FUNC rssmx_InitWithOptions(
    ViRsrc resourceName,
    ViBoolean IDQuery,
    ViBoolean resetDevice,
    ViString optionString,
    ViSession* newInstrSession
)
{
    ViStatus error = VI_SUCCESS;
    RsCoreAttributePtr* attrList = NULL;
    ViSession instrSession = 0;
    RsCoreSessionPtr sessionProperties = NULL;

    if (newInstrSession == NULL)
    {
        (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER, VI_ERROR_PARAMETER5,
                                  "Null address for Instrument Handle");
        checkErr(RS_ERROR_INVALID_PARAMETER);
    }

    attrList = (RsCoreAttributePtr *)rssmx_RsCoreAttributeList;

    *newInstrSession = 0;

    checkErr(RsCore_NewSpecificDriver(
        resourceName, // VISA Resource Name
        "rssmx", // driver prefix
        optionString, // Init Options string, is applied to the session settings
        attrList, // List of all attributes from the rsxxx_AttrPropertiesList
        rssmx_RsCoreAttributeListLength, // Attributes count
        VI_FALSE, //idnModelFullName Model has the full *IDN? query name e.g. true: "CMW100A", VI_FALSE: "CMW" Used in CheckInstrument()
        0, // WriteDelay
        0, // ReadDelay
        1000000, // IO Segment Size
        RS_VAL_OPCWAIT_STBPOLLING, // OPC Wait Mode
        RSSMX_OPC_TIMEOUT, // OPC timeout
        15000, // VISA Timeout
        600000, // Self-test timeout
        RS_VAL_BIN_FLOAT_FORMAT_SINGLE_4BYTES, // BinaryFloatNumbersFormat
        RS_VAL_BIN_INTEGER_FORMAT_INT32_4BYTES, // binaryIntegerNumbersFormat
        &instrSession));

    // Minimal allowed rscore version is 4.0.0
    checkErr(RsCore_CheckMinimalEngineVersion(instrSession, 4, 0, 0));

    checkErr(RsCore_GetRsSession(instrSession, &sessionProperties));

    // No SCPI command has been sent yet.
    // Call viClear before sending any SCPI command
    checkErr(RsCore_ViClear(instrSession));

    /* --- Here perform settings that are default for this driver,
    but can be overwritten by the optionsString settings */

    sessionProperties->autoSystErrQuery = VI_FALSE;

    // Parse option string and optionally sets the initial state of the following session attributes
    checkErr(RsCore_ApplyOptionString(instrSession, optionString));
    checkErr(RsCore_BuildRepCapTable(instrSession, rssmx_RsCoreRepCapTable, rssmx_RsCoreRepCapTableCount));

    // Query *IDN? string, parse it and set the following attributes:
    // -RS_ATTR_INSTRUMENT_MANUFACTURER
    // - RS_ATTR_INSTRUMENT_MODEL - based on the idnModelFullName true: "SMA100B", false : "SMA"
    // - RS_ATTR_INSTRUMENT_FIRMWARE_REVISION
    checkErr(RsCore_QueryAndParseIDNstring(instrSession, RSSMX_SIMULATION_ID_QUERY, NULL));

    // Query *OPT? string, parse the options, remove the duplicates, sort them and store the result string to RS_ATTR_OPTIONS_LIST
    checkErr(RsCore_QueryAndParseOPTstring(instrSession, RSSMX_SIMULATION_OPT_QUERY, RS_VAL_OPTIONS_PARSING_AUTO));

    // Default Instrument Setup + optional *RST
    if (resetDevice == VI_TRUE)
    {
        checkErr(rssmx_reset(instrSession));
    }
    else
    {
        checkErr(rssmx_DefaultInstrSetup(instrSession));
    }

    if (IDQuery == VI_TRUE)
    {
        checkErr(RsCore_FitsIDNpattern(instrSession, RSSMX_VALID_ID_RESPONSE_STRING, NULL));
    }

    checkErr(rssmx_CheckStatus(instrSession));

Error:
    if (error < VI_SUCCESS)
    {
        if (error == RS_ERROR_INSTRUMENT_STATUS && sessionProperties->autoSystErrQuery == VI_FALSE)
        {
            sessionProperties->autoSystErrQuery = VI_TRUE;
            (void)rssmx_CheckStatus(instrSession);
            sessionProperties->autoSystErrQuery = VI_FALSE;
        }

        if (instrSession != 0)
            (void)RsCore_ViClose(instrSession);
    }
    else
    {
        *newInstrSession = instrSession;
    }

    return error;
}

/// HIFN  This function enables the RF output signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR outputEnabled/Activates and deactivates the RF output.
ViStatus _VI_FUNC rssmx_ConfigureOutputEnabled(ViSession instrSession,
                                               ViBoolean outputEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_ALL_RF_OUTPUTS_ENABLED, outputEnabled),
            2, "Outputs Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the frequency and the power level of the RF
/// HIFN      output signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR frequency/Sets the frequency of the RF output signal for CW mode (:SOURce:FREQuency:MODE CW). In Sweep mode (:SOURce:FREQuency:MODE SWEep), this value is linked to the current sweep frequency.
/// HIPAR powerLevel/Sets the RF output level in CW mode.
ViStatus _VI_FUNC rssmx_ConfigureRF(ViSession instrSession,
                                    ViReal64  frequency,
                                    ViReal64  powerLevel)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY, frequency),
            2, "Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_AMPLITUDE, powerLevel),
            3, "Power Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the frequency mode for generating the RF output signal in the
/// HIFN      selected path. The selected mode determines the parameters to be used
/// HIFN      for further frequency settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR rfFrequencyMode/Sets the frequency mode for generating the RF output signal in the selected path. The selected mode determines the parameters to be used for further frequency settings.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencyMode(ViSession instrSession,
                                                 ViInt32   rfFrequencyMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_MODE, rfFrequencyMode),
            2, "RF Frequency Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the frequency and power mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR powerMode/Selects the operating mode of the instrument to set the output level.
ViStatus _VI_FUNC rssmx_ConfigurePowerMode(ViSession instrSession,
                                           ViInt32   powerMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_POWER_MODE, powerMode),
            2, "Power Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sends a command to trigger the RF signal generator.
/// HIFN  Call this function if you set a trigger source to a software trigger
/// HIFN  value.  Below is a list of attributes and functions which can set the
/// HIFN  trigger source to a software trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
ViStatus _VI_FUNC rssmx_SendSoftwareTrigger(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_INIT_SW_TRIGGER, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the frequency of the RF output signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR frequency/Sets the frequency of the RF output signal for CW mode (:SOURce:FREQuency:MODE CW). In Sweep mode (:SOURce:FREQuency:MODE SWEep), this value is linked to the current sweep frequency.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequency(ViSession instrSession,
                                             ViReal64  frequency)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY, frequency),
            2, "Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures additional RF frequency settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR mainPLLBandwidth/Selects the PLL (Phase Locked Loop) bandwidth of the main synthesizer.
/// HIPAR offset/Sets the frequency offset of a downstream instrument
/// HIPAR multiplier/Sets the multiplication factor of a subsequent downstream instrument, e.g. a frequency muiltiplier.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencySettings(ViSession instrSession,
                                                     ViInt32   mainPLLBandwidth,
                                                     ViReal64  offset,
                                                     ViReal64  multiplier)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_MAIN_PLL_BANDWIDTH, mainPLLBandwidth),
            2, "Main PLL Bandwidth");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_OFFSET, offset),
            3, "RF Frequency Offset");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_MULTIPLIER, multiplier),
            4, "Multiplier");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures RF frequency phase continuity.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/Activates phase continuity of the RF frequency.
/// HIPAR mode/Selects the mode that determines the frequency range for the phase
/// HIPAR mode/continuity.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencyPhaseContinuity(ViSession instrSession,
                                                            ViBoolean enabled,
                                                            ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_PHASE_CONTINUITY_ENABLED, enabled),
            2, "Enabled");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_PHASE_CONTINUITY_MODE, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries RF frequency phase continuity Max and Min.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR max/Queries the maximum frequency of the frequency range for phase
/// HIPAR max/continuous settings.
/// HIPAR min/Queries the minimum frequency of the frequency range for phase
/// HIPAR min/continuous settings.
ViStatus _VI_FUNC rssmx_QueryRFFrequencyPhaseContinuityMaxMin(
                            ViSession instrSession,
                            ViReal64* max,
                            ViReal64* min)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_PHASE_CONTINUITY_MAX, max),
            2, "Max");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_PHASE_CONTINUITY_MIN, min),
            3, "Min");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the power level of the RF output signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR powerLevel/Sets the RF output level in CW mode.
ViStatus _VI_FUNC rssmx_ConfigureRFAmplitude(ViSession instrSession,
                                             ViReal64  powerLevel)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_AMPLITUDE, powerLevel),
            3, "Power Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets RF level main  parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR mode/Sets the RF level mode.
/// HIPAR limit/Limits the maximum RF output level in CW and SWEEP mode. It does not influence the LEVEL display or the response to the POW? query command.
/// HIPAR offset/Specifies the constant level offset of a downstream attenuator/amplifier.
/// HIPAR settingCharacteristics/Selects the level behavior at the RF output over time.
/// HIPAR rfAmplitude/Sets the RF output level in CW mode.
/// HIPAR harmonicFilter/Activates low harmonic filter or enables its automatic switching.
ViStatus _VI_FUNC rssmx_ConfigureRFLevel(ViSession instrSession,
                                         ViReal64  rfAmplitude,
                                         ViInt32   mode,
                                         ViReal64  limit,
                                         ViReal64  offset,
                                         ViInt32   settingCharacteristics,
                                         ViInt32   harmonicFilter)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_AMPLITUDE, rfAmplitude),
            2, "RF Amplitude");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_MODE, mode),
            3, "Mode");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_LIMIT, limit),
            4, "Limit");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_OFFSET, offset),
            5, "Level Offset");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_SETTING_CHARACTERISTICS, settingCharacteristics),
            6, "Level Setting Characteristics");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_HARMONIC_FILTER, harmonicFilter),
            7, "Harmonic Filter");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the RF level attenuator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR mode/Switches the mode of the attenuator at the RF output.
/// HIPAR rfAttenuatorRFOFFMode/Selects the state the attenuator is to assume if the RF signal is switched off.
/// HIPAR attenuation/Sets the attenuation value of the RF signal.
ViStatus _VI_FUNC rssmx_ConfigureRFLevelAttenuator(ViSession instrSession,
                                                   ViInt32   mode,
                                                   ViInt32   rfAttenuatorRFOFFMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_ATTENUATOR_MODE, mode),
            2, "Mode");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_ATTENUATOR_RF_OFF_MODE, rfAttenuatorRFOFFMode),
            3, "RF Attenuator RF OFF Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the state of the protective circuit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR overvoltageProtectionTripped/Queries the state of the protective circuit.
ViStatus _VI_FUNC rssmx_OvervoltageProtectionTripped(ViSession  instrSession,
                                                     ViBoolean* overvoltageProtectionTripped)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_GetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_OVERVOLTAGE_PROTECTION_TRIPPED, overvoltageProtectionTripped),
            2, "Overvoltage Protection Tripped");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Resets the protective circuit after it has been tripped. The state of
/// HIFN      the output is again determined by OUTPut:STATe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_OvervoltageProtectionClear(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_OVERVOLTAGE_PROTECTION_CLEAR, NULL),
            2, "Overvoltage Protection Clear");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the state which the RF output assumes when the instrument is
/// HIFN      switched on.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR powerOnState/Selects the state which the RF output assumes when the instrument is switched on.
ViStatus _VI_FUNC rssmx_ConfigureRFPowerOnState(ViSession instrSession,
                                                ViInt32   powerOnState)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ON_ENABLED, powerOnState),
            2, "Power On State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Determines whether the current level is retained or whether the stored
/// HIFN      level setting is adopted when an instrument configuration is loaded.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR rfLevelOnRecall/Determines whether the current level is retained or whether the stored level setting is adopted when an instrument configuration is loaded.
ViStatus _VI_FUNC rssmx_ConfigureRFLevelOnRecall(ViSession instrSession,
                                                 ViInt32   rfLevelOnRecall)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_ON_RECALL, rfLevelOnRecall),
            2, "RF Level On Recall");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the current interruption-free range of the level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR lowerRange/Queries the current interruption-free lower range of the level.
/// HIPAR upperRange/Queries the current interruption-free upper range of the level.
ViStatus _VI_FUNC rssmx_QueryRFLevelUninterruptedRange(ViSession instrSession,
                                                       ViReal64* lowerRange,
                                                       ViReal64* upperRange)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_LOWER_RANGE, lowerRange),
            2, "Lower Range");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_UPPER_RANGE, upperRange),
            3, "Upper Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the current power range of the level sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR rangeMin/Queries the current power range of the level sweep.
/// HIPAR rangeMax/Queries the current power range of the level sweep.
ViStatus _VI_FUNC rssmx_QueryRFLevelRange(ViSession instrSession,
                                          ViReal64* rangeMin,
                                          ViReal64* rangeMax)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_RANGE_MIN, rangeMin),
            2, "Range Min");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_RANGE_MAX, rangeMax),
            3, "Range Max");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables the Automatic Level Control.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR alcEnabled/Activates/deactivates automatic level control.
ViStatus _VI_FUNC rssmx_ConfigureALCEnabled(ViSession instrSession,
                                            ViInt32   alcEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_ALC_ENABLED, alcEnabled),
            2, "ALC Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the currently set ALC mode. See RSSMX_ATTR_ALC_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR alcMode/Queries the currently set ALC mode. See RSSMX_ATTR_ALC_ENABLED.
ViStatus _VI_FUNC rssmx_QueryALCMode(ViSession instrSession,
                                     ViInt32*  alcMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_GetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_ALC_MODE, alcMode),
            2, "ALC Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the sensitivity of the ALC detector.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR detectorSensitivity/Sets the sensitivity of the ALC detector.
ViStatus _VI_FUNC rssmx_ConfigureALCDetectorSensitivity(ViSession instrSession,
                                                        ViInt32   detectorSensitivity)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_ALC_DETECTOR_SENSITIVITY, detectorSensitivity),
            2, "Detector Sensitivity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Recalculates the instrument internal settings optimized for the
/// HIFN      current level. Not required for automatic modes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_ALCRecalculate(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_ALC_RECALCULATE, NULL),
            2, "ALC Recalculate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates level control for correction purposes temporarily.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_ALCReadjust(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_ALC_READJUST, NULL),
            2, "ALC Readjust");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the level control mode. It is activated when automatic level
/// HIFN      control is switched off (ALC Off). Activates the level control briefly
/// HIFN      when changing the frequency or level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_ALCLevelControlMode(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_ALC_LEVEL_CONTROL_MODE, NULL),
            2, "ALC Level Control Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the ALC External Detector.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR couplingFactor/Sets the attenuation value of the RF coupler.
/// HIPAR generatorLevel/Sets the maximum power level at the RF output required for
/// HIPAR generatorLevel/compensating the external ALC coupler and cable losses.
ViStatus _VI_FUNC rssmx_ConfigureALCExternalDetector(ViSession instrSession,
                                                     ViReal64  couplingFactor,
                                                     ViReal64  generatorLevel)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_ALC_EXTERNAL_DETECTOR_COUPLING_FACTOR, couplingFactor),
            2, "Coupling Factor");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_ALC_EXTERNAL_DETECTOR_REQUIRED_GENERATOR_LEVEL, generatorLevel),
            3, "Generator Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies the phase variation relative to the current phase. The
/// HIFN      variation can be specified in RADians.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR rfDeltaPhase/Specifies the phase variation relative to the current phase. The variation can be specified in RADians.
ViStatus _VI_FUNC rssmx_ConfigureRFDeltaPhase(ViSession instrSession,
                                              ViReal64  rfDeltaPhase)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_DELTA_PHASE, rfDeltaPhase),
            2, "RF Delta Phase");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Adopts the phase set with SOURce:PHASe as the reference phase.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_ResetRFDeltaPhaseDisplay(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_RESET_RF_DELTA_PHASE_DISPLAY, NULL),
            2, "Reset RF Delta Phase Display");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Switches the modulations on and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR allModulationsEnabled/Switches the modulations on and off.
ViStatus _VI_FUNC rssmx_ConfigureAllModulationsState(ViSession instrSession,
                                                     ViBoolean allModulationsEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_ALL_MODULATIONS_ENABLED, allModulationsEnabled),
            2, "All Modulations Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configure the signal of an externally supplied LF signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR external/Selects the external input.
/// HIPAR coupling/Selects the coupling mode (AC or DC) for the external signal.
/// HIPAR impedance/Sets the impedance for the externally supplied modulation signal.
ViStatus _VI_FUNC rssmx_ConfigureExternalInput(ViSession instrSession,
                                               ViInt32   external,
                                               ViInt32   coupling,
                                               ViInt32   impedance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, external, 1, 2),
            2, "External");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "EXT%ld", external);
    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_EXTERNAL_INPUT_COUPLING_MODE, coupling),
            3, "Coupling");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_EXTERNAL_INPUT_IMPEDANCE, impedance),
            4, "Impedance");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures noise generator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR distribution/Sets the distribution of the noise power density.
/// HIPAR bandwidthState/Activates noise bandwidth limitation.
/// HIPAR bandwidth/Selects the noise bandwidth.
ViStatus _VI_FUNC rssmx_ConfigureNoiseGenerator(ViSession instrSession,
                                                ViInt32   distribution,
                                                ViBoolean bandwidthState,
                                                ViReal64  bandwidth)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_NOISE_DISTRIBUTION, distribution),
            2, "Distribution");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_NOISE_BANDWIDTH_STATE, bandwidthState),
            3, "Bandwidth State");
    if (bandwidthState)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_NOISE_BANDWIDTH, bandwidth),
                4, "Bandwidth");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Contains the amplitude modulation settings.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Selecting the modulation mode to "Mode > Scan" sets the modulation
/// HIFN  type to "Exponential".
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the AM path.
/// HIPAR modeandType/Selects the mode and type of the amplitude modulation.
/// HIPAR depth/Sets the depth of the linear or exponential amplitude modulation.
/// HIPAR sensitivity/Sets the sensitivity of the external signal source for amplitude
/// HIPAR sensitivity/modulation for either linear or exponential sensitivity type.
ViStatus _VI_FUNC rssmx_ConfigureAMSettings(ViSession instrSession,
                                            ViInt32   path,
                                            ViInt32   modeAndType,
                                            ViReal64  depth,
                                            ViReal64  sensitivity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, modeAndType, RSSMX_VAL_AM_MODE_TYPE_NORM_LIN, RSSMX_VAL_AM_MODE_TYPE_SCAN_EXP),
            3, "Mode and Type");

    switch (modeAndType)
    {
    case RSSMX_VAL_AM_MODE_TYPE_NORM_LIN:
        checkErr(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_AM_MODE, RSSMX_VAL_AM_MODE_NORMAL));
        checkErr(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_AM_TYPE, RSSMX_VAL_AM_TYPE_LINEAR));
        break;

    case RSSMX_VAL_AM_MODE_TYPE_NORM_EXP:
        checkErr(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_AM_MODE, RSSMX_VAL_AM_MODE_NORMAL));
        checkErr(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_AM_TYPE, RSSMX_VAL_AM_TYPE_EXPONENTIAL));
        break;

    case RSSMX_VAL_AM_MODE_TYPE_SCAN_EXP:
        checkErr(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_AM_MODE, RSSMX_VAL_AM_MODE_SCAN));
        checkErr(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_AM_TYPE, RSSMX_VAL_AM_TYPE_EXPONENTIAL));
        break;
    }

    if (modeAndType == RSSMX_VAL_AM_MODE_TYPE_NORM_LIN)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_AM_DEPTH_LINEAR, depth),
                3, "Depth");

        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_AM_SENSITIVITY_LINEAR, sensitivity),
                4, "Sensitivity");
    }

    if (modeAndType == RSSMX_VAL_AM_MODE_TYPE_NORM_EXP || modeAndType == RSSMX_VAL_AM_MODE_TYPE_SCAN_EXP)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_AM_DEPTH_EXPONENTIAL, depth),
                3, "Depth");

        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_AM_SENSITIVITY_EXPONENTIAL, sensitivity),
                4, "Sensitivity");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures AM path parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR path/Selects the AM path.
/// HIPAR enabled/Activates/deactivates amplitude modulation.
/// HIPAR source/Selects the modulation source for amplitude modulation.
/// HIPAR depth/Sets the depth of the amplitude modulation in percent.
ViStatus _VI_FUNC rssmx_ConfigureAMPath(ViSession instrSession,
                                        ViInt32   path,
                                        ViBoolean enabled,
                                        ViInt32   source,
                                        ViReal64  depth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));
    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_AM_SOURCE, source),
            4, "Source");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_AM_DEPTH, depth),
            5, "Depth");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_AM_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the deviation ratio (path#2 to path#1) in percent.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR deviationRatio/Sets the deviation ratio (path#2 to path#1) in percent.
ViStatus _VI_FUNC rssmx_ConfigureAMDeviationMode(ViSession instrSession,
                                                 ViInt32   deviationMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_AM_DEVIATION_MODE, deviationMode),
            2, "Deviation Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the deviation ratio (path#2 to path#1) in percent.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR deviationRatio/Sets the deviation ratio (path#2 to path#1) in percent.
ViStatus _VI_FUNC rssmx_ConfigureAMDeviationRatio(ViSession instrSession,
                                                  ViReal64  deviationRatio)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_AM_DEVIATION_RATIO, deviationRatio),
            2, "Deviation Ratio");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the total depth of the LF signal when using combined signal
/// HIFN  sources in amplitude modulation.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR depthTotal/Sets the total depth of the LF signal when using combined signal
/// HIPAR depthTotal/sources in amplitude modulation.
ViStatus _VI_FUNC rssmx_ConfigureAMDepthTotal(ViSession instrSession,
                                              ViReal64  depthTotal)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_AM_DEPTH_TOTAL, depthTotal),
            2, "Depth Total");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the coupling mode for the external modulation input in case of
/// HIFN      amplitude modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR amExternalCoupling/Selects the coupling mode for the external modulation input in case of amplitude modulation.
ViStatus _VI_FUNC rssmx_ConfigureAMExternalCoupling(ViSession instrSession,
                                                    ViInt32   amExternalCoupling)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_AM_EXTERNAL_COUPLING, amExternalCoupling),
            2, "AM External Coupling");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures FM modulation path parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR path/Selects the FM path.
/// HIPAR enabled/Activates/deactivates the frequency modulation.
/// HIPAR source/Selects the modulation source for frequency modulation.
/// HIPAR deviation/Sets the modulation deviation of the frequency modulation in Hz.
ViStatus _VI_FUNC rssmx_ConfigureFMPath(ViSession instrSession,
                                        ViInt32   path,
                                        ViBoolean enabled,
                                        ViInt32   source,
                                        ViReal64  deviation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));
    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_FM_SOURCE, source),
            4, "Source");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_FM_DEVIATION, deviation),
            5, "Deviation");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_FM_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the deviation ratio (path2 to path1) and mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR ratio/Sets the deviation ratio (path2 to path1) in percent.
/// HIPAR mode/Selects the mode for the frequency modulation.
ViStatus _VI_FUNC rssmx_ConfigureFMSettings(ViSession instrSession,
                                            ViReal64  ratio,
                                            ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_FM_RATIO, ratio),
            2, "Ratio");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_FM_MODE, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the coupling mode. The coupling mode parameter also determines
/// HIFN  the mode for fixing the total deviation.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR deviationMode/Selects the coupling mode. The coupling mode parameter also determines
/// HIPAR deviationMode/the mode for fixing the total deviation.
ViStatus _VI_FUNC rssmx_ConfigureFMDeviationMode(ViSession instrSession,
                                                 ViInt32   deviationMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_FM_DEVIATION_MODE, deviationMode),
            2, "Deviation Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the total deviation of the LF signal when using combined signal
/// HIFN  sources in frequency modulation.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR deviationTotal/Sets the total deviation of the LF signal when using combined signal
/// HIPAR deviationTotal/sources in frequency modulation.
ViStatus _VI_FUNC rssmx_ConfigureFMDeviationTotal(ViSession instrSession,
                                                  ViReal64  deviationTotal)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_FM_DEVIATION_TOTAL, deviationTotal),
            2, "Deviation Total");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures PM modulation path parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR path/Selects the FM path.
/// HIPAR enabled/Activates/deactivates phase modulation.
/// HIPAR source/Selects the modulation source for phase modulation signal.
/// HIPAR deviation/Sets the the modulation depth in RAD.
ViStatus _VI_FUNC rssmx_ConfigurePMPath(ViSession instrSession,
                                        ViInt32   path,
                                        ViBoolean enabled,
                                        ViInt32   source,
                                        ViReal64  deviation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));
    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_PM_SOURCE, source),
            4, "Source");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_PM_DEVIATION, deviation),
            5, "Deviation");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_PM_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the deviation ratio (path2 to path1) and mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR ratio/Sets the deviation ratio (path2 to path1) in percent.
/// HIPAR mode/Selects the mode for the phase modulation.
ViStatus _VI_FUNC rssmx_ConfigurePMSettings(ViSession instrSession,
                                            ViReal64  ratio,
                                            ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_PM_RATIO, ratio),
            2, "Ratio");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PM_MODE, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the coupling mode. The coupling mode parameter also determines
/// HIFN  the mode for fixing the total deviation.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR deviationMode/Selects the coupling mode. The coupling mode parameter also determines
/// HIPAR deviationMode/the mode for fixing the total deviation.
ViStatus _VI_FUNC rssmx_ConfigurePMDeviationMode(ViSession instrSession,
                                                 ViInt32   deviationMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PM_DEVIATION_MODE, deviationMode),
            2, "Deviation Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the total deviation of the LF signal when using combined signal
/// HIFN  sources in phase modulation.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR deviationTotal/Sets the total deviation of the LF signal when using combined signal
/// HIPAR deviationTotal/sources in phase modulation.
ViStatus _VI_FUNC rssmx_ConfigurePMDeviationTotal(ViSession instrSession,
                                                  ViReal64  deviationTotal)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_PM_DEVIATION_TOTAL, deviationTotal),
            2, "Deviation Total");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the signal generator to apply pulse
/// HIFN      modulation to the RF output signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR pulseModulationEnabled/Activates/deactivates the pulse modulation.
ViStatus _VI_FUNC rssmx_ConfigurePulseModulationEnabled(ViSession instrSession,
                                                        ViBoolean pulseModulationEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_PULM_ENABLED, pulseModulationEnabled),
            2, "Pulse Modulation Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configure pulse modulation settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR source/Selects the source for pulse modulation.
/// HIPAR transitionType/Sets the Pulse Modulation Transition Type.
/// HIPAR videoPolarity/Sets the polarity of the internally generated pulse video (modulating) signal, related to the RF (modulated) signal.
ViStatus _VI_FUNC rssmx_ConfigurePulseModulationSettings(ViSession instrSession,
                                                         ViInt32   source,
                                                         ViInt32   transitionType,
                                                         ViInt32   videoPolarity)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PULM_SOURCE, source),
            2, "Source");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PULM_TRANSITION_TYPE, transitionType),
            3, "Transition Type");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PULM_VIDEO_POLARITY, videoPolarity),
            4, "Video Polarity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configure characteristics of the PULSE EXT connector.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR polarity/Sets the polarity of the externally applied modulation signal.
/// HIPAR impedance/Sets the impedance for the external pulse trigger and pulse modulation input.
/// HIPAR threshold/Sets the threshold for the input signal at the PULSE EXT connector.
ViStatus _VI_FUNC rssmx_ConfigurePulseModulationExternalTrigger(
                            ViSession instrSession,
                            ViInt32   polarity,
                            ViInt32   impedance,
                            ViReal64  threshold)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PULM_POLARITY, polarity),
            2, "Polarity");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PULM_IMPEDANCE, impedance),
            3, "Impedance");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_PULM_THRESHOLD, threshold),
            4, " Threshold");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables the output of the video/sync signal.
/// HIFN     If the pulse generator is the current modulation source, activating
/// HIFN      the pulse modulation automatically activates the signal output and the
/// HIFN      pulse generator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR pulseGeneratorEnabled/Enables the output of the video/sync signal.
ViStatus _VI_FUNC rssmx_ConfigurePulseGeneratorState(ViSession instrSession,
                                                     ViBoolean pulseGeneratorEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_PGEN_ENABLED, pulseGeneratorEnabled),
            2, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the mode for the pulse modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR mode/Selects the mode for the pulse modulation.
ViStatus _VI_FUNC rssmx_ConfigurePulseGeneratorMode(ViSession instrSession,
                                                    ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PGEN_MODE, mode),
            2, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures parameters of generated pulse.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR period/Sets the period of the generated pulse, that means the repetition frequency of the internally generated modulation signal.
/// HIPAR width/Sets the width of the generated pulse, that means the pulse length. It must be at least 20ns less than the set pulse period.
ViStatus _VI_FUNC rssmx_ConfigurePulseGeneratorPulseParameters(
                            ViSession instrSession,
                            ViReal64  period,
                            ViReal64  width)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_PGEN_PERIOD, period),
            2, "Period");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_PGEN_WIDTH, width),
            3, "Width");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures parameters of generated double pulse.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR doubleDelay/Sets the delay from the start of the first pulse to the start of the second pulse.
/// HIPAR doubleWidth/Sets the width of the second pulse.
ViStatus _VI_FUNC rssmx_ConfigurePulseGeneratorDoublePulseParameters(
                            ViSession instrSession,
                            ViReal64  doubleDelay,
                            ViReal64  doubleWidth)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_PGEN_DOUBLE_DELAY, doubleDelay),
            2, "Double Delay");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_PGEN_DOUBLE_WIDTH, doubleWidth),
            3, "Double Width");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the pulse delay.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR delay/Sets the pulse delay.
ViStatus _VI_FUNC rssmx_ConfigurePulseGeneratorDelay(ViSession instrSession,
                                                     ViReal64  delay)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_PGEN_DELAY, delay),
            2, "Delay");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects a trigger mode - auto, external, external single or external
/// HIFN      gated - for generating the modulation signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR triggerMode/Selects a trigger mode - auto, external, external single or external gated - for generating the modulation signal.
ViStatus _VI_FUNC rssmx_ConfigurePulseGeneratorTriggerMode(ViSession instrSession,
                                                           ViInt32   triggerMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PGEN_TRIGGER_MODE, triggerMode),
            2, "Trigger Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If [:SOURce<hw>]:PULM:TRIGger:MODE SINGle, triggers the pulse
/// HIFN  generator.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_TriggerPulseGenerator(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_TRIGGER_PULSE_GENERATOR, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the output of the pulse modulation signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR pulseOutputState/Activates the output of the pulse modulation signal.
ViStatus _VI_FUNC rssmx_ConfigurePulseGeneratorOutputState(ViSession instrSession,
                                                           ViBoolean pulseOutputState)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_PGEN_OUTPUT, pulseOutputState),
            2, "Pulse Output State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets pulse generator output polarity.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR pulseOutputPolarity/Sets pulse generator output polarity.
ViStatus _VI_FUNC rssmx_ConfigurePulseGeneratorOutputPolarity(
                            ViSession instrSession,
                            ViInt32   pulseOutputPolarity)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PGEN_OUTPUT_POLARITY, pulseOutputPolarity),
            2, "Pulse Output Polarity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Reads Pulse Modulation train settings files.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Catalog'.
/// HIPAR catalog/List of list filenames, separated by commas.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is larger then 'Array Size', then the response stored in 'Catalog' is not complete. Resize 'Catalog' array to accomodate all values and call into  the function again.
ViStatus _VI_FUNC rssmx_QueryPulseModulationTrainCatalog(ViSession instrSession,
                                                         ViUInt32  arraySize,
                                                         ViChar    catalog[],
                                                         ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_QueryCatalog(instrSession, ":PULM:TRA:CAT?", arraySize, catalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects or creates a data list in pulse train mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileName/Selects or creates a data list in pulse train mode.
ViStatus _VI_FUNC rssmx_SelectPulseModulationTrain(ViSession instrSession,
                                                   ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_PULM_TRAIN_SELECT, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the PULM train off time points.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Off Times'.
/// HIPAR offTimes/Array of Off Time values.
ViStatus _VI_FUNC rssmx_ConfigurePulseModulationTrainOffTimes(
                            ViSession instrSession,
                            ViUInt32  arraySize,
                            ViReal64  offTimes[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_WriteViReal64Array(instrSession,
                                          ":PULM:TRA:OFFT",
                                          arraySize,
                                          offTimes));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the PULM train on time points.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'On Times'.
/// HIPAR onTimes/Array of On Time values.
ViStatus _VI_FUNC rssmx_ConfigurePulseModulationTrainOnTimes(ViSession instrSession,
                                                             ViUInt32  arraySize,
                                                             ViReal64  onTimes[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_WriteViReal64Array(instrSession,
                                          ":PULM:TRA:ONT",
                                          arraySize,
                                          onTimes));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the PULM train repetition points.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Repetitions'.
/// HIPAR repetitions/Array of repetition values.
ViStatus _VI_FUNC rssmx_ConfigurePulseModulationTrainRepetitions(
                            ViSession instrSession,
                            ViUInt32  arraySize,
                            ViReal64  repetitions[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_WriteViReal64Array(instrSession,
                                          ":PULM:TRA:REP",
                                          arraySize,
                                          repetitions));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the selected file with PULM train settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileName/Deletes the selected file with PULM train settings.
ViStatus _VI_FUNC rssmx_DeletePulseModulationTrain(ViSession instrSession,
                                                   ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_PULM_TRAIN_DELETE, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the available ASCII files in the current or specified
/// HIFN      directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Catalog'.
/// HIPAR catalog/List of list filenames, separated by commas.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is larger then 'Array Size', then the response stored in 'Catalog' is not complete. Resize 'Catalog' array to accomodate all values and call into  the function again.
ViStatus _VI_FUNC rssmx_QueryPulseTrainDataExchangeCatalog(ViSession instrSession,
                                                           ViUInt32  arraySize,
                                                           ViChar    catalog[],
                                                           ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_QueryCatalog(instrSession, ":PULM:TRA:DEXC:AFIL:CAT?", arraySize, catalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the ASCII file for import or export, containing a pulse train
/// HIFN      list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileName/Selects the ASCII file for import or export, containing a pulse train list.
ViStatus _VI_FUNC rssmx_SelectPulseTrainDataExchangeFile(ViSession instrSession,
                                                         ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_PULSE_TRAIN_DATA_EXCHANGE_FILE, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the ASCII file to be imported or exported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR asciiFile/Selects the ASCII file to be imported or exported.
ViStatus _VI_FUNC rssmx_SelectPulseTrainDataExchangeASCIIFile(
                            ViSession instrSession,
                            ViString  asciiFile)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_PULSE_TRAIN_DATA_EXCHANGE_ASCII_FILE, asciiFile),
            2, "ASCII File");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configure ASCII file for import or export.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR asciiExtension/Determines the extension of the ASCII file for import or export, or to query existing files.
/// HIPAR asciiColumnSeparator/Selects the separator between the frequency and level column of the ASCII table.
/// HIPAR asciiDecimalSeparator/Selects the decimal separator used in the ASCII data between '.' (decimal point) and ',' (comma) with floating-point numerals.
ViStatus _VI_FUNC rssmx_ConfigurePulseTrainDataExchangeASCIIFile(
                            ViSession instrSession,
                            ViInt32   asciiExtension,
                            ViInt32   asciiColumnSeparator,
                            ViInt32   asciiDecimalSeparator)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PULSE_TRAIN_DATA_EXCHANGE_ASCII_EXTENSION, asciiExtension),
            2, "ASCII Extension");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PULSE_TRAIN_DATA_EXCHANGE_ASCII_COLUMN_SEPARATOR, RSSMX_VAL_COLUMN_SEP_TAB),
            3, "ASCII Column Separator");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PULSE_TRAIN_DATA_EXCHANGE_ASCII_DECIMAL_SEPARATOR, RSSMX_VAL_DECIMAL_SEP_DOT),
            4, "ASCII Decimal Separator");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PULSE_TRAIN_DATA_EXCHANGE_ASCII_COLUMN_SEPARATOR, asciiColumnSeparator),
            3, "ASCII Column Separator");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PULSE_TRAIN_DATA_EXCHANGE_ASCII_DECIMAL_SEPARATOR, asciiDecimalSeparator),
            4, "ASCII Decimal Separator");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Determines the import or export of a list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR importExport/Determines the import or export of a list.
ViStatus _VI_FUNC rssmx_ConfigurePulseTrainDataExchangeImportExport(
                            ViSession instrSession,
                            ViInt32   importExport)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_PULSE_TRAIN_DATA_EXCHANGE_IMPORT_EXPORT, importExport),
            2, "Import Export");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Executes the import or export of the selected list file, according to
/// HIFN      the transfer direction.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_PulseTrainDataExchangeExecute(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_PULSE_TRAIN_DATA_EXCHANGE_EXECUTE, NULL),
            2, "Pulse Train Data Exchange Execute");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates/deactivates the LF output.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR lfOutputEnabled/Activates/deactivates the LF output.
ViStatus _VI_FUNC rssmx_ConfigureLFOutputState(ViSession instrSession,
                                               ViBoolean lfOutputEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_LF_OUTPUT_ENABLED, lfOutputEnabled),
            2, "LF Output Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures LF output source and voltage parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR source/Defines which signal is output.
/// HIPAR outputVoltage/Sets the output voltage of the selected LF output.
/// HIPAR dcOffset/Sets the LF Output DC Offset.
ViStatus _VI_FUNC rssmx_ConfigureLFOutputSettings(ViSession instrSession,
                                                  ViInt32   source,
                                                  ViReal64  outputVoltage,
                                                  ViReal64  dcOffset)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LF_OUTPUT_SOURCE, source),
            2, "Source");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_LF_OUTPUT_VOLTAGE, outputVoltage),
            3, "Output Voltage");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_LF_OUTPUT_DC_OFFSET, dcOffset),
            4, "DC Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the shape of the LF generator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR lfGenerator/Selects the LF output.
/// HIPAR shape/Selects the shape of the LF generator.
ViStatus _VI_FUNC rssmx_ConfigureLFGeneratorShape(ViSession instrSession,
                                                  ViInt32   lfGenerator,
                                                  ViInt32   shape)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_LFRepCap(instrSession, lfGenerator, repCap));
    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_LF_GENERATOR_SHAPE, shape),
            3, "Shape");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the output voltage for the LF generators.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR lfGenerator/Selects the LF output.
/// HIPAR voltage/Sets the output voltage for the LF generators.
ViStatus _VI_FUNC rssmx_ConfigureLFGeneratorVoltage(ViSession instrSession,
                                                    ViInt32   lfGenerator,
                                                    ViReal64  voltage)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_LFRepCap(instrSession, lfGenerator, repCap));
    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_LF_GENERATOR_INTERNAL_VOLTAGE, voltage),
            3, "Internal Voltage");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the frequency of the LF signal for CW mode (:SOUR::MODE CW mode).
/// HIFN      In Sweep mode (:SOUR:LFO:FREQ:MODE SWE), the frequency is linked to the
/// HIFN      sweep frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR lfGenerator/Selects the LF output.
/// HIPAR frequency/Sets the frequency of the LF signal for CW mode (:SOUR::MODE CW mode). In Sweep mode (:SOUR:LFO:FREQ:MODE SWE), the frequency is linked to the sweep frequency.
ViStatus _VI_FUNC rssmx_ConfigureLFGeneratorSineFrequency(ViSession instrSession,
                                                          ViInt32   lfGenerator,
                                                          ViReal64  frequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_LFRepCap(instrSession, lfGenerator, repCap));
    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_LF_GENERATOR_FREQUENCY, frequency),
            3, "LF Generator Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures LF generator pulse parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR lfGenerator/Selects the LF output.
/// HIPAR period/Sets LF Generator Pulse Period.
/// HIPAR width/Sets the pulse length of the generated pulse.
/// HIPAR dutyCycle/Sets the duty cycle for the shape pulse.
ViStatus _VI_FUNC rssmx_ConfigureLFGeneratorPulse(ViSession instrSession,
                                                  ViInt32   lfGenerator,
                                                  ViReal64  period,
                                                  ViReal64  width)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_LFRepCap(instrSession, lfGenerator, repCap));
    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_LF_GENERATOR_PULSE_PERIOD, period),
            3, "Period");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_LF_GENERATOR_PULSE_WIDTH, width),
            4, "Width");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the LF generator trapezoid.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR lfGenerator/Selects the LF output.
/// HIPAR period/Sets the trapezoid period.
/// HIPAR rise/Selects the rise time for the trapezoid shape of the LF generator.
/// HIPAR fall/Selects the fall time for the trapezoid shape of the LF generator.
/// HIPAR high/Sets the high time for the trapezoid signal of the LF generator.
ViStatus _VI_FUNC rssmx_ConfigureLFGeneratorTrapezoid(ViSession instrSession,
                                                      ViInt32   lfGenerator,
                                                      ViReal64  period,
                                                      ViReal64  rise,
                                                      ViReal64  fall,
                                                      ViReal64  high)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_LFRepCap(instrSession, lfGenerator, repCap));
    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_LF_GENERATOR_TRAPEZOID_PERIOD, period),
            3, " Period");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_LF_GENERATOR_TRAPEZOID_RISE, rise),
            4, " Rise");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_LF_GENERATOR_TRAPEZOID_FALL, fall),
            5, " Fall");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_LF_GENERATOR_TRAPEZOID_HIGH, high),
            6, " High");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the LF generator triangle.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR lfGenerator/Selects the LF output.
/// HIPAR period/Sets the triangle period.
/// HIPAR rise/Selects the rise time for the triangle shape of the LF generator.
ViStatus _VI_FUNC rssmx_ConfigureLFGeneratorTriangle(ViSession instrSession,
                                                     ViInt32   lfGenerator,
                                                     ViReal64  period,
                                                     ViReal64  rise)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_LFRepCap(instrSession, lfGenerator, repCap));
    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_LF_GENERATOR_TRIANGLE_PERIOD, period),
            3, " Period");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_LF_GENERATOR_TRIANGLE_RISE, rise),
            4, " Rise");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates the generation of a chirp modulation signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR chirpModulationEnabled/Activates the generation of a chirp modulation signal.
ViStatus _VI_FUNC rssmx_ConfigureChirpModulationEnabled(ViSession instrSession,
                                                        ViBoolean chirpModulationEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_CHIRP_MODULATION_STATE, chirpModulationEnabled),
            2, "Chirp Modulation Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the chirp modulation settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR direction/Selects the direction of the chirp modulation.
/// HIPAR triggerMode/Selects the trigger mode for the chirp modulation signal.
/// HIPAR pulsePeriod/Sets the period of the generated modulation chirp. The period
/// HIPAR pulsePeriod/determines the repetition frequency of the internal signal. Note that
/// HIPAR pulsePeriod/minimum value for K23 is 2E-7 s, otherwise it's 5e-6.
/// HIPAR pulseWidth/Sets the width of the generated pulse. The pulse width must be at
/// HIPAR pulseWidth/least 1us less than the set pulse period.
/// HIPAR bandwidth/Sets the modulation bandwidth of the chirp modulated signal.
ViStatus _VI_FUNC rssmx_ConfigureChirpModulationSettings(ViSession instrSession,
                                                         ViInt32   direction,
                                                         ViInt32   triggerMode,
                                                         ViReal64  pulsePeriod,
                                                         ViReal64  pulseWidth,
                                                         ViReal64  bandwidth)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_CHIRP_MODULATION_DIRECTION, direction),
            2, "Direction");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_CHIRP_MODULATION_TRIGGER_MODE, triggerMode),
            3, "Trigger Mode");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_CHIRP_MODULATION_PULSE_PERIOD, pulsePeriod),
            4, "Pulse Period");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_CHIRP_MODULATION_PULSE_WIDTH, pulseWidth),
            5, "Pulse Width");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_CHIRP_MODULATION_BANDWIDTH, bandwidth),
            6, "Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the pulse compression ratio (= product of pulse width (s) and
/// HIFN  bandwidth (Hz)).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR compressionRatio/Queries the pulse compression ratio (= product of pulse width (s) and
/// HIPAR compressionRatio/bandwidth (Hz)).
ViStatus _VI_FUNC rssmx_QueryChirpModulationCompressionRatio(ViSession instrSession,
                                                             ViReal64* compressionRatio)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_CHIRP_MODULATION_COMPRESSION_RATIO, compressionRatio),
            2, "Compression Ratio");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Immediately starts the chirp signal generation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_ExecuteChirpModulationSingleTrigger(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_CHIRP_MODULATION_EXECUTE_SINGLE_TRIGGER, NULL));

    checkErr(RsCore_CheckStatus(instrSession, error));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the sweep mode.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sweepMode/Sets the sweep mode.
ViStatus _VI_FUNC rssmx_ConfigureSweepType(ViSession instrSession,
                                           ViInt32   sweepType)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_SWEEP_TYPE, sweepType),
            2, "Sweep Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Resets all active sweeps to the starting point.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_ResetAllSweeps(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_RESET_ALL_SWEEPS, NULL),
            2, "Reset All Sweeps");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Starts all sweeps which are activated for the respective path. The
/// HIFN      sweep to be executed depends on the respective MODE setting
/// HIFN      (:SOURce<1|2>:SWEep:POWer|FREQuency:MODE STEP). This function
/// HIFN      corresponds to the manual-control command Execute Trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_TriggerAllSweeps(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_TRIGGER_ALL_SWEEPS, NULL),
            2, "Trigger All Sweeps");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the trigger source for all sweeps.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR source/Sets the trigger source for all sweeps.
/// HIPAR slope/Sets the polarity of the active slope of an applied instrument trigger.
ViStatus _VI_FUNC rssmx_ConfigureSweepTrigger(ViSession instrSession,
                                              ViInt32   source,
                                              ViInt32   slope)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_TRIGGER_SOURCE_FOR_ALL_SWEEPS, source),
            2, "Source");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_TRIGGER_INPUT_SLOPE, slope),
            3, "Slope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables or disables the frequency sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR sweepState/Enables or disables the frequency sweep.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencySweepState(ViSession instrSession,
                                                       ViBoolean sweepState)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  value = RSSMX_VAL_RF_FREQUENCY_CW;

    checkErr(RsCore_LockSession(instrSession));

    if (sweepState == VI_TRUE)
        value = RSSMX_VAL_RF_FREQUENCY_SWEEP;

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_MODE, value),
            2, "RF Frequency Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Triggers a sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_RFFrequencySweepExecute(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_EXECUTE, NULL),
            2, "RF Frequency Sweep Execute");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Immediately starts an RF frequency sweep. The sweep to be executed
/// HIFN      depends on the respective MODE setting (:SOURce:SWEep:FREQuency:MODE
/// HIFN      SING). This function corresponds to the manual-control command Execute
/// HIFN      Trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_TriggerRFFrequencySweep(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_TRIGGER_RF_FREQUENCY_SWEEP, NULL),
            2, "Trigger RF Frequency Sweep");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries blank points during the RF frequency sweep in ramp sweep mode.
/// HIFN
/// HIFN     At certain switchover frequency points, the R&S SMA100B shortly blanks
/// HIFN  the RF signal to adjust the settings accordingly.
/// HIFN
/// HIFN     This query returns all blanked frequency points within the entire
/// HIFN  frequency range, regardless of the set frequency sweep range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR blankPoints/Queries blank points during the RF frequency sweep in ramp sweep mode.
/// HIPAR returnedValues/Returns number of values read from instrument.
ViStatus _VI_FUNC rssmx_QueryRFFrequencySweepBlankPoints(ViSession instrSession,
                                                         ViReal64  blankPoints[],
                                                         ViInt32*  returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   sBlankPoints[] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_GetAttributeViString(instrSession, NULL,
                                          RSSMX_ATTR_HIDDEN_RF_FREQUENCY_SWEEP_BLANK_POINTS, RS_MAX_MESSAGE_BUF_SIZE,
                                          sBlankPoints));
    RsCore_Convert_String_To_ViReal64Array(instrSession, sBlankPoints, &blankPoints, returnedValues);

    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the sweep mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sweepMode/Sets the sweep mode.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencySweepMode(ViSession instrSession,
                                                      ViInt32   sweepMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_MODE, sweepMode),
            2, "Sweep Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the trigger source for the RF frequency sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR triggerSource/Sets the trigger source for the RF frequency sweep.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencySweepTriggerSource(
                            ViSession instrSession,
                            ViInt32   triggerSource)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_FREQUENCY_SWEEP_TRIGGER_SOURCE, triggerSource),
            2, "Trigger Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates that the signal changes to the start frequency value while
/// HIFN      it is waiting for the next trigger event.
/// HIFN     You can enable this feature, when you are working with sawtooth shapes
/// HIFN      in sweep mode 'Single' or 'External Single'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR retrace/Activates that the signal changes to the start frequency value while it is waiting for the next trigger event.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencySweepRetrace(ViSession instrSession,
                                                         ViBoolean retrace)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_RETRACE, retrace),
            2, "Retrace");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  In Sweep mode (:SOUR:FREQ:MODE SWE) this property sets the frequency
/// HIFN      for the next sweep step in the Step sweep mode (:SOUR:SWE:MODE MAN).
/// HIFN      Here only frequency values between the settings [SOUR]:FREQ:STAR and
/// HIFN      ...:STOP are permitted. Each sweep step is triggered by a separate
/// HIFN      :SOUR:FREQ:MAN command.
/// HIFN
/// HIFN     As with the Frequency value entered in the header, the OFFSet value is
/// HIFN      also taken into consideration with this function. The specified value
/// HIFN      range is therefore only effective if OFFSet is set to 0. The value
/// HIFN      range for other OFFset values can be calculated using the following
/// HIFN      formula (see also section RF Frequency and Phase - Frequency - Phase).
/// HIFN
/// HIFN     STARt + OFFSet ... STOP + OFFSet
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR manualStep/In Sweep mode (:SOUR:FREQ:MODE SWE) this property sets the frequency for the next sweep step in the Step sweep mode (:SOUR:SWE:MODE MAN). Here only frequency values between the settings [SOUR]:FREQ:STAR and ...:STOP are permitted. Each sweep step is triggered by a separate :SOUR:FREQ:MAN command.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencySweepManualStep(ViSession instrSession,
                                                            ViReal64  manualStep)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_MANUAL_STEP, manualStep),
            2, "Manual Step");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the time taken for each frequency step of the sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR dwellTime/Sets the time taken for each frequency step of the sweep.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencySweepDwellTime(ViSession instrSession,
                                                           ViReal64  dwellTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_DWELL_TIME, dwellTime),
            2, "Dwell Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the cycle mode for a sweep sequence (shape).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR shape/Selects the cycle mode for a sweep sequence (shape).
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencySweepShape(ViSession instrSession,
                                                       ViInt32   shape)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_SHAPE, shape),
            2, "Shape");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the duration of a frequency ramp sweep step.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencySweepTime(ViSession instrSession,
                                                      ViReal64  frequencySweepTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_TIME, frequencySweepTime),
            2, "Frequency Sweep Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the start and stop frequencies for RF
/// HIFN      frequency sweep. If the stop frequency is less than the start
/// HIFN      frequency, the frequency decreases during the sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR startFrequency/Sets the start frequency for the sweep mode. STARt can be greater than STOP.
/// HIPAR stopFrequency/Sets the stop frequency for the sweep mode. STOP can be less than STARt.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencySweepStartStop(ViSession instrSession,
                                                           ViReal64  startFrequency,
                                                           ViReal64  stopFrequency)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_START_FREQUENCY, startFrequency),
            2, "Start Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_STOP_FREQUENCY, stopFrequency),
            3, "Stop Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the center frequency and span for a frequency
/// HIFN      sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR centerFrequency/Sets the center frequency of the sweep. This setting in combination with the span setting ([SOURce:]FREQuency:SPAN) defines the sweep range.
/// HIPAR span/Specifies the span for the sweep. This setting in combination with the center frequency setting ([SOUR]:FREQ:CENT) defines the sweep range.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencySweepCenterSpan(ViSession instrSession,
                                                            ViReal64  centerFrequency,
                                                            ViReal64  span)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_CENTER_FREQUENCY, centerFrequency),
            2, "Center Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_SPAN, span),
            3, "Span");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the number of steps in an RF sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sweepPoints/Sets the number of steps in an RF sweep. This function is linked to the command :SWEep[:FREQuency]:STEP as follows:
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencySweepPoints(ViSession instrSession,
                                                        ViInt32   sweepPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_POINTS, sweepPoints),
            2, "Sweep Points");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures RF frequency sweep spacing.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR spacing/Selects linear or logarithmic sweep spacing.
/// HIPAR step/Sets the step width for linear or logarithmic sweeps. The value is added at each sweep step to the current frequency.
ViStatus _VI_FUNC rssmx_ConfigureRFFrequencySweepSpacing(ViSession instrSession,
                                                         ViInt32   spacing,
                                                         ViReal64  step)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_SPACING, spacing),
            2, "Spacing");
    switch (spacing)
    {
    case RSSMX_VAL_FREQ_SWEEP_SPACING_LINEAR:
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_STEP_LIN, step),
                3, "Step Linear");
        break;
    case RSSMX_VAL_FREQ_SWEEP_SPACING_LOGARITHMIC:
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_SWEEP_STEP_LOG, step),
                3, "Step Logarithmic");
        break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables or disables the LF frequency sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR sweepState/Enables or disables the LF frequency sweep.
ViStatus _VI_FUNC rssmx_ConfigureLFFrequencySweepState(ViSession instrSession,
                                                       ViBoolean sweepState)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  value = RSSMX_VAL_MODE_CW;

    checkErr(RsCore_LockSession(instrSession));

    if (sweepState == VI_TRUE)
        value = RSSMX_VAL_MODE_SWEEP;
    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LF_MODE, value),
            2, "LF Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Immediately starts an LF sweep. The MODE setting determines which
/// HIFN      sweep is executed, e.g. :SOURce:LFOutput:SWEep:FREQuency:MODE STEP.
/// HIFN      This function corresponds to the manual-control command EXECUTE SINGLE
/// HIFN      SWEEP.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_LFFrequencySweepExecute(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_LF_FREQUENCY_SWEEP_EXECUTE, NULL),
            2, "LF Frequency Sweep Execute");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Executes an LF frequency sweep in single trigger mode. To execute the
/// HIFN      sweep, preset RSSMX_ATTR_LF_SWEEP_MODE - AUTO, and
/// HIFN      RSSMX_ATTR_LF_SWEEP_TRIGGER_SOURCE - SING.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_TriggerLFFrequencySweep(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_TRIGGER_LF_FREQUENCY_SWEEP, NULL),
            2, "Trigger LF Frequency Sweep");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Executes an LF frequency sweep in the following configuration:
/// HIFN     TRIG:LFFS:SOUR SING
/// HIFN     LFO:SWE:MODE AUTO
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_TriggerLFFrequencySweepAuto(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_TRIGGER_LF_FREQUENCY_SWEEP, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the mode for the output of the LF generator frequency, and
/// HIFN      determines the commands to be used for frequency settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR lfMode/Sets the mode for the output of the LF generator frequency, and determines the commands to be used for frequency settings.
ViStatus _VI_FUNC rssmx_ConfigureLFFrequencyMode(ViSession instrSession,
                                                 ViInt32   lfMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LF_MODE, lfMode),
            2, "LF Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the sweep cycle mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sweepMode/Sets the sweep cycle mode.
ViStatus _VI_FUNC rssmx_ConfigureLFFrequencySweepMode(ViSession instrSession,
                                                      ViInt32   sweepMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LF_FREQUENCY_SWEEP_MODE, sweepMode),
            2, "Sweep Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the trigger source for the LF sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR triggerSource/Sets the trigger source for the LF sweep.
ViStatus _VI_FUNC rssmx_ConfigureLFFrequencySweepTriggerSource(
                            ViSession instrSession,
                            ViInt32   triggerSource)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LF_FREQUENCY_SWEEP_TRIGGER_SOURCE, triggerSource),
            2, "Trigger Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates that the signal changes to the start frequency value while
/// HIFN      it is waiting for the next trigger event.
/// HIFN     You can enable this feature, when you are working with sawtooth shapes
/// HIFN      in sweep mode 'Single' or 'External Single'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR retrace/Activates that the signal changes to the start frequency value while it is waiting for the next trigger event.
ViStatus _VI_FUNC rssmx_ConfigureLFFrequencySweepRetrace(ViSession instrSession,
                                                         ViBoolean retrace)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_LF_FREQUENCY_SWEEP_RETRACE, retrace),
            2, "Retrace");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  In Sweep mode (:SOUR:LFO:FREQ:MODE SWE) this function sets the
/// HIFN      frequency for the next sweep step in the Step sweep mode
/// HIFN      (:SOUR:LFO:SWE:MODE MAN). Here only frequency values between the
/// HIFN      settings :SOUR:LFO:FREQ:STAR and ...:STOP are permitted. Each sweep
/// HIFN      step is triggered by a separate :SOUR:LFO:FREQ:MAN command.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR manualStep/In Sweep mode (:SOUR:LFO:FREQ:MODE SWE) this function sets the frequency for the next sweep step in the Step sweep mode (:SOUR:LFO:SWE:MODE MAN). Here only frequency values between the settings :SOUR:LFO:FREQ:STAR and ...:STOP are permitted. Each sweep step is triggered by a separate :SOUR:LFO:FREQ:MAN command.
ViStatus _VI_FUNC rssmx_ConfigureLFFrequencySweepManualStep(ViSession instrSession,
                                                            ViReal64  manualStep)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_LF_FREQUENCY_SWEEP_MANUAL_STEP, manualStep),
            2, "Manual Step");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the cycle mode for a sweep sequence (shape).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR shape/Selects the cycle mode for a sweep sequence (shape).
ViStatus _VI_FUNC rssmx_ConfigureLFFrequencySweepShape(ViSession instrSession,
                                                       ViInt32   shape)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LF_FREQUENCY_SWEEP_SHAPE, shape),
            2, "Shape");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the dwell time for each frequency step of the sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR dwellTime/Sets the dwell time for each frequency step of the sweep.
ViStatus _VI_FUNC rssmx_ConfigureLFFrequencySweepDwellTime(ViSession instrSession,
                                                           ViReal64  dwellTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_LF_FREQUENCY_SWEEP_DWELL_TIME, dwellTime),
            2, "Dwell Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the start and stop frequencies for LF
/// HIFN      frequency sweep. If the stop frequency is less than the start
/// HIFN      frequency, the frequency decreases during the sweep.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSSMX_ATTR_LF_FREQUENCY_SWEEP_START_FREQUENCY
/// HIFN     RSSMX_ATTR_LF_FREQUENCY_SWEEP_STOP_FREQUENCY
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     [:SOURce]:LFOutput:FREQuency:STARt
/// HIFN     [:SOURce]:LFOutput:FREQuency:STOP
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR startFrequency/Sets the start frequency for the LF Sweep mode.
/// HIPAR stopFrequency/Sets the stop frequency for the LF sweep.
ViStatus _VI_FUNC rssmx_ConfigureLFFrequencySweepStartStop(ViSession instrSession,
                                                           ViReal64  startFrequency,
                                                           ViReal64  stopFrequency)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_LF_FREQUENCY_SWEEP_START_FREQUENCY, startFrequency),
            2, "Start Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_LF_FREQUENCY_SWEEP_STOP_FREQUENCY, stopFrequency),
            3, "Stop Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  The following applies for linear sweeps and STARt < STOP:     POINts =
/// HIFN      ((STOP-STARt) / STEP:LIN) + 1
/// HIFN
/// HIFN     The following applies for logarithmic sweeps and STARt < STOP:
/// HIFN
/// HIFN     POINts = ((log STOP - log STARt) / log STEP:LOG) + 1
/// HIFN
/// HIFN     If POINTs changes, the value of STEP is adjusted. The STARt and STOP
/// HIFN      value is retained.
/// HIFN
/// HIFN     Two separate POINts values are used for linear or logarithmic sweep
/// HIFN      spacing (LFOutput:SWEep[:FREQuency]:SPACing LIN | LOG). This function
/// HIFN      is always effective for the currently set sweep spacing.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sweepPoints/The following applies for linear sweeps and STARt < STOP:     POINts = ((STOP-STARt) / STEP:LIN) + 1
ViStatus _VI_FUNC rssmx_ConfigureLFFrequencySweepPoints(ViSession instrSession,
                                                        ViInt32   sweepPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LF_FREQUENCY_SWEEP_POINTS, sweepPoints),
            2, "Sweep Points");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects linear or logarithmic sweep spacing.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR spacing/Selects linear or logarithmic sweep spacing.
/// HIPAR step/Sets the step width for the linear or logartithmic sweep.
ViStatus _VI_FUNC rssmx_ConfigureLFFrequencySweepSpacing(ViSession instrSession,
                                                         ViInt32   spacing,
                                                         ViReal64  step)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LF_FREQUENCY_SWEEP_SPACING, spacing),
            2, "Spacing");

    switch (spacing)
    {
    case RSSMX_VAL_FREQ_SWEEP_SPACING_LINEAR:
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_LF_FREQUENCY_SWEEP_STEP_LIN, step),
                3, "Step Lin");
        break;
    case RSSMX_VAL_FREQ_SWEEP_SPACING_LOGARITHMIC:
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_LF_FREQUENCY_SWEEP_STEP_LOG, step),
                3, "Step Log");
        break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables or disables the RF level sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR sweepState/Enables or disables the RF level sweep.
ViStatus _VI_FUNC rssmx_ConfigureRFLevelSweepState(ViSession instrSession,
                                                   ViBoolean sweepState)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  value = RSSMX_VAL_MODE_CW;

    checkErr(RsCore_LockSession(instrSession));

    if (sweepState == VI_TRUE)
        value = RSSMX_VAL_MODE_SWEEP;

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_POWER_MODE, value),
            2, "Level Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Triggers a sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_RFLevelSweepExecute(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_SWEEP_EXECUTE, NULL),
            2, "RF Level Sweep Execute");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Immediately starts an RF level sweep. The sweep to be executed depends
/// HIFN      on the set sweep mode (:SOURce<1|2>:SWEep:POWer:MODE). This function
/// HIFN      corresponds to the manual-control command Execute Trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_TriggerRFLevelSweep(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_TRIGGER_RF_LEVEL_SWEEP, NULL),
            2, "Trigger RF Level Sweep");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the operating mode of the instrument to set the output level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR levelMode/Selects the operating mode of the instrument to set the output level.
ViStatus _VI_FUNC rssmx_ConfigureRFLevelMode(ViSession instrSession,
                                             ViInt32   levelMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_POWER_MODE, levelMode),
            2, "Level Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the sweep mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sweepMode/Sets the sweep mode.
ViStatus _VI_FUNC rssmx_ConfigureRFLevelSweepMode(ViSession instrSession,
                                                  ViInt32   sweepMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_SWEEP_MODE, sweepMode),
            2, "Sweep Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the trigger source for the RF level sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR triggerSource/Sets the trigger source for the RF level sweep.
ViStatus _VI_FUNC rssmx_ConfigureRFLevelSweepTriggerSource(ViSession instrSession,
                                                           ViInt32   triggerSource)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_SWEEP_TRIGGER_SOURCE, triggerSource),
            2, "Trigger Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates that the signal changes to the start level value while it is
/// HIFN      waiting for the next trigger event.
/// HIFN     You can enable this feature, when you are working with sawtooth shapes
/// HIFN      in sweep mode 'Single' or 'External Single'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR retrace/Activates that the signal changes to the start level value while it is waiting for the next trigger event.
ViStatus _VI_FUNC rssmx_ConfigureRFLevelSweepRetrace(ViSession instrSession,
                                                     ViBoolean retrace)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_SWEEP_RETRACE, retrace),
            2, "Retrace");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  In Sweep mode (:SOUR:POW:MODE SWE) this function sets the level for
/// HIFN      the next sweep step in the Step sweep mode (:SOUR:SWE:POW:MODE MAN).
/// HIFN      Here only level values between the settings [SOUR]:POW:STAR and
/// HIFN      ...:STOP are permitted. Each sweep step is triggered by a separate
/// HIFN      :SOUR:POW:MAN command.
/// HIFN
/// HIFN     As with the Level value entered in the RF Level menu, the OFFSet value
/// HIFN      is also taken into consideration with this function.
/// HIFN
/// HIFN     The specified value range is therefore only effective if
/// HIFN      :SOURce:POWer:OFFSet is set to 0. The value range for other OFFset
/// HIFN      values can be calculated using the following formula (see also Chapter
/// HIFN      4, section Level Offset - RF Signal):
/// HIFN
/// HIFN     Minimum level + OFFSet ... Maximum level + OFFSet
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR manualStep/In Sweep mode (:SOUR:POW:MODE SWE) this function sets the level for the next sweep step in the Step sweep mode (:SOUR:SWE:POW:MODE MAN). Here only level values between the settings [SOUR]:POW:STAR and ...:STOP are permitted. Each sweep step is triggered by a separate :SOUR:POW:MAN command.
ViStatus _VI_FUNC rssmx_ConfigureRFLevelSweepManualStep(ViSession instrSession,
                                                        ViReal64  manualStep)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_SWEEP_MANUAL_STEP, manualStep),
            2, "Manual Step");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the cycle mode for a sweep sequence (shape).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR shape/Selects the cycle mode for a sweep sequence (shape).
ViStatus _VI_FUNC rssmx_ConfigureRFLevelSweepShape(ViSession instrSession,
                                                   ViInt32   shape)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_SWEEP_SHAPE, shape),
            2, "Shape");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the time taken for each level step of the sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR dwellTime/Sets the time taken for each level step of the sweep.
ViStatus _VI_FUNC rssmx_ConfigureRFLevelSweepDwellTime(ViSession instrSession,
                                                       ViReal64  dwellTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_SWEEP_DWELL_TIME, dwellTime),
            2, "Dwell Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the RF start and stop levels in Sweep mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR startLevel/Sets the RF start level in Sweep mode.
/// HIPAR stopLevel/Sets the stop level in Sweep mode.
ViStatus _VI_FUNC rssmx_ConfigureRFLevelSweepStartStop(ViSession instrSession,
                                                       ViReal64  startLevel,
                                                       ViReal64  stopLevel)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_SWEEP_START_LEVEL, startLevel),
            2, "Start Level");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_SWEEP_STOP_LEVEL, stopLevel),
            3, "Stop Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the number of steps in a level sweep. This function is linked to
/// HIFN      the command :SWEep:POWer:STEP as follows:
/// HIFN
/// HIFN     POINts = ((STOP - STARt) / STEP:LOG) + 1
/// HIFN
/// HIFN     If POINTs changes, the value of STEP is adjusted. The STARt and STOP
/// HIFN      value is retained.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sweepPoints/Sets the number of steps in a level sweep. This function is linked to the command :SWEep:POWer:STEP as follows:
ViStatus _VI_FUNC rssmx_ConfigureRFLevelSweepPoints(ViSession instrSession,
                                                    ViInt32   sweepPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_SWEEP_POINTS, sweepPoints),
            2, "Sweep Points");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the step width factor for logarithmic sweeps. The next level
/// HIFN      value of a sweep is calculated (for STARt < STOP) using the following
/// HIFN      formula:
/// HIFN
/// HIFN     New level = Old level + STEP:LOG x Old level
/// HIFN
/// HIFN     STEP:LOG therefore gives the fraction of the old level. The level is
/// HIFN      increased by this fraction for the next sweep step. Usually STEP:LOG is
/// HIFN      given in decibels, whereby the suffix dB must always be used.
/// HIFN
/// HIFN     This function is linked to the command :SWEep:POWer:POINts for STARt <
/// HIFN      STOP as follows:
/// HIFN
/// HIFN     POINts = ((STOP - STARt) / STEP:LOG) + 1
/// HIFN
/// HIFN     If STEP:LOG changes, the value of POINTs is adjusted. The STARt and
/// HIFN      STOP value is retained.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR step/Sets the step width factor for logarithmic sweeps.
ViStatus _VI_FUNC rssmx_ConfigureRFLevelSweepStep(ViSession instrSession,
                                                  ViReal64  step)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_LEVEL_SWEEP_STEP, step),
            2, "Step");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}



/// HIFN  Enables or disables the RF cobmined sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR rfCombinedSweepState/Enables or disables the RF cobmined sweep.
ViStatus _VI_FUNC rssmx_ConfigureRFCombinedSweepState(ViSession instrSession,
                                                      ViBoolean rfCombinedSweepState)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  sweepMode = RSSMX_VAL_RF_FREQUENCY_CW;

    checkErr(RsCore_LockSession(instrSession));

    if(rfCombinedSweepState == VI_TRUE)
        sweepMode = RSSMX_VAL_RF_FREQUENCY_COMBINED;

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_MODE, sweepMode),
            2, "RF Combined Sweep State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the cycle mode for the combined frequency / level sweep.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Sets the cycle mode for the combined frequency / level sweep.
ViStatus _VI_FUNC rssmx_ConfigureRFCombinedSweepMode(ViSession instrSession,
                                                     ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_COMBINED_SWEEP_MODE, mode),
            2, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the trigger source for the combined RF frequency / level
/// HIFN  sweep.
/// HIFN     The parameter names correspond to the manual control. If needed, see
/// HIFN  table Table 'Cross-reference between the manual and remote control '
/// HIFN  for selecting the trigger source with SCPI compliant parameter names.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR triggerSource/Selects the trigger source for the combined RF frequency / level
/// HIPAR triggerSource/sweep.
ViStatus _VI_FUNC rssmx_ConfigureRFCombinedSweepTriggerSource(
                            ViSession instrSession,
                            ViInt32   triggerSource)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_COMBINED_SWEEP_TRIGGER_SOURCE, triggerSource),
            2, "Trigger Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates that the signal changes to the start level value while it is
/// HIFN  waiting for the next trigger event.
/// HIFN     You can enable this feature, when you are working with sawtooth shapes
/// HIFN  in sweep mode 'Single' or 'External Single'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR retrace/Activates that the signal changes to the start level value while it is
/// HIPAR retrace/waiting for the next trigger event.
ViStatus _VI_FUNC rssmx_ConfigureRFCombinedSweepRetrace(ViSession instrSession,
                                                        ViBoolean retrace)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_RF_COMBINED_SWEEP_RETRACE, retrace),
            2, "Retrace");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Executes an RF frequency / level sweep cycle.
/// HIFN     The command triggers one single sweep manually. Therefore, you can use
/// HIFN  it in manual sweep mode, selected with
/// HIFN  RSSMX_ATTR_RF_COMBINED_SWEEP_MODE set as MANual.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_ExecuteRFCombinedSingleSweep(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_RF_COMBINED_SWEEP_EXECUTE_SINGLE_SWEEP, NULL));

    checkErr(RsCore_CheckStatus(instrSession, error));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the waveform shape for the combined frequency / level sweep
/// HIFN  sequence.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR shape/Selects the waveform shape for the combined frequency / level sweep
/// HIPAR shape/sequence.
ViStatus _VI_FUNC rssmx_ConfigureRFCombinedSweepShape(ViSession instrSession,
                                                      ViInt32   shape)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_COMBINED_SWEEP_SHAPE, shape),
            2, "Shape");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the dwell time for the combined frequency / level sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR dwellTime/Sets the dwell time for the combined frequency / level sweep.
ViStatus _VI_FUNC rssmx_ConfigureRFCombinedSweepDwellTime(ViSession instrSession,
                                                          ViReal64  dwellTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

       viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_COMBINED_SWEEP_DWELL_TIME, dwellTime),
               2, "Dwell Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the start and end frequency of the combined RF frequency / level
/// HIFN  sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR startFrequency/Sets the start frequency of the combined RF frequency / level sweep.
/// HIPAR startFrequency/See 'Correlating Parameters in Sweep Mode'.
/// HIPAR stopFrequency/Sets the end frequency of the combined RF frequency / level sweep.
ViStatus _VI_FUNC rssmx_ConfigureRFCombinedSweepFrequencyStartStop(
                            ViSession instrSession,
                            ViReal64  startFrequency,
                            ViReal64  stopFrequency)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_COMBINED_SWEEP_RANGE_FREQUENCY_START, startFrequency),
            2, "Start Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_COMBINED_SWEEP_RANGE_FREQUENCY_STOP, stopFrequency),
            3, "Stop Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the start and stop level value of the combined RF frequency /
/// HIFN  level sweep.
/// HIFN     See 'Correlating Parameters in Sweep Mode'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR startLevel/Sets the start level value of the combined RF frequency / level sweep.
/// HIPAR stopLevel/Sets the stop level value of the combined RF frequency / level sweep.
ViStatus _VI_FUNC rssmx_ConfigureRFCombinedSweepLevelStartStop(
                            ViSession instrSession,
                            ViReal64  startLevel,
                            ViReal64  stopLevel)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_COMBINED_SWEEP_RANGE_POWER_START, startLevel),
            2, "Start Level");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_RF_COMBINED_SWEEP_RANGE_POWER_STOP, stopLevel),
            3, "Stop Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the number of sweeps you want to execute.
/// HIFN     This parameter applies to RSSMX_ATTR_RF_COMBINED_SWEEP_MODE > SINGle.
/// HIFN  To start the sweep signal generation, use the command
/// HIFN  RSSMX_ATTR_RF_COMBINED_SWEEP_EXECUTE_SINGLE_SWEEP.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR stepCount/Defines the number of sweeps you want to execute.
ViStatus _VI_FUNC rssmx_ConfigureRFCombinedSweepStepCount(ViSession instrSession,
                                                          ViInt32   stepCount)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_COMBINED_SWEEP_STEP_COUNT, stepCount),
            2, "Step Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}



/// HIFN  This function enables or disables the list state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.  The handle identifies a particular iinstrument session.
/// HIPAR listState/Enables or disables the list state.
ViStatus _VI_FUNC rssmx_ConfigureListState(ViSession instrSession,
                                           ViBoolean listState)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  value = RSSMX_VAL_RF_FREQUENCY_CW;

    checkErr(RsCore_LockSession(instrSession));

    if (listState == VI_TRUE)
        value = RSSMX_VAL_RF_FREQUENCY_LIST;

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RF_FREQUENCY_MODE, value),
            2, "RF Frequency Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures general settins of list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR listMode/Sets the list mode.
/// HIPAR dwellTimeMode/Selects the dwell time mode.
ViStatus _VI_FUNC rssmx_ConfigureListGeneralSettings(ViSession instrSession,
                                                     ViInt32   listMode,
                                                     ViInt32   dwellTimeMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LIST_MODE, listMode),
            2, "List Mode");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LIST_DWELL_TIME_MODE, dwellTimeMode),
            3, "Dwell Time Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the index.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR listIndex/Sets the index.
ViStatus _VI_FUNC rssmx_ConfigureListIndex(ViSession instrSession,
                                           ViInt32   listIndex)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LIST_INDEX, listIndex),
            2, "List Index");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the time for which the instrument retains a setting.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR dwellTime/Sets the time for which the instrument retains a setting.
ViStatus _VI_FUNC rssmx_ConfigureListGlobalDwellTime(ViSession instrSession,
                                                     ViReal64  dwellTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_LIST_DWELL_TIME, dwellTime),
            2, "Dwell Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enters the dwell time values in the selected list in s.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Dwell Times'.
/// HIPAR dwellTimes/Array of dwell times.
ViStatus _VI_FUNC rssmx_ConfigureDwellTimesList(ViSession instrSession,
                                                ViUInt32  arraySize,
                                                ViReal64  dwellTimes[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_WriteViReal64Array(instrSession,
                                          ":LIST:DWEL:LIST",
                                          arraySize,
                                          dwellTimes));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the trigger source for the list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR listTriggerSource/Sets the trigger source for the list mode.
ViStatus _VI_FUNC rssmx_ConfigureListTriggerSource(ViSession instrSession,
                                                   ViInt32   listTriggerSource)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LIST_TRIGGER_SOURCE, listTriggerSource),
            2, "List Trigger Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Immediately starts the processing of a list in list mode. It
/// HIFN      corresponds to the manual-control command Execute Single.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_ListTriggerExecute(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_LIST_TRIGGER_EXECUTE, NULL),
            2, "List Trigger Execute");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Requests a list of available lists. The individual lists are separated
/// HIFN      by commas.
/// HIFN
/// HIFN     The lists are stored with the fixed file extensions *.lsw in a
/// HIFN      directory of the user's choice. The directory applicable to the
/// HIFN      commands is defined with the command MMEMory:CDIR. A path can also be
/// HIFN      specified in command :SOUR:LIST:CAT?, in which case the files in the
/// HIFN      specified folder are read.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Catalog'.
/// HIPAR catalog/List of list filenames, separated by commas.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is larger then 'Array Size', then the response stored in 'Catalog' is not complete. Resize 'Catalog' array to accomodate all values and call into  the function again.
ViStatus _VI_FUNC rssmx_QueryListCatalog(ViSession instrSession,
                                         ViUInt32  arraySize,
                                         ViChar    catalog[],
                                         ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_QueryCatalog(instrSession, ":LIST:CAT?", arraySize, catalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the specified list. If a new list is to be created, the name
/// HIFN      can be entered here. The list is created if it does not yet exist. The
/// HIFN      list selected here is available for the further processing steps
/// HIFN      (editing) and is used in the instrument when the List mode is
/// HIFN      activated.
/// HIFN
/// HIFN     The files are stored with the fixed file extensions *.lsw in a
/// HIFN      directory of the user's choice. The directory applicable to the command
/// HIFN      is defined with the command MMEMory:CDIR. A path can also be specified
/// HIFN      in command :SOUR:LIST:SEL in which case the list mode file in the
/// HIFN      specified folder is selected.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileName/Selects the specified list. If a new list is to be created, the name can be entered here. The list is created if it does not yet exist. The list selected here is available for the further processing steps (editing) and is used in the instrument when the List mode is activated.
ViStatus _VI_FUNC rssmx_SelectList(ViSession instrSession,
                                   ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_LIST_SELECT_LIST, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enters the frequency values in the selected list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR frequencies/Enters the frequency values in the selected list.
/// HIPAR arraySize/Size of array passed to 'Frequencies'.
ViStatus _VI_FUNC rssmx_ConfigureListFrequencies(ViSession instrSession,
                                                 ViUInt32  arraySize,
                                                 ViReal64  frequencies[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_WriteViReal64Array(instrSession,
                                          ":LIST:FREQ",
                                          arraySize,
                                          frequencies));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enters the level values in the selected list. The number of level
/// HIFN      values must correspond to the number of frequency values. Existing data
/// HIFN      is overwritten.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Levels'.
/// HIPAR levels/Enters the level values in the selected list. The number of level values must correspond to the number of frequency values. Existing data is overwritten.
ViStatus _VI_FUNC rssmx_ConfigureListLevels(ViSession instrSession,
                                            ViUInt32  arraySize,
                                            ViReal64  levels[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_WriteViReal64Array(instrSession,
                                          ":LIST:POW",
                                          arraySize,
                                          levels));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the start and stop index of the index range which defines a
/// HIFN      subgroup of frequency/level value pairs in the current list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR listStartIndex/Sets the start index of the index range which defines a subgroup of frequency/level value pairs in the current list.
/// HIPAR listStopIndex/Sets the stop index of the index range which defines a subgroup of frequency/level value pairs in the current list.
ViStatus _VI_FUNC rssmx_ConfigureListStartStopIndex(ViSession instrSession,
                                                    ViInt32   listStartIndex,
                                                    ViInt32   listStopIndex)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LIST_START_INDEX, listStartIndex),
            2, "List Start Index");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LIST_STOP_INDEX, listStopIndex),
            3, "List Stop Index");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Resets the list to the starting point.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_ResetList(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_LIST_RESET_LIST, NULL),
            2, "List Reset List");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the specified list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileName/File Name parameter.
ViStatus _VI_FUNC rssmx_DeleteList(ViSession instrSession,
                                   ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_LIST_DELETE_LIST, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes all lists in the set directory. The List mode must be
/// HIFN      deactivated beforehand to ensure that no lists are selected when this
/// HIFN      function is called (:SOUR:FREQ:MODE CW or SWE).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_DeleteAllLists(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_LIST_DELETE_ALL, NULL),
            2, "List Delete All");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the available ASCII files for export or import of list mode
/// HIFN      data in the current directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Catalog'.
/// HIPAR catalog/List of list filenames, separated by commas.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is larger then 'Array Size', then the response stored in 'Catalog' is not complete. Resize 'Catalog' array to accomodate all values and call into  the function again.
ViStatus _VI_FUNC rssmx_QueryListImportExportCatalog(ViSession instrSession,
                                                     ViUInt32  arraySize,
                                                     ViChar    catalog[],
                                                     ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_QueryCatalog(instrSession, ":LIST:DEXC:AFIL:CAT?", arraySize, catalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Calls the File Manager for selecting the list mode list to be exported
/// HIFN      (source) into an ASCII file or the destination for the ASCII file to be
/// HIFN      imported (destination) in.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR listImportExportFile/Calls the File Manager for selecting the list mode list to be exported (source) into an ASCII file or the destination for the ASCII file to be imported (destination) in.
ViStatus _VI_FUNC rssmx_SelectListImportExportFile(ViSession instrSession,
                                                   ViString  listImportExportFile)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_LIST_IMPORT_EXPORT_FILE, listImportExportFile),
            2, "List Import Export File");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the ASCII file to be imported or exported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR listImportExportASCIIFile/Selects the ASCII file to be imported or exported.
ViStatus _VI_FUNC rssmx_SelectListImportExportASCIIFile(ViSession instrSession,
                                                        ViString  listImportExportASCIIFile)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_LIST_IMPORT_EXPORT_ASCII_FILE, listImportExportASCIIFile),
            2, "List Import Export ASCII File");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures parameters of the ASCII file for import or export.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR extension/Determines the extension of the ASCII file for import or export.
/// HIPAR columnSeparator/Selects the separator between the frequency and level column of the ASCII table.
/// HIPAR decimalSeparator/Selects the decimal separator used in the ASCII data between '.' (decimal point) and ',' (comma) with floating-point numerals.
ViStatus _VI_FUNC rssmx_ConfigureListImportExportASCIIFile(ViSession instrSession,
                                                           ViInt32   extension,
                                                           ViInt32   columnSeparator,
                                                           ViInt32   decimalSeparator)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LIST_IMPORT_EXPORT_ASCII_EXTENSION, extension),
            2, "Extension");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LIST_IMPORT_EXPORT_ASCII_DECIMAL_SEPARATOR, decimalSeparator),
            4, "Decimal Separator");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LIST_IMPORT_EXPORT_ASCII_COLUMN_SEPARATOR, columnSeparator),
            3, "Column Separator");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Determines the import or export of a list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR listImportExport/Determines the import or export of a list.
ViStatus _VI_FUNC rssmx_ConfigureListImportExport(ViSession instrSession,
                                                  ViInt32   listImportExport)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_LIST_IMPORT_EXPORT, listImportExport),
            2, "List Import Export");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Starts the export or import of the selected file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_ListImportExportExecute(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_LIST_IMPORT_EXPORT_EXECUTE, NULL),
            2, "List Import Export Execute");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates user correction with the currently selected table.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR userCorrectionDataEnabled/Activates user correction with the currently selected table.
ViStatus _VI_FUNC rssmx_ConfigureUserCorrectionState(ViSession instrSession,
                                                     ViBoolean userCorrectionDataEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_USER_CORRECTION_DATA_ENABLED, userCorrectionDataEnabled),
            2, "User Correction Data Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Requests a list of user correction tables.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Catalog'.
/// HIPAR catalog/List of list filenames, separated by commas.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is larger then 'Array Size', then the response stored in 'Catalog' is not complete. Resize 'Catalog' array to accomodate all values and call into  the function again.
ViStatus _VI_FUNC rssmx_QueryUserCorrectionCatalog(ViSession instrSession,
                                                   ViUInt32  arraySize,
                                                   ViChar    catalog[],
                                                   ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_QueryCatalog(instrSession, ":CORR:CSET:CAT?", arraySize, catalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the table for user correction. Level correction must also be
/// HIFN      activated with the command :CORRection:CSET:STATe ON.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileName/Selects the table for user correction. Level correction must also be activated with the command :CORRection:CSET:STATe ON.
ViStatus _VI_FUNC rssmx_SelectUserCorrectionTable(ViSession instrSession,
                                                  ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_USER_CORRECTION_DATA_TABLE, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enters the frequency values in the selected table.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Frequencies'.
/// HIPAR frequencies/Enters the frequency values in the selected table.
ViStatus _VI_FUNC rssmx_ConfigureUserCorrectionFrequencies(ViSession instrSession,
                                                           ViUInt32  arraySize,
                                                           ViReal64  frequencies[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_WriteViReal64Array(instrSession,
                                          ":CORR:CSET:DATA:FREQ",
                                          arraySize,
                                          frequencies));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enters the level values in the selected table.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Frequencies'.
/// HIPAR levels/Enters the level values in the selected table.
ViStatus _VI_FUNC rssmx_ConfigureUserCorrectionLevels(ViSession instrSession,
                                                      ViUInt32  arraySize,
                                                      ViReal64  levels[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_WriteViReal64Array(instrSession,
                                          ":CORR:CSET:DATA:POW",
                                          arraySize,
                                          levels));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Fills the selected user correction table with the level values
/// HIFN      measured by the power sensor for the given frequencies.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Sets the sensor number.
ViStatus _VI_FUNC rssmx_UserCorrectionFillWithSensor(ViSession instrSession,
                                                     ViInt32   sensor,
                                                     ViUInt32  maxTime)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sensor, 1, 4),
            2, "Sensor");
    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":CORR:CSET:DATA:SENS%ld:POWer:SONCe", sensor);
    checkErr(RsCore_WriteWithOpc(instrSession, cmd, maxTime));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the specified user correction list file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileName/Deletes the specified user correction list file.
ViStatus _VI_FUNC rssmx_DeleteUserCorrection(ViSession instrSession,
                                             ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_USER_CORRECTION_DATA_DELETE, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the available ASCII files for export or import of user
/// HIFN      correction data in the current directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Catalog'.
/// HIPAR catalog/List of list filenames, separated by commas.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is larger then 'Array Size', then the response stored in 'Catalog' is not complete. Resize 'Catalog' array to accomodate all values and call into  the function again.
ViStatus _VI_FUNC rssmx_QueryUserCorrectionDataExchangeCatalog(
                            ViSession instrSession,
                            ViUInt32  arraySize,
                            ViChar    catalog[],
                            ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_QueryCatalog(instrSession, ":CORR:DEXC:AFIL:CAT?", arraySize, catalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the correction file to be imported or exported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileName/Selects the correction file to be imported or exported.
ViStatus _VI_FUNC rssmx_SelectUserCorrectionDataExchangeFile(ViSession instrSession,
                                                             ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_USER_CORRECTION_DATA_EXCHANGE_FILE, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the ASCII file to be imported or exported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileName/Selects the ASCII file to be imported or exported.
ViStatus _VI_FUNC rssmx_SelectUserCorrectionDataExchangeASCIIFile(
                            ViSession instrSession,
                            ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_USER_CORRECTION_DATA_EXCHANGE_ASCII_FILE, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures parameters of the ASCII file for import or export.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR extension/Selects the file extension of the ASCII file to be imported or exported. Selection TXT (text file) or CSV (Excel file) is available.
/// HIPAR columnSeparator/Selects the separator between the frequency and level column of the ASCII table.
/// HIPAR decimalSeparator/Selects the decimal separator used in the ASCII data between '.' (decimal point) and ',' (comma) with floating-point numerals.
ViStatus _VI_FUNC rssmx_ConfigureUserCorrectionDataExchangeFile(
                            ViSession instrSession,
                            ViInt32   extension,
                            ViInt32   columnSeparator,
                            ViInt32   decimalSeparator)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_USER_CORRECTION_DATA_EXCHANGE_EXTENSION, extension),
            2, "Extension");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_USER_CORRECTION_DATA_EXCHANGE_COLUMN_SEPARATOR, columnSeparator),
            3, "Column Separator");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_USER_CORRECTION_DATA_EXCHANGE_DECIMAL_SEPARATOR, decimalSeparator),
            4, "Decimal Separator");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Determines import or export of a user correction list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR userCorrectionDataExchange/Determines import or export of a user correction list.
ViStatus _VI_FUNC rssmx_ConfigureUserCorrectionDataExchange(ViSession instrSession,
                                                            ViInt32   userCorrectionDataExchange)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_USER_CORRECTION_DATA_EXCHANGE, userCorrectionDataExchange),
            2, "User Correction Data Exchange");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Starts the export or import of the selected file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_UserCorrectionDataExchangeExecute(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_CORRECTION_EXECUTE, NULL),
            2, "User Correction Data Exchange Execute");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates/deactivates the VOR modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR vorEnabled/Activates/deactivates the VOR modulation.
ViStatus _VI_FUNC rssmx_ConfigureVOREnabled(ViSession instrSession,
                                            ViInt32   path,
                                            ViBoolean vorEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_VOR_ENABLED, vorEnabled),
            3, "VOR Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the parameters of the digital standard to their default values.
/// HIFN
/// HIFN     Not affected is the state set with the command rssmx_VOREnabled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
ViStatus _VI_FUNC rssmx_SetVORToDefault(ViSession instrSession,
                                        ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    checkErr(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_VOR_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the files with settings in the default directory. Listed are
/// HIFN  files with the file extension *.adf/*.ils/*.vor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR arraySize/Size of array passed to 'Settings Catalog'.
/// HIPAR settingsCatalog/Returns a string of filenames separated by commas.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is
/// HIPAR bytesRead/larger then 'Array Size', then the response stored in 'Settings
/// HIPAR bytesRead/Catalog' is not complete. Resize 'Settings Catalog' array to accomodate
/// HIPAR bytesRead/all values and call into the function again.
ViStatus _VI_FUNC rssmx_QueryVORSettingsCatalog(ViSession instrSession,
                                                ViInt32   path,
                                                ViUInt32  arraySize,
                                                ViChar    settingsCatalog[],
                                                ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, 2),
            2, "Path");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SOUR%ld:VOR:SETT:CAT?", path);
    checkErr(rssmx_QueryCatalog(instrSession, cmd, arraySize, settingsCatalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes, loads, stores the selected file from the default or the
/// HIFN  specified directory. Files use extension *.adf/*.ils/*.vor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR action/Sets the action with selected file.
/// HIPAR filename/The filename of the settings file to be deleted, loaded or saved.
ViStatus _VI_FUNC rssmx_ManageVORSettings(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   action,
                                          ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr   attr[] = {RSSMX_ATTR_VOR_DELETE_SETTINGS, RSSMX_ATTR_VOR_RECALL_SETTINGS, RSSMX_ATTR_VOR_SAVE_SETTINGS};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, action, RSSMX_VAL_FILE_ACTION_DELETE, RSSMX_VAL_FILE_ACTION_SAVE),
            3, "Action");

    viCheckParm(rssmx_SetAttributeViString(instrSession, repCap, attr[action], filename),
            4, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains the carrier frequency settings for VOR.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR carrierFrequencyMode/Sets the mode for the carrier frequency of the signal
/// HIPAR carrierFrequency/Sets the carrier frequency of the signal
/// HIPAR icaoChannel/Sets the ICAO channel and the corresponding transmitting frequency.
/// HIPAR extAM/Sets the modulation source for the avionic standard modulation.
ViStatus _VI_FUNC rssmx_ConfigureVORCarrierFrequencySettings(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   carrierFrequencyMode,
                                                             ViReal64  carrierFrequency,
                                                             ViInt32   icaoChannel,
                                                             ViInt32   extAM)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_VOR_CARRIER_FREQUENCY_MODE, carrierFrequencyMode),
            3, "Carrier Frequency Mode");

    if (carrierFrequencyMode == RSSMX_VAL_VOR_FREQ_MODE_USER)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_VOR_USER_MODE_CARRIER_FREQUENCY, carrierFrequency),
                4, "Carrier Frequency");
    }
    else
    {
        viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_VOR_ICAO_CHANNEL, icaoChannel),
                5, "ICAO Channel");
    }

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_VOR_EXT_AM, extAM),
            6, "EXT AM");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains signal settings for VOR.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR operatingMode/Selects the operating mode for the VOR modulation signal.
/// HIPAR var/refFrequency/Sets the frequency of the variable and the reference signal.
/// HIPAR varDepth/Sets the AM modulation depth of the 30Hz variable signal.
/// HIPAR subcarrierFrequency/Sets the frequency of the FM carrier.
/// HIPAR subcarrierDepth/Sets the AM modulation depth of the FM carrier.
/// HIPAR refDeviation/Sets the frequency deviation of the reference signal on the FM
/// HIPAR refDeviation/carrier.
ViStatus _VI_FUNC rssmx_ConfigureVORSignalSettings(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViInt32   operatingMode,
                                                   ViReal64  varrefFrequency,
                                                   ViReal64  varDepth,
                                                   ViReal64  subcarrierFrequency,
                                                   ViReal64  subcarrierDepth,
                                                   ViInt32   refDeviation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_VOR_MODE, operatingMode),
            3, "Operating Mode");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_VOR_VAR_REF_FREQUENCY, varrefFrequency),
            4, "VAR/REF Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_VOR_VAR_DEPTH, varDepth),
            5, "VAR Depth");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_VOR_SUBCARRIER_FREQUENCY, subcarrierFrequency),
            6, "Subcarrier Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_VOR_SUBCARRIER_DEPTH, subcarrierDepth),
            7, "Subcarrier Depth");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_VOR_REF_DEVIATION, refDeviation),
            8, "REF Deviation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the position settings related to the VOR modulation signal.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR bearingAngle/Sets the bearing angle between the VAR signal and the reference
/// HIPAR bearingAngle/signal.
/// HIPAR direction/Sets the reference position of the phase information.
ViStatus _VI_FUNC rssmx_ConfigureVORPosition(ViSession instrSession,
                                             ViInt32   path,
                                             ViReal64  bearingAngle,
                                             ViInt32   direction)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_VOR_BEARING_ANGLE, bearingAngle),
            3, "Bearing Angle");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_VOR_DIRECTION, direction),
            4, "Direction");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the COM/ID signal settings related to the VOR signal.
/// HIFN
/// HIFN
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR com/idState/Enables/disables the COM/ID signal.
/// HIPAR code/Sets the coding of the COM/ID signal by the international short name
/// HIPAR code/of the airport (e.g. MUC for the Munich airport).
/// HIPAR period/Sets the period of the COM/ID signal.
/// HIPAR frequency/Sets the frequency of the COM/ID signal.
/// HIPAR depth/Sets the AM modulation depth of the COM/ID signal.
ViStatus _VI_FUNC rssmx_ConfigureVORCOMID(ViSession instrSession,
                                          ViInt32   path,
                                          ViBoolean comidState,
                                          ViString  code,
                                          ViReal64  period,
                                          ViReal64  frequency,
                                          ViReal64  depth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_VOR_COMID_STATE, comidState),
            3, "COM/ID State");

    viCheckParm(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_VOR_CODE, code),
            4, "Code");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_VOR_PERIOD, period),
            5, "Period");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_VOR_FREQUENCY, frequency),
            6, "Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_VOR_DEPTH, depth),
            7, "Depth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains settings for the time schema of the Morse code for the COM/ID
/// HIFN  signal.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) In Standard mode the set dot length determines the length of the
/// HIFN  dash, the symbol space and letter space of the Morse code.
/// HIFN
/// HIFN     (2) In User mode you can set each length value separately.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR timeSchema/Sets the time schema of the Morse code for the COM/ID signal.
/// HIPAR dotLength/Sets the length of a Morse code dot.
/// HIPAR dashLength/Sets the length of a Morse code dash.
/// HIPAR symbolSpace/Sets the length of the Morse code symbol space.
/// HIPAR letterSpace/Sets the length of a Morse code letter space.
ViStatus _VI_FUNC rssmx_ConfigureVORCOMIDTimeSchema(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   timeSchema,
                                                    ViReal64  dotLength,
                                                    ViReal64  dashLength,
                                                    ViReal64  symbolSpace,
                                                    ViReal64  letterSpace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_VOR_TIME_SCHEMA, timeSchema),
            3, "Time Schema");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_VOR_DOT_LENGTH, dotLength),
            4, "Dot Length");

    if (timeSchema == RSSMX_VAL_VOR_TIME_SCHEMA_USER)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_VOR_DASH_LENGTH, dashLength),
                5, "Dash Length");

        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_VOR_SYMBOL_SPACE, symbolSpace),
                6, "Symbol Space");

        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_VOR_LETTER_SPACE, letterSpace),
                7, "Letter Space");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates/deactivates the ILS avionic standard.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR ilsEnabled/Activates/deactivates the ILS avionic standard.
ViStatus _VI_FUNC rssmx_ConfigureILSEnabled(ViSession instrSession,
                                            ViInt32   path,
                                            ViBoolean ilsEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_ILS_ENABLED, ilsEnabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the parameters of the digital standard to their default values.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
ViStatus _VI_FUNC rssmx_SetILSToDefault(ViSession instrSession,
                                        ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    checkErr(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_ILS_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the files with settings in the default directory. Listed are
/// HIFN  files with the file extension *.adf/*.ils/*.vor.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR arraySize/Size of array passed to 'Settings Catalog'.
/// HIPAR settingsCatalog/Returns a string of filenames separated by commas.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is
/// HIPAR bytesRead/larger then 'Array Size', then the response stored in 'Settings
/// HIPAR bytesRead/Catalog' is not complete. Resize 'Settings Catalog' array to accomodate
/// HIPAR bytesRead/all values and call into the function again.
ViStatus _VI_FUNC rssmx_QueryILSSettingsCatalog(ViSession instrSession,
                                                ViUInt32  arraySize,
                                                ViChar    settingsCatalog[],
                                                ViUInt32* bytesRead,
                                                ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, 2),
            2, "Path");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SOUR%ld:ILS:SETT:CAT?", path);
    checkErr(rssmx_QueryCatalog(instrSession, cmd, arraySize, settingsCatalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes, loads, saves the selected file from the default or the
/// HIFN  specified directory. Files use extension *.adf/*.ils/*.vor.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR action/Sets the action with selected file.
/// HIPAR filename/The filename of the settings file to be deleted, loaded or saved.
ViStatus _VI_FUNC rssmx_ManageILSSettings(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   action,
                                          ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr   attr[] = {RSSMX_ATTR_ILS_DELETE_SETTINGS, RSSMX_ATTR_ILS_RECALL_SETTINGS, RSSMX_ATTR_ILS_SAVE_SETTINGS};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, action, RSSMX_VAL_FILE_ACTION_DELETE, RSSMX_VAL_FILE_ACTION_SAVE),
            3, "Action");

    viCheckParm(rssmx_SetAttributeViString(instrSession, repCap, attr[action], filename),
            4, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the ILS modulation type.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR component/Selects the ILS modulation type.
ViStatus _VI_FUNC rssmx_ConfigureILSComponent(ViSession instrSession,
                                              ViInt32   path,
                                              ViInt32   component)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_COMPONENT, component),
            3, "Component");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the parameters of the ILS glide slope component to their default
/// HIFN  values (*RST values specified for the commands).
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
ViStatus _VI_FUNC rssmx_SetILSGlideSlopeToDefault(ViSession instrSession,
                                                  ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    checkErr(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_ILS_GS_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains the carrier frequency settings for ILS Glide Slope component.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR carrierFrequencyMode/Sets the mode for the carrier frequency of the signal.
/// HIPAR carrierFrequency/Sets the carrier frequency of the signal.
/// HIPAR icaoChannel/Sets the ICAO channel and the corresponding transmitting frequency.
/// HIPAR extAM/Sets the modulation source for the avionic standard modulation.
ViStatus _VI_FUNC rssmx_ConfigureILSGlideSlopeCarrierFrequencySettings(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   carrierFrequencyMode,
                            ViReal64  carrierFrequency,
                            ViInt32   icaoChannel,
                            ViInt32   extAM)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_GS_CARRIER_FREQUENCY_MODE, carrierFrequencyMode),
            3, "Carrier Frequency Mode");

    if (carrierFrequencyMode == RSSMX_VAL_ILS_GS_FREQ_MODE_USER)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_GS_CARRIER_FREQUENCY, carrierFrequency),
                4, "Carrier Frequency");
    }

    else
    {
        viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_GS_ICAO_CHANNEL, icaoChannel),
                5, "ICAO Channel");
    }

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_GS_EXT_AM, extAM),
            6, "EXT AM");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates synchronization of the ILS glide slope with the ILS localizer carrier frequency.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR syncwithLocalizer/Activates synchronization of the ILS localizer ICAO channel with the
/// HIPAR syncwithLocalizer/ILS glide slope ICAO channel.
ViStatus _VI_FUNC rssmx_ConfigureILSGlideSlopeSyncWithLocalizer(
                            ViSession instrSession,
                            ViInt32   path,
                            ViBoolean syncwithLocalizer)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_ILS_GS_SYNC_WITH_LOCALIZER, syncwithLocalizer),
            3, "Sync with Localizer");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains modulation signal settings related to the ILS glide slope
/// HIFN  component of the ILS signal.
/// HIFN
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR operatingMode/Sets the operating mode for the ILS glide slope modulation signal.
/// HIPAR ddmPolarity/Sets the polarity for DDM calculation (see
/// HIPAR ddmPolarity/[:SOURce<hw>]:ILS[:GS|GSLope]:DDM[:DEPTh]).
/// HIPAR frequencyType/Selects the frequency type.
/// HIPAR frequency/Sets the modulation frequency of the upper or lower antenna lobe.
/// HIPAR up/downPhase/Sets the phase between the modulation signals of the upper and lower
/// HIPAR up/downPhase/antenna lobe of the ILS glide slope signal.
ViStatus _VI_FUNC rssmx_ConfigureILSGlideSlopeSignalSettings(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   operatingMode,
                                                             ViInt32   ddmPolarity,
                                                             ViInt32   frequencyType,
                                                             ViReal64  frequency,
                                                             ViReal64  updownPhase)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr   attr[] = {RSSMX_ATTR_ILS_GS_UP_FREQUENCY, RSSMX_ATTR_ILS_GS_DOWN_FREQUENCY};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_GS_OPERATING_MODE, operatingMode),
            3, "Operating Mode");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_GS_DDM_POLARITY, ddmPolarity),
            4, "DDM Polarity");

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, frequencyType, RSSMX_VAL_UP, RSSMX_VAL_DOWN),
            5, "Frequency Type");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, attr[frequencyType], frequency),
            6, "Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_GS_UPDOWN_PHASE, updownPhase),
            7, "Up/Down Phase");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains amplitude settings related to the ILS glide slope component
/// HIFN  of the ILS signal.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR flyMode/Sets the simulation mode for the ILS glide slope modulation signal. A
/// HIPAR flyMode/change of the setting automatically changes the sign of the DDM value.
/// HIPAR sumofDepth/Sets the arithmetic sum of the modulation depths of the upper lobe (90
/// HIPAR sumofDepth/Hz) and lower lobe (150 Hz) for the ILS glide slope signal contents.
/// HIPAR ddmCoupling/Selects if the DDM value is fixed or is changed with a change of sum
/// HIPAR ddmCoupling/of modulation depths (SDM, see [:SOURce<hw>]:ILS[:GS|GSLope]:SDM).
/// HIPAR ddmStep/Sets the variation of the difference in depth of modulation via the
/// HIPAR ddmStep/rotary knob.
ViStatus _VI_FUNC rssmx_ConfigureILSGlideSlopeAmplitude(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   flyMode,
                                                        ViReal64  sumofDepth,
                                                        ViInt32   ddmCoupling,
                                                        ViInt32   ddmStep)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_GS_DDM_COUPLING, ddmCoupling),
            5, "DDM Coupling");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_GS_SUM_OF_DEPTH, sumofDepth),
            4, "Sum of Depth");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_GS_DDM_STEP, ddmStep),
            6, "DDM Step");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_GS_FLY_MODE, flyMode),
            3, "Fly Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the DDM value.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR ddmType/Selects the DDM type.
/// HIPAR ddmValue/Sets the DDM value.
ViStatus _VI_FUNC rssmx_ConfigureILSGlideSlopeAmplitudeDDMValue(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   ddmType,
                            ViReal64  ddmValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr   attr[] = {RSSMX_ATTR_ILS_GS_DDM_CURRENT, RSSMX_ATTR_ILS_GS_DDM_DEPTH, RSSMX_ATTR_ILS_GS_DDM_LOGARITHMIC, RSSMX_ATTR_ILS_GS_DDM_PERCENT};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, ddmType, RSSMX_VAL_ILS_AMPLITUDE_CURRENT, RSSMX_VAL_ILS_AMPLITUDE_PERCENT),
            3, "DDM Type");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, attr[ddmType], ddmValue),
            4, "DDM Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the parameters of the ILS localizer component to their default
/// HIFN  values (*RST values specified for the commands).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
ViStatus _VI_FUNC rssmx_SetILSLocalizerToDefault(ViSession instrSession,
                                                 ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    checkErr(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains settings for carrier frequency of the signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR carrierFrequencyMode/Sets the mode for the carrier frequency of the signal.
/// HIPAR carrierFrequency/Sets the carrier frequency of the signal.
/// HIPAR icaoChannel/Sets the ICAO channel and the corresponding transmitting frequency.
/// HIPAR extAM/Sets the modulation source for the avionic standard modulation.
ViStatus _VI_FUNC rssmx_ConfigureILSLocalizerCarrierFrequencySettings(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   carrierFrequencyMode,
                            ViReal64  carrierFrequency,
                            ViInt32   icaoChannel,
                            ViInt32   extAM)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_CARRIER_FREQUENCY_MODE, carrierFrequencyMode),
            3, "Carrier Frequency Mode");

    if (carrierFrequencyMode == RSSMX_VAL_ILS_LOCALIZER_FREQ_MODE_USER)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_CARRIER_FREQUENCY, carrierFrequency),
                4, "Carrier Frequency");
    }
    else
    {
        viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_ICAO_CHANNEL, icaoChannel),
                5, "ICAO Channel");
    }

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_EXT_AM, extAM),
            6, "EXT AM");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates synchronization of the ILS glide slope with the ILS localizer carrier frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR syncwithGlideSlope/Activates synchronization of the ILS localizer ICAO channel with the
/// HIPAR syncwithGlideSlope/ILS glide slope ICAO channel.
ViStatus _VI_FUNC rssmx_ConfigureILSLocalizerSyncWithGlideSlope(
                            ViSession instrSession,
                            ViInt32   path,
                            ViBoolean syncwithGlideSlope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_SYNC_WITH_GS, syncwithGlideSlope),
            3, "Sync with Glide Slope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains  modulation signal settings related to the ILS localizer
/// HIFN  component of the ILS signal.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR operatingMode/Sets the operating mode for the ILS localizer modulation signal.
/// HIPAR ddmPolarity/Sets the polarity for DDM calculation (see
/// HIPAR ddmPolarity/[:SOURce<hw>]:ILS:LOCalizer:DDM[:DEPTh]).
/// HIPAR frequencyType/Selects the frequency type.
/// HIPAR frequency/Sets the modulation frequency of the antenna lobe arranged at the left
/// HIPAR frequency/or right viewed from the air plane.
/// HIPAR left/rightPhase/Sets the phase between the modulation signals of the left and right
/// HIPAR left/rightPhase/antenna lobe of the ILS localizer signal.The zero crossing of the right
/// HIPAR left/rightPhase/lobe (150Hz) signal serves as a reference. The angle refers to the
/// HIPAR left/rightPhase/period of the signal of the right antenna lobe.
ViStatus _VI_FUNC rssmx_ConfigureILSLocalizerSignalSettings(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   operatingMode,
                                                            ViInt32   ddmPolarity,
                                                            ViInt32   frequencyType,
                                                            ViReal64  frequency,
                                                            ViReal64  leftrightPhase)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr   attr[] = {RSSMX_ATTR_ILS_LOCALIZER_LEFT_FREQUENCY, RSSMX_ATTR_ILS_LOCALIZER_RIGHT_FREQUENCY};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_OPERATING_MODE, operatingMode),
            3, "Operating Mode");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_DDM_POLARITY, ddmPolarity),
            4, "DDM Polarity");

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, frequencyType, RSSMX_VAL_LEFT, RSSMX_VAL_RIGHT),
            5, "Frequency Type");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, attr[frequencyType], frequency),
            6, "Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_LEFT_RIGHT_PHASE, leftrightPhase),
            3, "Left/Right Phase");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains amplitude settings related to the ILS localizer component of
/// HIFN  the ILS signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR flyMode/Sets the simulation mode for the ILS-LOC modulation signal. A change
/// HIPAR flyMode/of the setting automatically changes the sign of the DDM value.
/// HIPAR sumofDepth/Sets the arithmetic sum of the modulation depths of the left lobe (90
/// HIPAR sumofDepth/Hz) and right lobe (150 Hz) for the ILS localizer signal contents.
/// HIPAR ddmCoupling/Selects if the DDM value is fixed or is changed with a change of sum
/// HIPAR ddmCoupling/of modulation depths (SDM, see RSSMX_ATTR_ILS_LOCALIZER_SUM_OF_DEPTH).
/// HIPAR ddmStep/Sets the variation step of the DDM values.
ViStatus _VI_FUNC rssmx_ConfigureILSLocalizerAmplitude(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   flyMode,
                                                       ViReal64  sumofDepth,
                                                       ViInt32   ddmCoupling,
                                                       ViInt32   ddmStep)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_SUM_OF_DEPTH, sumofDepth),
            4, "Sum of Depth");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_DDM_COUPLING, ddmCoupling),
            5, "DDM Coupling");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_DDM_STEP, ddmStep),
            6, "DDM Step");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_FLY_MODE, flyMode),
            3, "Fly Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the DDM value.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR ddmType/Selects the DDM type.
/// HIPAR ddmValue/Sets the DDM value.
ViStatus _VI_FUNC rssmx_ConfigureILSLocalizerAmplitudeDDMValue(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   ddmType,
                            ViReal64  ddmValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr   attr[] = {RSSMX_ATTR_ILS_LOCALIZER_DDM_CURRENT, RSSMX_ATTR_ILS_LOCALIZER_DDM_DEPTH, RSSMX_ATTR_ILS_LOCALIZER_DDM_LOGARITHMIC, RSSMX_ATTR_ILS_LOCALIZER_DDM_PERCENT};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, ddmType, RSSMX_VAL_ILS_AMPLITUDE_CURRENT, RSSMX_VAL_ILS_AMPLITUDE_PERCENT),
            3, "DDM Type");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, attr[ddmType], ddmValue),
            4, "DDM Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains COM/ID settings related to the ILS localizer component of the
/// HIFN  ILS signal.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR com/idState/Enables/disables the COM/ID signal.
/// HIPAR code/Sets the coding of the COM/ID signal by the international short name
/// HIPAR code/of the airport (e.g. MUC for the Munich airport).
/// HIPAR period/Sets the period of the COM/ID signal.
/// HIPAR frequency/Sets the frequency of the COM/ID signal.
/// HIPAR depth/Sets the AM modulation depth of the COM/ID signal.
ViStatus _VI_FUNC rssmx_ConfigureILSLocalizerCOMID(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViBoolean comidState,
                                                   ViString  code,
                                                   ViReal64  period,
                                                   ViReal64  frequency,
                                                   ViReal64  depth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_COMID_STATE, comidState),
            3, "COM/ID State");

    viCheckParm(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_CODE, code),
            4, "Code");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_PERIOD, period),
            5, "Period");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_FREQUENCY, frequency),
            6, "Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_DEPTH, depth),
            7, "Depth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains the setting for time schema of the Morse code for the COM/ID
/// HIFN  signal.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR timeSchema/Sets the time schema of the Morse code for the COM/ID signal.
/// HIPAR dotLength/Sets the length of a Morse code dot.
/// HIPAR dashLength/Sets the length of a Morse code dash.
/// HIPAR symbolSpace/Sets the length of the Morse code symbol space.
/// HIPAR letterSpace/Sets the length of a Morse code letter space.
ViStatus _VI_FUNC rssmx_ConfigureILSLocalizerCOMIDTimeSchema(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   timeSchema,
                                                             ViReal64  dotLength,
                                                             ViReal64  dashLength,
                                                             ViReal64  symbolSpace,
                                                             ViReal64  letterSpace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_TIME_SCHEMA, timeSchema),
            3, "Time Schema");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_DOT_LENGTH, dotLength),
            4, "Dot Length");

    if (timeSchema == RSSMX_VAL_ILS_LOCALIZER_TIME_SCHEMA_USER)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_DASH_LENGTH, dashLength),
                5, "Dash Length");

        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_SYMBOL_SPACE, symbolSpace),
                6, "Symbol Space");

        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_LOCALIZER_LETTER_SPACE, letterSpace),
                7, "Letter Space");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the parameters of the ILS marker beacons component to their
/// HIFN  default values (*RST values specified for the commands).
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
ViStatus _VI_FUNC rssmx_SetILSMarkerBeaconsToDefault(ViSession instrSession,
                                                     ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    checkErr(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_ILS_MB_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains the carrier frequency settings forthe ILS marker beacon
/// HIFN  signal.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR carrierFrequencyMode/Sets the carrier frequency mode of the ILS marker beacon signal.
/// HIPAR carrierFrequency/Sets the carrier frequency for the ILS marker beacon signal.
ViStatus _VI_FUNC rssmx_ConfigureILSMarkerBeaconsCarrierFrequencySettings(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   carrierFrequencyMode,
                            ViReal64  carrierFrequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_MB_CARRIER_FREQUENCY_MODE, carrierFrequencyMode),
            3, "Carrier Frequency Mode");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_MB_CARRIER_FREQUENCY, carrierFrequency),
            4, "Carrier Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains signal settings related to the ILS marker beacons component
/// HIFN  of the ILS signal.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR markerFrequency/Sets the modulation frequency of the marker signal for the ILS marker
/// HIPAR markerFrequency/beacon modulation signal.
/// HIPAR markerDepth/Sets the modulation depth of the marker signal for the ILS marker
/// HIPAR markerDepth/beacon signal.
/// HIPAR pulsedMarker/Activates the modulation of a pulsed marker signal (morse coding).
ViStatus _VI_FUNC rssmx_ConfigureILSMarkerBeaconsSignalSettings(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   markerFrequency,
                            ViReal64  markerDepth,
                            ViBoolean pulsedMarker)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_MB_MARKER_FREQUENCY, markerFrequency),
            3, "Marker Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_MB_MARKER_DEPTH, markerDepth),
            4, "Marker Depth");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_ILS_MB_PULSED_MARKER, pulsedMarker),
            5, "Pulsed Marker");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains general COM/ID settings of the marker beacons component of
/// HIFN  the ILS signal.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR com/idState/Enables/disables the COM/ID signal.
/// HIPAR code/Sets the coding of the COM/ID signal by the international short name
/// HIPAR code/of the airport (e.g. MUC for the Munich airport).The COM/ID tone is
/// HIPAR code/sent according to the selected code, see 'Morse Code Settings'.
/// HIPAR period/Sets the period of the COM/ID signal.
/// HIPAR frequency/Sets the frequency of the COM/ID signal.
/// HIPAR depth/Sets the AM modulation depth of the COM/ID signal.
ViStatus _VI_FUNC rssmx_ConfigureILSMarkerBeaconsCOMID(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViBoolean comidState,
                                                       ViString  code,
                                                       ViReal64  period,
                                                       ViReal64  frequency,
                                                       ViReal64  depth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_ILS_MB_COMID_STATE, comidState),
            3, "COM/ID State");

    viCheckParm(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_ILS_MB_CODE, code),
            4, "Code");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_MB_PERIOD, period),
            5, "Period");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_MB_FREQUENCY, frequency),
            6, "Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_MB_DEPTH, depth),
            7, "Depth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains settings for the time schema of the Morse code for the COM/ID
/// HIFN  signal.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR timeSchema/Sets the time schema of the Morse code for the COM/ID signal.
/// HIPAR dotLength/Sets the length of a Morse code dot.
/// HIPAR dashLength/Sets the length of a Morse code dash.
/// HIPAR symbolSpace/Sets the length of the Morse code symbol space.
/// HIPAR letterSpace/Sets the length of a Morse code letter space.

ViStatus _VI_FUNC rssmx_ConfigureILSMarkerBeaconsCOMIDTimeSchema(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   timeSchema,
                            ViReal64  dotLength,
                            ViReal64  dashLength,
                            ViReal64  symbolSpace,
                            ViReal64  letterSpace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ILS_MB_TIME_SCHEMA, timeSchema),
            3, "Time Schema");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_MB_DOT_LENGTH, dotLength),
            4, "Dot Length");

    if (timeSchema == RSSMX_VAL_ILS_MB_TIME_SCHEMA_USER)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_MB_DASH_LENGTH, dashLength),
                5, "Dash Length");

        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_MB_SYMBOL_SPACE, symbolSpace),
                6, "Symbol Space");

        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ILS_MB_LETTER_SPACE, letterSpace),
                7, "Letter Space");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates/deactivates the ADF modulation.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR adfEnabled/Activates/deactivates the ADF modulation.
ViStatus _VI_FUNC rssmx_ConfigureADFEnabled(ViSession instrSession,
                                            ViInt32   path,
                                            ViBoolean adfEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_ADF_ENABLED, adfEnabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the parameters of the digital standard to their default values
/// HIFN  (*RST values specified for the commands).
/// HIFN
/// HIFN     Not affected is the state set with the command rssmx_ADFEnabled
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_SetADFToDefault(ViSession instrSession,
                                        ViInt32   path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    checkErr(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_ADF_SET_TO_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the files with settings in the default directory. Listed are
/// HIFN  files with the file extension *.adf/*.ils/*.vor.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Size of array passed to 'Settings Catalog'.
/// HIPAR settingsCatalog/Returns a string of filenames separated by commas.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is
/// HIPAR bytesRead/larger then 'Array Size', then the response stored in 'Settings
/// HIPAR bytesRead/Catalog' is not complete. Resize 'Settings Catalog' array to accomodate
/// HIPAR bytesRead/all values and call into the function again.
ViStatus _VI_FUNC rssmx_QueryADFSettingsCatalog(ViSession instrSession,
                                                ViInt32   path,
                                                ViUInt32  arraySize,
                                                ViChar    settingsCatalog[],
                                                ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, 2),
            2, "Path");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SOUR%ld:ADF:SETT:CAT?", path);
    checkErr(rssmx_QueryCatalog(instrSession, cmd, arraySize, settingsCatalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the selected file from the default or the specified directory.
/// HIFN  Deleted are files with extension *.adf/*.ils/*.vor.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR action/Sets the action with selected file.
/// HIPAR filename/The filename of the settings file to be deleted, loaded or saved.
ViStatus _VI_FUNC rssmx_ManageADFSettings(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   action,
                                          ViString  filename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr   attr[] = {RSSMX_ATTR_ADF_DELETE_SETTINGS, RSSMX_ATTR_ADF_RECALL_SETTINGS, RSSMX_ATTR_ADF_SAVE_SETTINGS};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, action, RSSMX_VAL_FILE_ACTION_DELETE, RSSMX_VAL_FILE_ACTION_SAVE),
            3, "Action");

    viCheckParm(rssmx_SetAttributeViString(instrSession, repCap, attr[action], filename),
            4, "Filename");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains general COM/ID settings of the marker beacons component of
/// HIFN  the ADF signal.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR com/idState/Enables/disables the COM/ID signal.
/// HIPAR code/Sets the coding of the COM/ID signal by the international short name
/// HIPAR code/of the airport (e.g. MUC for the Munich airport).
/// HIPAR period/Sets the period of the COM/ID signal.
/// HIPAR frequency/Sets the frequency of the COM/ID signal.
/// HIPAR depth/Sets the AM modulation depth of the COM/ID signal.
ViStatus _VI_FUNC rssmx_ConfigureADFCOMID(ViSession instrSession,
                                          ViInt32   path,
                                          ViBoolean comidState,
                                          ViString  code,
                                          ViReal64  period,
                                          ViReal64  frequency,
                                          ViReal64  depth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_ADF_COM_ID_ENABLED, comidState),
            3, "COM/ID Enabled");

    viCheckParm(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_ADF_CODE, code),
            4, "Code");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ADF_PERIOD, period),
            5, "Period");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ADF_FREQUENCY, frequency),
            6, "Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ADF_DEPTH, depth),
            7, "Depth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Contains settings for the time schema of the Morse code for the COM/ID
/// HIFN  signal.

/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR tmeSchema/Sets the time schema of the Morse code for the COM/ID signal.
/// HIPAR dotLength/Sets the length of a Morse code dot.
/// HIPAR dashLength/Sets the length of a Morse code dash.
/// HIPAR symbolSpace/Sets the length of the Morse code symbol space.
/// HIPAR letterSpace/Sets the length of a Morse code letter space.
ViStatus _VI_FUNC rssmx_ConfigureADFCOMIDTimeSchema(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   timeSchema,
                                                    ViReal64  dotLength,
                                                    ViReal64  dashLength,
                                                    ViReal64  symbolSpace,
                                                    ViReal64  letterSpace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_pathRepCap(instrSession, path, repCap));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_ADF_TIME_SCHEMA, timeSchema),
            3, "Time Schema");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ADF_DOT_LENGTH, dotLength),
            4, "Dot Length");

    if (timeSchema == RSSMX_VAL_ADF_TIME_SCHEMA_USER)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ADF_DASH_LENGTH, dashLength),
                5, "Dash Length");

        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ADF_SYMBOL_SPACE, symbolSpace),
                6, "Symbol Space");

        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_ADF_LETTER_SPACE, letterSpace),
                7, "Letter Space");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects between internal and external reference
/// HIFN      frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR source/This function selects between internal and external reference frequency.
ViStatus _VI_FUNC rssmx_ConfigureReferenceOscillatorSource(ViSession instrSession,
                                                           ViInt32   source)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_REFERENCE_OSCILLATOR_SOURCE, source),
            2, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Determines if the RF output is switched off in case of a missing
/// HIFN      external reference signal for selection external source. If enabled,
/// HIFN      this setting ensures that no improper RF signal due to the missing
/// HIFN      external reference signal is output and used for measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.The handle identifies a particular instrument session.
/// HIPAR rfSwitchOffActive/Determines if the RF output is switched off in case of a missing external reference signal for selection external source. If enabled, this setting ensures that no improper RF signal due to the missing external reference signal is output and used for measurements.
ViStatus _VI_FUNC rssmx_ConfigureReferenceOscillatorRFSwitchOffActive(
                            ViSession instrSession,
                            ViBoolean rfSwitchOffActive)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_REFERENCE_OSCILLATOR_RF_SWITCH_OFF_ACTIVE, rfSwitchOffActive),
            2, "RF Switch Off Active");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the reference oscillator external frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR externalFrequency/Queries the instrument of the frequency of the external reference.
/// HIPAR userDefinedExternalFrequency/Specifies the user-defined external reference frequency. This parameter is valid only for 'External Frequency' == 'Variable'.
ViStatus _VI_FUNC rssmx_ConfigureReferenceOscillatorExternalFrequency(
                            ViSession instrSession,
                            ViInt32   externalFrequency,
                            ViReal64  userDefinedExternalFrequency)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_REFERENCE_OSCILLATOR_EXTERNAL_FREQUENCY, externalFrequency),
            2, "External Frequency");

    if (externalFrequency == RSSMX_VAL_SMU_ROSC_EXTERNAL_FREQUENCY_VAR)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_REFERENCE_OSCILLATOR_USER_DEFINED_EXTERNAL_FREQUENCY, userDefinedExternalFrequency),
                3, "User Defined External Frequency");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the synchronization bandwidth for an external reference
/// HIFN      signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.The handle identifies a particular instrument session.
/// HIPAR synchronizationBandwidth/Selects the synchronization bandwidth for an external reference signal.
ViStatus _VI_FUNC rssmx_ConfigureReferenceOscillatorSynchronizationBandwidth(
                            ViSession instrSession,
                            ViInt32   synchronizationBandwidth)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_REFERENCE_OSCILLATOR_SYNCHRONIZATION_BANDWIDTH, synchronizationBandwidth),
            2, "Synchronization Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the nominal synchronization bandwidth for the selected
/// HIFN  external reference frequency and synchronization bandwidth.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Size of array passed to 'Device'.
/// HIPAR nominalSyncBandwidth/Queries the nominal synchronization bandwidth for the selected
/// HIPAR nominalSyncBandwidth/external reference frequency and synchronization bandwidth.
ViStatus _VI_FUNC rssmx_QueryReferenceOscillatorNominalSynchronizationBandwidth(
                            ViSession instrSession,
                            ViUInt32  arraySize,
                            ViChar    nominalSyncBandwidth[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_GetAttributeViString(instrSession, NULL, RSSMX_ATTR_REFERENCE_OSCILLATOR_NOMINAL_SYNCHRONIZATION_BANDWIDTH,
            arraySize, nominalSyncBandwidth),
            3, "Nominal Sync Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configure the EFC (external frequency control).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.The handle identifies a particular instrument session.
/// HIPAR enabled/Activates the EFC (external frequency control).
/// HIPAR voltageTuningSensitivity/Sets the sensitivity of the external tuning volatge.
ViStatus _VI_FUNC rssmx_ConfigureReferenceOscillatorEFC(ViSession instrSession,
                                                        ViBoolean enabled,
                                                        ViInt32   voltageTuningSensitivity)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_REFERENCE_OSCILLATOR_EFC_ENABLED, enabled),
            2, "Enabled");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_REFERENCE_OSCILLATOR_VOLTAGE_TUNING_SENSITIVITY, voltageTuningSensitivity),
            3, "Voltage Tuning Sensitivity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the reference oscillator output frequency mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.The handle identifies a particular instrument session.
/// HIPAR outputFrequencyMode/Sets the reference oscillator output frequency mode.
ViStatus _VI_FUNC rssmx_ConfigureReferenceOscillatorOutputFrequencyMode(
                            ViSession instrSession,
                            ViInt32   outputFrequencyMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_REFERENCE_OSCILLATOR_OUTPUT_FREQUENCY_MODE, outputFrequencyMode),
            2, "Output Frequency Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the output reference frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.The handle identifies a particular instrument session.
/// HIPAR outputReferenceFrequency/Sets the output reference frequency.
ViStatus _VI_FUNC rssmx_ConfigureReferenceOscillatorOutputReferenceFrequency(
                            ViSession instrSession,
                            ViInt32   outputReferenceFrequency)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_REFERENCE_OSCILLATOR_OUTPUT_REFERENCE_FREQUENCY, outputReferenceFrequency),
            2, "Output Reference Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures adjustment settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.The handle identifies a particular instrument session.
/// HIPAR active/Determines whether the calibrated (OFF) or a user-defined (ON) adjustment value is used for fine adjustment of the frequency. With STATe ON, the instrument is no longer in the calibrated state.
/// HIPAR adjustmentDACFrequency/Specifies the frequency correction value (adjustment value).
ViStatus _VI_FUNC rssmx_ConfigureReferenceOscillatorAdjustmentDAC(
                            ViSession instrSession,
                            ViBoolean active,
                            ViReal64  adjustmentDACFrequency)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_REFERENCE_OSCILLATOR_ADJUSTMENT_DAC_ACTIVE, active),
            2, "Active");
    if (active)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_REFERENCE_OSCILLATOR_ADJUSTMENT_DAC_FREQUENCY, adjustmentDACFrequency),
                3, "Adjustment DAC Frequency");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the minimum locking range for the selected external reference
/// HIFN  frequency.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Size of array passed to 'Device'.
/// HIPAR minimumLockingRange/Queries the minimum locking range for the selected external reference
/// HIPAR minimumLockingRange/frequency.
ViStatus _VI_FUNC rssmx_QueryReferenceOscillatorMinimumLockingRange(
                            ViSession instrSession,
                            ViUInt32  arraySize,
                            ViChar    minimumLockingRange[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_GetAttributeViString(instrSession, NULL,
        RSSMX_ATTR_REFERENCE_OSCILLATOR_MINIMUM_LOCKING_RANGE, arraySize, minimumLockingRange));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Resets the reference oscillator settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_ReferenceOscillatorPreset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_REFERENCE_OSCILLATOR_PRESET, NULL),
            2, "Reference Oscillator Preset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the clock synthesis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR state/Activates the clock synthesis.
ViStatus _VI_FUNC rssmx_ConfigureClockSynthesisState(ViSession instrSession,
                                                     ViBoolean state)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_CLOCK_SYNTHESIS_ENABLED, state),
            2, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the generated clock signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR outputType/Defines the shape of the generated clock signal.
/// HIPAR frequency/Sets the frequency of the generated clock signal.
/// HIPAR level/Sets the power level of the generated clock signal.
/// HIPAR voltage/Sets the voltage for the CMOS signal.
/// HIPAR deltaPhase/Shifts the phase of the generated clock signal.
ViStatus _VI_FUNC rssmx_ConfigureClockSynthesisOutputSignal(ViSession instrSession,
                                                            ViInt32   outputType,
                                                            ViReal64  frequency,
                                                            ViReal64  level,
                                                            ViReal64  voltage,
                                                            ViReal64  deltaPhase)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_CLOCK_SYNTHESIS_OUTPUT_TYPE, outputType),
            2, "Output Type");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_CLOCK_SYNTHESIS_FREQUENCY, frequency),
            3, "Frequency");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_CLOCK_SYNTHESIS_POWER, level),
            4, "Level");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_CLOCK_SYNTHESIS_VOLTAGE, voltage),
            5, "Voltage");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_CLOCK_SYNTHESIS_PHASE, deltaPhase),
            6, "Delta Phase");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures DC offset.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR dcOffsetState/Activates a DC offset.
/// HIPAR clockSynthesisDCOffset/Sets the value of the DC offset.
ViStatus _VI_FUNC rssmx_ConfigureClockSynthesisDCOffsetState(ViSession instrSession,
                                                             ViBoolean dcOffsetState,
                                                             ViReal64  clockSynthesisDCOffset)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_CLOCK_SYNTHESIS_DC_OFFSET_STATE, dcOffsetState),
            2, "DC Offset State");
    if (dcOffsetState)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_CLOCK_SYNTHESIS_DC_OFFSET, clockSynthesisDCOffset),
                3, "Clock Synthesis DC Offset");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Resets the delta phase value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_ClockSynthesisResetDeltaPhaseValue(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_CLOCK_SYNTHESIS_RESET_DELTA_PHASE_VALUE, NULL),
            2, "Clock Synthesis Reset Delta Phase Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures power viewer display settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR displayPermanent/Switches on and off  the permanent indication of the power measurement result in the upper right corner of the block diagram. For each sensor, the type of sensor, the connector, the measurement source and - if set - the offset is indicated.
/// HIPAR display/Selects average or peak power for permanent display.
ViStatus _VI_FUNC rssmx_ConfigurePowerDisplay(ViSession instrSession,
                                              ViInt32   sensor,
                                              ViBoolean displayPermanent,
                                              ViInt32   display)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");
    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_DISPLAY_PERMANENT_ENABLED, displayPermanent),
            3, "Display Permanent");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_POWER_DISPLAY_PERMANENT, display),
            4, "Display");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the RF frequency of the source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR useFrequencyOf/Determines the signal to be measured.
/// HIPAR frequency/Sets the RF frequency of the source if the user source is selected.
ViStatus _VI_FUNC rssmx_ConfigurePowerFrequency(ViSession instrSession,
                                                ViInt32   sensor,
                                                ViInt32   useFrequencyOf,
                                                ViReal64  frequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");
    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_POWER_SOURCE, useFrequencyOf),
            3, "Use Frequency Of");
    if (useFrequencyOf == RSSMX_VAL_SENSE_POWER_SOURCE_USER)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_FREQUENCY, frequency),
                4, "Frequency");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures offset value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR offsetEnabled/Activates/deactivates the addition of  the level offset to the measured value. The level offset value is set with command SENSe[:POWer]:OFFSet.
/// HIPAR offset/Sets a level offset which is added to the measured level value after activation with command SENSe[:POWer]:OFFSet:STATe ON. This allows e.g. an attenuator in the signal path to be taken into account.
ViStatus _VI_FUNC rssmx_ConfigurePowerLevelOffset(ViSession instrSession,
                                                  ViInt32   sensor,
                                                  ViBoolean offsetEnabled,
                                                  ViReal64  offset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_OFFSET_ENABLED, offsetEnabled),
            3, "Offset Enabled");
    if (offsetEnabled)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_OFFSET, offset),
                4, "Offset");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures aperture time settings of the respective sensor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR defaultApertureTimeEnabled/Deactivates the default aperture time of the respective sensor.
/// HIPAR apertureTime/Defines the aperture time (size of the acquisition interval) for the corresponding sensor.
ViStatus _VI_FUNC rssmx_ConfigurePowerApertureTime(ViSession instrSession,
                                                   ViInt32   sensor,
                                                   ViBoolean defaultApertureTimeEnabled,
                                                   ViReal64  apertureTime)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_DEFAULT_APERTURE_TIME_ENABLED, defaultApertureTimeEnabled),
            3, "Default Aperture Time Enabled");
    if (defaultApertureTimeEnabled == VI_FALSE)
    {
        viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_APERTURE_TIME, apertureTime),
                4, "Aperture Time");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates/deactivates the use of the s-parameters correction data of
/// HIFN      the connected power sensor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR sParameter/Activates/deactivates the use of the s-parameters correction data of the connected power sensor.
ViStatus _VI_FUNC rssmx_ConfigurePowerUseSParameter(ViSession instrSession,
                                                    ViInt32   sensor,
                                                    ViBoolean sParameter)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_USE_SPARAMETERS, sParameter),
            3, "SParameters");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Several S-parameter tables can be stored in a sensor. The property
/// HIFN      selects a loaded data set for S-parameter correction for the
/// HIFN      corresponding sensor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR sParameterDataSet/Several S-parameter tables can be stored in a sensor. The property selects a loaded data set for S-parameter correction for the corresponding sensor.
ViStatus _VI_FUNC rssmx_ConfigurePowerSParameterDataSet(ViSession instrSession,
                                                        ViInt32   sensor,
                                                        ViReal64  sParameterDataSet)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_S_PARAMETER_DATA_SET, sParameterDataSet),
            3, "S Parameter Data Set");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the list of the S-parameter data sets that have been loaded to
/// HIFN      the power sensor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR arraySize/Size of array passed to 'S Parameter Data Set List'.
/// HIPAR sParameterDataSetList/Queries the list of the S-parameter data sets that have been loaded to the power sensor.
ViStatus _VI_FUNC rssmx_QueryPowerSParameterDataSetList(ViSession instrSession,
                                                        ViInt32   sensor,
                                                        ViUInt32  arraySize,
                                                        ViChar    sParameterDataSetList[],
                                                        ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sensor, 1, 4),
            2, "Sensor");
    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SENS%ld:CORR:SPD:LIST?", sensor);
    checkErr(rssmx_QueryCatalog(instrSession, cmd, arraySize, sParameterDataSetList, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the recording of the power values, measured by a connected
/// HIFN      R&S NRP power sensor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR state/Activates the recording of the power values, measured by a connected R&S NRP power sensor.
ViStatus _VI_FUNC rssmx_ConfigurePowerLoggingState(ViSession instrSession,
                                                   ViInt32   sensor,
                                                   ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_LOGGING_STATE, state),
            3, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the unit used for result query with command READ. The power
/// HIFN      sensor provides the measured value in Watt. In which unit the measured
/// HIFN      value is returned is selected here and might be either Watt, dBm or
/// HIFN      dBuV.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR powerUnit/Selects the unit used for result query with command READ. The power sensor provides the measured value in Watt. In which unit the measured value is returned is selected here and might be either Watt, dBm or dBuV.
ViStatus _VI_FUNC rssmx_ConfigurePowerUnit(ViSession instrSession,
                                           ViInt32   sensor,
                                           ViInt32   powerUnit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");
    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_POWER_UNIT, powerUnit),
            3, "Power Unit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates/deactivates the continuous power measurement by the R&S NRP
/// HIFN      power sensors.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR continuous/Activates/deactivates the continuous power measurement by the R&S NRP
/// HIFN      power sensors.
ViStatus _VI_FUNC rssmx_PowerContinuous(ViSession instrSession,
                                        ViInt32   sensor,
                                        ViBoolean continuous)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_CONTINUOUS, continuous),
            3, "Continuous");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  retrieves the power measurement result of the selected power sensor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR power/retrieves the power measurement result of the selected power sensor.
ViStatus _VI_FUNC rssmx_ReadPower(ViSession instrSession,
                                  ViInt32   sensor,
                                  ViReal64* power)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_READ_POWER, power),
            3, "Power");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the autozero function. Zeroing is required in regular
/// HIFN      interval (at least once a day)and if the temperature has varied more
/// HIFN      than about 5 C, if the sensor has been replaced or if measurements of
/// HIFN      signals with very low power are to be performed. The sensor must be
/// HIFN      disconnected from all power sources before starting the autozero
/// HIFN      function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
ViStatus _VI_FUNC rssmx_ZeroPower(ViSession instrSession,
                                  ViInt32   sensor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_POWER_ZERO, NULL),
            3, "Power Zero");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the filter mode. The filter length is the multiplier for the
/// HIFN      time window and thus directly influences the measurement time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function.The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR powerFilterMode/Selects the filter mode. The filter length is the multiplier for the time window and thus directly influences the measurement time.
ViStatus _VI_FUNC rssmx_ConfigurePowerFilterMode(ViSession instrSession,
                                                 ViInt32   sensor,
                                                 ViInt32   powerFilterMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_POWER_FILTER_MODE, powerFilterMode),
            3, "Power Filter Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the filter length for user filter mode. As the filter length works as
/// HIFN      a multiplier for the time window, a constant filter length results in a
/// HIFN      constant measurement time. Values 1 and 2^n are setable. In remote
/// HIFN      control, when using command READ to retrieve the measurement result,
/// HIFN      the time window is fixed to 20 ms.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR filterLength/Selects the filter length for user filter mode. As the filter length works as a multiplier for the time window, a constant filter length results in a constant measurement time. Values 1 and 2^n are setable. In remote control, when using command READ to retrieve the measurement result, the time window is fixed to 20 ms.
ViStatus _VI_FUNC rssmx_ConfigurePowerFilterLength(ViSession instrSession,
                                                   ViInt32   sensor,
                                                   ViInt32   filterLength)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_POWER_FILTER_LENGTH, filterLength),
            3, "Filter Length");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the noise content for fixed noise filter mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR noiseSignalRatio/Defines the noise content for fixed noise filter mode. This value determines the proportion of intrinsic noise in the measured result.
/// HIPAR noiseSignalRatioTimeout/Defines the timeout for fixed noise filter mode. This value ensures limited settling times.
ViStatus _VI_FUNC rssmx_ConfigurePowerFilterFixedNoise(ViSession instrSession,
                                                       ViInt32   sensor,
                                                       ViReal64  noiseSignalRatio,
                                                       ViReal64  noiseSignalRatioTimeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_FILTER_NS_RATIO, noiseSignalRatio),
            3, "Filter NS Ratio");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_FILTER_NS_RATIO_TIMEOUT, noiseSignalRatioTimeout),
            4, "Filter NS Ratio Timeout");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the search for the optimum filter length for the current
/// HIFN      measurement conditions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
ViStatus _VI_FUNC rssmx_PowerFilterSearchOnce(ViSession instrSession,
                                              ViInt32   sensor,
                                              ViUInt32  maxTime)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  old_tout = 0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_GetOPCTimeout(instrSession, &old_tout));
    checkErr(rssmx_SetOPCTimeout(instrSession, maxTime));
    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_POWER_FILTER_SEARCH_ONCE, NULL),
            3, "Power Filter Search Once");

Error:
    checkErr(rssmx_SetOPCTimeout(instrSession, old_tout));
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries if a sensor is connected at the selected port to the signal
/// HIFN      generator. The sensor is selected by suffix 1, 2 or 3 in key word SENSe
/// HIFN      or READ of the command header. Suffix 1 denotes the sensor connected to
/// HIFN      the SENSOR connector, suffix 2 the sensor connected first to one of the
/// HIFN      USB interfaces and suffix 3 the sensor connected second to one of the
/// HIFN      USB interfaces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR arraySize/Size of array passed to 'Device'.
/// HIPAR device/Queries if a sensor is connected at the selected port to the signal generator.
ViStatus _VI_FUNC rssmx_PowerSensorDevice(ViSession  instrSession,
                                          ViInt32    sensor,
                                          ViBoolean* device)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_GetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_SENSOR_DEVICE, device),
            3, "Power Sensor Device");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the type of sensor connected at the selected port. The type is
/// HIFN      automatically detected.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR arraySize/Size of array passed to 'Sensor Type'.
/// HIPAR sensorType/Queries the type of sensor connected at the selected port. The type is automatically detected.
ViStatus _VI_FUNC rssmx_PowerSensorType(ViSession instrSession,
                                        ViInt32   sensor,
                                        ViUInt32  arraySize,
                                        ViChar    sensorType[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_GetAttributeViString(instrSession, repCap, RSSMX_ATTR_POWER_SENSOR_TYPE,
            arraySize, sensorType),
            3, "Sensor Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the software version of the connected NRP power sensor.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSSMX_ATTR_POWER_SENSOR_VERSION
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     :SENSe<ch>[:POWer]:SVERsion?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR arraySize/Size of array passed to 'Version'.
/// HIPAR version/Queries the software version of the connected NRP power sensor.
ViStatus _VI_FUNC rssmx_PowerSensorVersion(ViSession instrSession,
                                           ViInt32   sensor,
                                           ViUInt32  arraySize,
                                           ViChar    version[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_GetAttributeViString(instrSession, repCap, RSSMX_ATTR_POWER_SENSOR_VERSION,
            arraySize, version),
            3, "Version");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the serial number of the sensor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensor/Selects the sensor.
/// HIPAR arraySize/Size of array passed to 'Serial Number'.
/// HIPAR serialNumber/Queries the serial number of the sensor.
ViStatus _VI_FUNC rssmx_PowerSensorSerialNumber(ViSession instrSession,
                                                ViInt32   sensor,
                                                ViUInt32  arraySize,
                                                ViChar    serialNumber[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SensorRepCap(instrSession, sensor, repCap), 2, "Sensor");

    viCheckParm(rssmx_GetAttributeViString(instrSession, repCap, RSSMX_ATTR_POWER_SENSOR_SERIAL_NUMBER,
            arraySize, serialNumber),
            3, "Serial Number");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Starts the search for R&S NRP power sensors, connected in the LAN or
/// HIFN      via the USBTMC protocol.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR scanEnabled/Starts the search for R&S NRP power sensors, connected in the LAN or via the USBTMC protocol.
ViStatus _VI_FUNC rssmx_ConfigureSensorMappingScan(ViSession instrSession,
                                                   ViBoolean scanEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_POWER_SENSOR_MAPPING_SCAN_ENABLED, scanEnabled),
            2, "Scan Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns a list of all detected sensors in a comma-separated string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Mapping List'.
/// HIPAR mappingList/Returns a list of all detected sensors in a comma-separated string.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is larger then 'Array Size', then the response stored in 'Mapping List' is not complete. Resize 'Mapping List' array to accomodate all values and call into  the function again.
ViStatus _VI_FUNC rssmx_QueryPowerSensorMappingList(ViSession instrSession,
                                                    ViUInt32  arraySize,
                                                    ViChar    mappingList[],
                                                    ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_QueryCatalog(instrSession, ":SLIS?", arraySize, mappingList, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}



/// HIFN  Scans for R&S NRP power sensors connected over a USB interface.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR deviceid/Device ID or Sensor Name, either a string or integer. Range 0 to
/// HIPAR deviceid/999999.
/// HIPAR serial/Serial Number. Range 0 to 999999.
ViStatus _VI_FUNC rssmx_AddPowerSensorMappingUSBSensor(ViSession instrSession,
                                                       ViString  deviceid,
                                                       ViInt32   serial)
{
    ViStatus error = VI_SUCCESS;
    ViChar   connectionString[RS_MAX_MESSAGE_LEN];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, serial, 0),
            3, "Control Label");
    viCheckParm(RsCore_InvalidViInt32RangeMax(instrSession, serial, 999999),
            3, "Control Label");

    (void)snprintf(connectionString, RS_MAX_MESSAGE_LEN, "\"%s\",%ld", deviceid, serial);

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_POWER_SENSOR_MAPPING_ADD_USB_SENSOR, connectionString),
            2, "Device ID");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Scans for R&S NRP power sensors connected in the LAN.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR ipAdress/Scans for R&S NRP power sensors connected in the LAN.
ViStatus _VI_FUNC rssmx_AddPowerSensorMappingLANSensor(ViSession instrSession,
                                                       ViString  ipAdress)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_POWER_SENSOR_MAPPING_ADD_LAN_SENSOR, ipAdress),
            2, "IP Address");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Removes all R&S NRP power sensors connected in the LAN from the list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_RemovePowerSensorMappingLANSensors(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_POWER_SENSOR_MAPPING_REMOVE_LAN_SENSORS, NULL));

    checkErr(RsCore_CheckStatus(instrSession, error));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Removes all R&S NRP power sensors connected over USB from the list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_RemovePowerSensorMappingUSBSensors(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_POWER_SENSOR_MAPPING_REMOVE_USB_SENSORS, NULL));

    checkErr(RsCore_CheckStatus(instrSession, error));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Removes all R&S NRP power sensors from the list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_RemoveAllPowerSensorMappingSensors(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_POWER_SENSOR_MAPPING_REMOVE_ALL, NULL));

    checkErr(RsCore_CheckStatus(instrSession, error));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Assigns an entry from the :SLISt[:LIST]? to one of the four sensor
/// HIFN      channels.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sensorFromList/Sets the sensor number.
/// HIPAR sensorChannel/Sets the Power Sensor Mapping for selected sensor.
ViStatus _VI_FUNC rssmx_ConfigurePowerSensorMapping(ViSession instrSession,
                                                    ViInt32   sensorFromList,
                                                    ViInt32   sensorChannel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sensorChannel, 0, 4),
            3, "Sensor Channel");
    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SLIS:ELEM%ld:MAPP %s", sensorFromList, gs_SensorChannelArr[sensorChannel]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queris the SCPI recording data from the internal file.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     -
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     :SYSTem:SRData?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Data'.
/// HIPAR data/SCPI recording data.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is larger then 'Array Size', then the response stored in 'Data' is not complete. Resize 'Data' array to accomodate all values and call into the function again.
ViStatus _VI_FUNC rssmx_QuerySCPIRecordingData(ViSession instrSession,
                                               ViUInt32  arraySize,
                                               ViChar    data[],
                                               ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_QueryCatalog(instrSession, ":SYST:SRD?", arraySize, data, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the device footprint of the instrument. The retrieved
/// HIFN      information is in machine readable form suitable for automatic further
/// HIFN      processing.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Device Footprint'.
/// HIPAR deviceFootprint/Queries the device footprint of the instrument. The retrieved
/// HIFN      information is in machine readable form suitable for automatic further
/// HIFN      processing.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is larger then 'Array Size', then the response stored in 'Device Footprint' is not complete. Resize 'Device Footprint' array to accomodate all values and call into the function again.
ViStatus _VI_FUNC rssmx_QueryDeviceFootprint(ViSession instrSession,
                                             ViUInt32  arraySize,
                                             ViChar    deviceFootprint[],
                                             ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_QueryCatalog(instrSession, ":SYST:DFPR?", arraySize, deviceFootprint, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
/// HIFN Use the function rscmwgs_GetError afterwards to get the detailed information about the instrument error(s).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoSystErrQuery/If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
ViStatus _VI_FUNC rssmx_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                    ViBoolean autoSystErrQuery)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->autoSystErrQuery = autoSystErrQuery;

Error:
    return error;
}

/// HIFN Session-related mutex switch.
/// HIFN If TRUE (default after init is FALSE), the driver sets a mutual-exclusion mechanism for every driver's hi-level function and attribute access.
/// HIFN Set this value to TRUE if you plan to use one session in more than one thread.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR multiThreadLocking/Session-related mutex switch
ViStatus _VI_FUNC rssmx_ConfigureMultiThreadLocking(ViSession instrSession,
                                                    ViBoolean multiThreadLocking)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->multiThreadLocking = multiThreadLocking;

Error:
    return error;
}

/// HIFN  Sets the image format in which the hard copy should be stored.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR graphicFormat/Sets the image format in which the hard copy should be stored.
/// HIPAR region/Selects the area to be copied.
ViStatus _VI_FUNC rssmx_ConfigureHardCopyImageSettings(ViSession instrSession,
                                                       ViInt32   graphicFormat,
                                                       ViInt32   region)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_HARD_COPY_GRAPHIC_FORMAT, graphicFormat),
            2, "Graphic Format");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_HARD_COPY_REGION, region),
            3, "Region");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Executes the hard copy command to the selected destination.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_HardCopyExecute(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_HARD_COPY_EXECUTE, NULL),
            2, "Hard Copy Execute");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Transfers the hard copy data directly as a NByte stream to the remote
/// HIFN      client.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Data'.
/// HIPAR data/SCPI recording data.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is larger then 'Array Size', then the response stored in 'Data' is not complete. Resize 'Catalog' array to accomodate all values and call into the function again.
ViStatus _VI_FUNC rssmx_QueryHardCopyImage(ViSession instrSession,
                                           ViUInt32  arraySize,
                                           ViChar    data[],
                                           ViUInt32* bytesRead)
{
    ViInt64  bytes_read = 0;
    ViStatus error = VI_SUCCESS;
    ViByte*  ext_buf = NULL;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryBinaryDataBlock(instrSession, "HCOP:DATA?", VI_FALSE, NULL, &ext_buf, &bytes_read));
    checkErr(rssmx_CheckStatus(instrSession));

    checkErr(RsCore_CopyToUserBufferBinData((ViByte*)data, arraySize, (ViBuf)ext_buf, bytes_read));

    *bytesRead = arraySize < (ViUInt32)bytes_read ? arraySize : (ViUInt32)bytes_read;

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures Hard Copy file auto naming.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR autoNamingEnabled/Specifies whether the destination file name of the hard copy command should be automatically generated.
/// HIPAR autoFileDirectory/Automatically defines the destination directory where the hard copy will be saved in. The 'HCopy' directory will be created if not yet existing.
/// HIPAR autoPrefixEnabled/Specifies wether a prefix should be appended to the file name. The prefix is entered via the command HCOP:FILE:NAME:AUTO:PREF.
/// HIPAR prefix/Defines the parameter <Prefix> that is used automatically to the file name of the hard copy. The Prefix is used only, if the state of the prefix is activated.
/// HIPAR day/Defines wether the currrent day should be appended to the file name.
/// HIPAR month/Defines wether the currrent month should be appended to the file name.
/// HIPAR year/Defines wether the currrent year should be appended to the file name.
ViStatus _VI_FUNC rssmx_ConfigureHardCopyAutoNaming(ViSession instrSession,
                                                    ViBoolean autoNamingEnabled,
                                                    ViString  autoFileDirectory,
                                                    ViBoolean autoPrefixEnabled,
                                                    ViString  prefix,
                                                    ViBoolean day,
                                                    ViBoolean month,
                                                    ViBoolean year)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_HARD_COPY_AUTO_NAMING_ENABLED, autoNamingEnabled),
            2, "Auto Naming Enabled");

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_HARD_COPY_AUTO_FILE_DIRECTORY, autoFileDirectory),
            3, "Auto File Directory");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_HARD_COPY_AUTO_PREFIX_ENABLED, autoPrefixEnabled),
            4, "Auto Prefix Enabled");
    if (autoPrefixEnabled)
    {
        viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_HARD_COPY_FILE_NAME_PREFIX, prefix),
                5, "Prefix");
    }
    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_HARD_COPY_DAY_TO_FILE_NAME, day),
            6, "Day");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_HARD_COPY_MONTH_TO_FILE_NAME, month),
            7, "Month");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_HARD_COPY_YEAR_TO_FILE_NAME, year),
            8, "Year");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Determines the file name and path to save the hard copy, provided
/// HIFN      automatic naming is disabled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileName/Determines the file name and path to save the hard copy, provided automatic naming is disabled.
ViStatus _VI_FUNC rssmx_ConfigureHardCopyFileName(ViSession instrSession,
                                                  ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_HARD_COPY_FILE_NAME, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries path and file name of the hardcopy file, if you have enabled
/// HIFN      Automatic Naming.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Generated Auto File Name'.
/// HIPAR generatedAutoFileName/Queries path and file name of the hardcopy file, if you have enabled Automatic Naming.
ViStatus _VI_FUNC rssmx_QueryHardCopyGeneratedAutoFileName(ViSession instrSession,
                                                           ViUInt32  arraySize,
                                                           ViChar    generatedAutoFileName[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_GetAttributeViString(instrSession, NULL, RSSMX_ATTR_HARD_COPY_GENERATED_AUTO_FILE_NAME,
            arraySize, generatedAutoFileName),
            3, "Generated Auto File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the automatically generated file name in which the hard copy
/// HIFN      will be saved in.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR arraySize/Size of array passed to 'Auto File Name'.
/// HIPAR autoFileName/Returns the automatically generated file name in which the hard copy will be saved in.
ViStatus _VI_FUNC rssmx_QueryHardCopyAutoFileName(ViSession instrSession,
                                                  ViUInt32  arraySize,
                                                  ViChar    autoFileName[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_GetAttributeViString(instrSession, NULL, RSSMX_ATTR_HARD_COPY_AUTO_FILE_NAME,
            arraySize, autoFileName),
            3, "Auto File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns a file number of three digits to the automatically generated
/// HIFN      file name of the hard copy.
/// HIFN
/// HIFN     Note:
/// HIFN     On initially switching on the device the number will be reset to the
/// HIFN      lowest possible value. Starting with number 0 the output directory will
/// HIFN      be scanned for already exisiting files. As long as files with the same
/// HIFN      name are existing the number will be increased by 1. The number will be
/// HIFN      automatically set to a number so that the resulting file name will be
/// HIFN      unique within the selected path. The current number will not be saved
/// HIFN      in the save recall file but will be temporarily stored within the
/// HIFN      database. On subsequent saves the number will be increased.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR currentNumber/Returns a file number of three digits to the automatically generated file name of the hard copy.
ViStatus _VI_FUNC rssmx_QueryHardCopyCurrentNumber(ViSession instrSession,
                                                   ViInt32*  currentNumber)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_GetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_HARD_COPY_CURRENT_NUMBER, currentNumber),
            2, "Current Number");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes all image files in the path directory of the hard copy files.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
ViStatus _VI_FUNC rssmx_ClearHardCopyFile(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_CLEAR_HARD_COPY_FILE, NULL),
            2, "Clear Hard Copy File");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Reads out the subdirectories and files in the specified directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR directoryPath/Directory path parameter.
/// HIPAR arraySize/Size of array passed to 'Catalog'.
/// HIPAR catalog/Reads back catalog list.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is larger then 'Array Size', then the response stored in 'Catalog' is not complete. Resize 'Catalog' array to accomodate all values and call into  the function again.
ViStatus _VI_FUNC rssmx_QueryMMEMoryCatalog(ViSession instrSession,
                                            ViString  directoryPath,
                                            ViUInt32  arraySize,
                                            ViChar    catalog[],
                                            ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEM:CAT? '%s'", directoryPath);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rssmx_QueryCatalog(instrSession, cmd, arraySize, catalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Reads out the number of files in the specified directory.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR directoryPath/Directory path parameter.
/// HIPAR catalogLength/Returns the number of files in the specified directory. If no
/// HIFN      directory is specified, the default directory is used.
ViStatus _VI_FUNC rssmx_QueryMMEMoryCatalogLength(ViSession instrSession,
                                                  ViString  directoryPath,
                                                  ViInt32*  catalogLength)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEM:CAT:LENG? '%s'", directoryPath);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rssmx_QueryViInt32(instrSession, cmd, catalogLength));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Reads out the subdirectories of the specified directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR directoryPath/Directory path parameter.
/// HIPAR arraySize/Size of array passed to 'Catalog'.
/// HIPAR catalog/Reads back catalog list. Size of the list is limited by the 'Array Size' parameter.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is larger then 'Array Size', then the response stored in 'Catalog' is not complete. Resize 'Catalog' array to accomodate all values and call into  the function again.
ViStatus _VI_FUNC rssmx_QueryMMEMoryDirectoryCatalog(ViSession instrSession,
                                                     ViString  directoryPath,
                                                     ViUInt32  arraySize,
                                                     ViChar    catalog[],
                                                     ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEM:DCAT? '%s'", directoryPath);
    checkErr(rssmx_QueryCatalog(instrSession, cmd, arraySize, catalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Reads out the number of subdirectories in the specified directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR directoryPath/Directory path parameter.
/// HIPAR catalogLength/Returns the number of subdirectories in the specified directory. If no
/// HIFN      directory is specified, the default directory is used.
ViStatus _VI_FUNC rssmx_QueryMMEMoryDirectoryCatalogLength(ViSession instrSession,
                                                           ViString  directoryPath,
                                                           ViInt32*  catalogLength)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEM:DCAT:LENG? '%s'", directoryPath);
    checkErr(rssmx_QueryViInt32(instrSession, cmd, catalogLength));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Changes the default directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR directory/Changes the default directory. This directory is used for all
/// HIFN      subsequent MMEM commands if no path is specified with them. It is also
/// HIFN      possible to change to a higher directory using two dots '..'.
ViStatus _VI_FUNC rssmx_MMEMoryChangeDirectory(ViSession instrSession,
                                               ViString  directory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_MMEMORY_CHANGE_DIRECTORY, directory),
            2, "Directory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Copies the first specified file to the second specified file. Instead
/// HIFN      of just a file, this function can also be used to copy a complete
/// HIFN      directory together with all its files.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR sourcePath/Source path of the file or a complete directory together with all its files.
/// HIPAR destinationpath/Destination path of the file or a directory.
ViStatus _VI_FUNC rssmx_MMEMoryCopy(ViSession instrSession,
                                    ViString  sourcePath,
                                    ViString  destinationPath)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEM:COPY '%s','%s'", sourcePath, destinationPath);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Renames an existing file ('File Source') if no path is specified for
/// HIFN      'File Destination'. Otherwise the file is moved to the specified path
/// HIFN      and stored under the original file name or, if specified, a new file
/// HIFN      name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileSource/Define file source.
/// HIPAR fileDestination/Define file destination.
ViStatus _VI_FUNC rssmx_MMEMoryMove(ViSession instrSession,
                                    ViString  fileSource,
                                    ViString  fileDestination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEM:MOVE '%s','%s'", fileSource, fileDestination);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the specified file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileName/Deletes the specified file.
ViStatus _VI_FUNC rssmx_MMEMoryDelete(ViSession instrSession,
                                      ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_MMEMORY_DELETE, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Creates a new subdirectory in the specified directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR directory/Creates a new subdirectory in the specified directory
ViStatus _VI_FUNC rssmx_MMEMoryMakeDirectory(ViSession instrSession,
                                             ViString  directory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_MMEMORY_MAKE_DIRECTORY, directory),
            2, "Directory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the specified subdirectory in the specified directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR directory/Deletes the specified subdirectory in the specified directory.
ViStatus _VI_FUNC rssmx_MMEMoryRemoveDirectory(ViSession instrSession,
                                               ViString  directory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_MMEMORY_REMOVE_DIRECTORY, directory),
            2, "Directory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Writes the block data <binary block data> to the file identified by
/// HIFN      <file_name>. The IEC/IEEE-bus terminator should be set to EOI in order
/// HIFN      to ensure correct data transfer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileName/File name of the binary block data.
/// HIPAR binaryBlockLength/Defines the number of bytes in the 'Binary Block Data' array.
/// HIPAR binaryBlockData/Binary block data array to be writen to the file defined by 'File Name' parameter with the size limited with 'Binary Block Length' parameter.
ViStatus _VI_FUNC rssmx_WriteMMEMoryBlockData(ViSession instrSession,
                                              ViString  fileName,
                                              ViUInt32  binaryBlockLength,
                                              ViChar    binaryBlockData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA '%s',", fileName);
    checkErr(RsCore_WriteBinaryDataBlock(instrSession, cmd, (ViBuf)binaryBlockData, binaryBlockLength));

    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN  Transfers the specified file from instrument to the IEC/IEEE bus and
/// HIFN      then on to the control computer. It is important to ensure that the
/// HIFN      intermediate memory on the control computer is large enough to take the
/// HIFN      file. In this case, the setting for the IEC/IEEE-bus terminator is
/// HIFN      irrelevant.
/// HIFN
/// HIFN     This function can be used to read stored instrument settings or
/// HIFN      waveforms directly from the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR fileName/File name of the binary block data.
/// HIPAR binaryBlockData/Binary block data to be retrieved from the file defined by the 'File Name' parameter. Array size of this parameter must be large enough to store all the retrieved data.
/// HIPAR arraySize/Size of array passed to 'Binary Block Data'.
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is larger then 'Array Size', then the response stored in 'Catalog' is not complete. Resize 'Binary Block Data' array to accomodate all values and call into the function again.
ViStatus _VI_FUNC rssmx_ReadMMEMoryBlockData(ViSession instrSession,
                                             ViString  fileName,
                                             ViUInt32  arraySize,
                                             ViChar    binaryBlockData[],
                                             ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViByte*  ext_buf = NULL;
    ViInt64  bytes_read = 0;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA? '%s'", fileName);
    checkErr(RsCore_QueryBinaryDataBlock(instrSession, cmd, VI_FALSE, NULL, &ext_buf, &bytes_read));
    checkErr(rssmx_CheckStatus(instrSession));
    checkErr(RsCore_CopyToUserBufferBinData((ViByte*)binaryBlockData, arraySize, ext_buf, bytes_read));

    *bytesRead = arraySize < (ViUInt32)bytes_read ? arraySize : (ViUInt32)bytes_read;

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Loads the instrument settings from an intermediate memory identified
/// HIFN  by the specified number.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR recallImmediate/Loads the instrument settings from an intermediate memory identified
/// HIPAR recallImmediate/by the specified number. The instrument settings can be stored to this
/// HIPAR recallImmediate/memory using the command *SAV with the associated number.
ViStatus _VI_FUNC rssmx_RecallImmediate(ViSession instrSession,
                                        ViInt32   recallImmediate)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_RECALL_IMMEDIATE, recallImmediate),
            3, "Recall Immediate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Stores the current instrument settings under the specified number in
/// HIFN  an intermediate memory. The settings can be recalled using the command
/// HIFN  *RCL with the associated number.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR saveImmediate/Stores the current instrument settings under the specified number in
/// HIPAR saveImmediate/an intermediate memory. The settings can be recalled using the command
/// HIPAR saveImmediate/*RCL with the associated number.
ViStatus _VI_FUNC rssmx_SaveImmediate(ViSession instrSession,
                                      ViInt32   saveImmediate)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_SAVE_IMMEDIATE, saveImmediate),
            3, "Save Immediate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Loads the specified file stored under the specified name in an
/// HIFN      internal memory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR number/Determines to the specific <number> to be used with the *RCL command, e.g. *RCL 4.
/// HIPAR fileName/File name parameter.
ViStatus _VI_FUNC rssmx_MMEMoryLoadState(ViSession instrSession,
                                         ViInt32   number,
                                         ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEM:LOAD:STAT %ld,'%s'", number, fileName);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Stores the current instrument setting in the specified file.
/// HIFN
/// HIFN     The instrument setting must first be stored in an internal memory with
/// HIFN      the same number using the common command *SAV.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR number/Corresponds to the specific <number> defined with the *SAV command, e.g. *SAV 4.
/// HIPAR fileName/File name parameter.
ViStatus _VI_FUNC rssmx_MMEMoryStoreState(ViSession instrSession,
                                          ViInt32   number,
                                          ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "*SAV %ld;:MMEM:STOR:STAT %ld,'%s'", number, number, fileName);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the drive (or network resource in the case of networks) using
/// HIFN      <msus> (MSIS = Mass Storage Identification String). This setting is
/// HIFN      effective for all MMEMory functions where the drive is not explicitly
/// HIFN      specified in the parameter.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR mmemoryDrive/Sets the drive (or network resource in the case of networks) using <msus> (MSIS = Mass Storage Identification String).
ViStatus _VI_FUNC rssmx_SelectMMEMoryDrive(ViSession instrSession,
                                           ViString  mmemoryDrive)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_MMEMORY_DRIVE, mmemoryDrive),
            2, "MMEMory Drive");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the used and available memory in Kb.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or rssmx_InitWithOptions function. The handle identifies a particular instrument session.
/// HIPAR totalPhysicalMemory/Total physical memory.
/// HIPAR applicationMemory/Application memory.
/// HIPAR usedHeapMemory/Used heap memory.
/// HIPAR availableHeapMemory/Available heap memory.
ViStatus _VI_FUNC rssmx_QueryFreeMemory(ViSession instrSession,
                                        ViInt32*  totalPhysicalMemory,
                                        ViInt32*  applicationMemory,
                                        ViInt32*  usedHeapMemory,
                                        ViInt32*  availableHeapMemory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryTupleViInt32(instrSession, ":MEM:HFR?", totalPhysicalMemory, applicationMemory, usedHeapMemory, availableHeapMemory));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Starts the power analysis with NRP power sensor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_PowerAnalysisInitiate(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_INITIATE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Aborts the power analysis with NRP power sensors.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_PowerAnalysisAbort(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_ABORT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Stores the selected trace data as reference trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Determines the trace to be saved as a reference.
ViStatus _VI_FUNC rssmx_StorePowerAnalysisTraceReference(ViSession instrSession,
                                                         ViInt32   trace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    checkErr(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_TRACE_REFERENCE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates and configures the selected trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Determines the trace that the configuration will apply to.
/// HIPAR traceState/Activates the selected trace.
/// HIPAR traceColor/Defines the color of the selected trace.
/// HIPAR traceSource/Selects the source for the trace data.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisTrace(ViSession instrSession,
                                                    ViInt32   trace,
                                                    ViInt32   state,
                                                    ViInt32   color,
                                                    ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, "", RSSMX_ATTR_POWER_ANALYSIS_TRACE_STATE, state),
            3, "State");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, "", RSSMX_ATTR_POWER_ANALYSIS_TRACE_COLOR, color),
            4, "Color");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, "", RSSMX_ATTR_POWER_ANALYSIS_TRACE_SOURCE, source),
            5, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the x and y values of the two reference points in 'Frequency'
/// HIFN  measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR pointAFrequencyX/Sets the Point A Frequency (X) value.
/// HIPAR pointAPowY/Sets the Point A Pow (Y) value.
/// HIPAR pointBFrequencyX/Sets the Point B Frequency (X) value.
/// HIPAR pointBPowY/Sets the Point B Pow (Y) value.
ViStatus _VI_FUNC rssmx_DefinePowerAnalysisFrequencyReferencePoints(
                            ViSession instrSession,
                            ViInt64   pointAFrequencyX,
                            ViReal64  pointAPowY,
                            ViInt64   pointBFrequencyX,
                            ViReal64  pointBPowY)
{
    ViStatus error = VI_SUCCESS;
    ViInt64  freqMin = 8000;
    ViInt64  freqMax = 6000000000;
    ViReal64 powMin = -200;
    ViReal64 powMax = 100;
    ViChar   XValCmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   YValCmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt64Range(instrSession, pointAFrequencyX, freqMin, freqMax), 2, "Point A Frequency X");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, pointAPowY, powMin, powMax),
            3, "Point A Pow Y");
    viCheckParm(RsCore_InvalidViInt64Range(instrSession, pointBFrequencyX, freqMin, freqMax), 4, "Point B Frequency X");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, pointBPowY, powMin, powMax),
            5, "Point B Pow Y");

    snprintf(XValCmd, RS_MAX_MESSAGE_BUF_SIZE, ":SENS:SWE:FREQ:REF:DATA:XVAL %lld,%lld", pointAFrequencyX, pointBFrequencyX);

    checkErr(RsCore_Write(instrSession, XValCmd));
    checkErr(rssmx_CheckStatus(instrSession));

    snprintf(YValCmd, RS_MAX_MESSAGE_BUF_SIZE, ":SENS:SWE:FREQ:REF:DATA:YVAL %.12lG,%.12lG", pointAPowY, pointBPowY);

    checkErr(RsCore_Write(instrSession, YValCmd));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the x and y values of the two reference points in 'Power'
/// HIFN  measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR pointAPowerX/Sets the Point A Power (X) value.
/// HIPAR pointAPowY/Sets the Point A Pow (Y) value.
/// HIPAR pointBPowerX/Sets the Point B Power (X) value.
/// HIPAR pointBPowY/Sets the Point B Pow (Y) value.
ViStatus _VI_FUNC rssmx_DefinePowerAnalysisPowerReferencePoints(
                            ViSession instrSession,
                            ViReal64  pointAPowerX,
                            ViReal64  pointAPowY,
                            ViReal64  pointBPowerX,
                            ViReal64  pointBPowY)
{
    ViStatus error = VI_SUCCESS;
    ViReal64 powerMin = -145;
    ViReal64 powerMax = 40;
    ViReal64 powMin = -200;
    ViReal64 powMax = 100;
    ViChar   XValCmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   YValCmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViReal64Range(instrSession, pointAPowerX, powerMin, powerMax),
            2, "Point A Power X");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, pointAPowY, powMin, powMax),
            3, "Point A Pow Y");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, pointBPowerX, powerMin, powerMax),
            4, "Point B Power X");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, pointBPowY, powMin, powMax),
            5, "Point B Pow Y");

    snprintf(XValCmd, RS_MAX_MESSAGE_BUF_SIZE, ":SENS:SWE:POW:REF:DATA:XVAL %.12lG,%.12lG", pointAPowerX, pointBPowerX);

    checkErr(RsCore_Write(instrSession, XValCmd));
    checkErr(rssmx_CheckStatus(instrSession));

    snprintf(YValCmd, RS_MAX_MESSAGE_BUF_SIZE, ":SENS:SWE:POW:REF:DATA:YVAL %.12lG,%.12lG", pointAPowY, pointBPowY);

    checkErr(RsCore_Write(instrSession, YValCmd));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the x and y values of the two reference points in 'Power'
/// HIFN  measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR pointATimeX/Sets the Point A Time (X) value.
/// HIPAR pointAPowY/Sets the Point A Pow (Y) value.
/// HIPAR pointBTimeX/Sets the Point B Time (X) value.
/// HIPAR pointBPowY/Sets the Point B Pow (Y) value.
ViStatus _VI_FUNC rssmx_DefinePowerAnalysisTimeReferencePoints(
                            ViSession instrSession,
                            ViReal64  pointATimeX,
                            ViReal64  pointAPowY,
                            ViReal64  pointBTimeX,
                            ViReal64  pointBPowY)
{
    ViStatus error = VI_SUCCESS;
    ViReal64 timeAMin = -1000000;
    ViReal64 timeAMax = 2000000;
    ViReal64 timeBMin = 0;
    ViReal64 timeBMax = 2000000;
    ViReal64 powMin = -200;
    ViReal64 powMax = 100;
    ViChar   XValCmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   YValCmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViReal64Range(instrSession, pointATimeX, timeAMin, timeAMax),
            2, "Point A Time X");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, pointAPowY, powMin, powMax),
            3, "Point A Pow Y");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, pointBTimeX, timeBMin, timeBMax),
            4, "Point B Time X");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, pointBPowY, powMin, powMax),
            5, "Point B Pow Y");

    snprintf(XValCmd, RS_MAX_MESSAGE_BUF_SIZE, ":SENS:SWE:POW:REF:DATA:XVAL %.12lG,%.12lG", pointATimeX, pointBTimeX);

    checkErr(RsCore_Write(instrSession, XValCmd));
    checkErr(rssmx_CheckStatus(instrSession));

    snprintf(YValCmd, RS_MAX_MESSAGE_BUF_SIZE, ":SENS:SWE:POW:REF:DATA:YVAL %.12lG,%.12lG", pointAPowY, pointBPowY);

    checkErr(RsCore_Write(instrSession, YValCmd));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Generates a reference curve for the given measurement mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Determines the power analysis mode that the reference curve will be
/// HIPAR mode/generated for.
ViStatus _VI_FUNC rssmx_GeneratePowerAnalysisReference(ViSession instrSession,
                                                       ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViAttr   arrGenerateCurveAttr[] = {
             RSSMX_ATTR_GENERATE_POWER_ANALYSIS_FREQUENCY_REFERENCE,
             RSSMX_ATTR_GENERATE_POWER_ANALYSIS_POWER_REFERENCE,
             RSSMX_ATTR_GENERATE_POWER_ANALYSIS_TIME_REFERENCE
             };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mode, RSSMX_VAL_ANALYSIS_MODE_FREQUENCY, RSSMX_VAL_ANALYSIS_MODE_TIME),
            2, "Mode");

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, arrGenerateCurveAttr[mode], NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the number of points from the reference curve in the given
/// HIFN  measurement mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Determines the power analysis mode that the reference curve will be
/// HIPAR mode/generated for.
/// HIPAR points/Queries the number of points from the reference curve in 'Frequency'
/// HIPAR points/measurement.
ViStatus _VI_FUNC rssmx_QueryPowerAnalysisReferencePoints(ViSession instrSession,
                                                          ViInt32   mode,
                                                          ViInt32*  points)
{
    ViStatus error = VI_SUCCESS;
    ViAttr   arrQueryPointsAttr[] = {
             RSSMX_ATTR_GENERATE_POWER_ANALYSIS_FREQUENCY_REFERENCE_POINTS,
             RSSMX_ATTR_GENERATE_POWER_ANALYSIS_POWER_REFERENCE_POINTS,
             RSSMX_ATTR_GENERATE_POWER_ANALYSIS_TIME_REFERENCE_POINTS
             };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mode, RSSMX_VAL_ANALYSIS_MODE_FREQUENCY, RSSMX_VAL_ANALYSIS_MODE_TIME),
            2, "Mode");

    viCheckParm(rssmx_GetAttributeViInt32(instrSession, NULL, arrQueryPointsAttr[mode], points),
            3, "Points");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures trace mathematics settings in the given measurement mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Determines the trace that the configuration will apply to.
/// HIPAR mode/Determines the power analysis mode that the settings will be applied to.
/// HIPAR mathEnabled/Activates the trace mathematics mode for the given measurement mode.
/// HIPAR mathEnabled/This feature enables you to calculate the difference between the
/// HIPAR mathEnabled/measurement values of two traces. For further calculation, a math
/// HIPAR mathEnabled/result can also be assigned to a trace.
/// HIPAR subtractionOperands/Subtracts the operands 1 and 2 and assigns the result to the selected
/// HIPAR subtractionOperands/trace.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisMath(ViSession instrSession,
                                                   ViInt32   trace,
                                                   ViInt32   mode,
                                                   ViBoolean mathEnabled,
                                                   ViInt32   subtractionOperands)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];
    ViAttr   arrMathEnabledAttr[] = {
             RSSMX_ATTR_POWER_ANALYSIS_MATH_FREQUENCY_ENABLED,
             RSSMX_ATTR_POWER_ANALYSIS_MATH_POWER_ENABLED,
             RSSMX_ATTR_POWER_ANALYSIS_MATH_TIME_ENABLED
             };
    ViAttr   arrSubtractionOperandsAttr[] = {
             RSSMX_ATTR_POWER_ANALYSIS_MATH_FREQUENCY_SUBTRACT,
             RSSMX_ATTR_POWER_ANALYSIS_MATH_POWER_SUBTRACT,
             RSSMX_ATTR_POWER_ANALYSIS_MATH_TIME_SUBTRACT
             };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "MATH%ld", trace);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mode, RSSMX_VAL_ANALYSIS_MODE_FREQUENCY, RSSMX_VAL_ANALYSIS_MODE_TIME),
            3, "Mode");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, arrMathEnabledAttr[mode], mathEnabled),
            4, "Math Enabled");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, arrSubtractionOperandsAttr[mode], subtractionOperands),
            5, "Subtraction Operands");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures trace mathematics settings in the given measurement mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Determines the trace that the configuration will apply to.
/// HIPAR mode/Determines the power analysis mode that the settings will be applied
/// HIPAR mode/to.
/// HIPAR xAxis/Sets the x-axis values for calculating the reference curve in
/// HIPAR xAxis/frequency measurement mode.
/// HIPAR yAxis/Sets the y-axis values for calculating the reference curve in
/// HIPAR yAxis/frequency measurement mode.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisMathAxis(ViSession instrSession,
                                                       ViInt32   trace,
                                                       ViInt32   mode,
                                                       ViReal64  xAxis,
                                                       ViReal64  yAxis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mode, RSSMX_VAL_ANALYSIS_MODE_FREQUENCY, RSSMX_VAL_ANALYSIS_MODE_TIME),
            3, "Mode");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMX_ATTR_POWER_ANALYSIS_MATH_FREQUENCY_X,
            "Trace", trace - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trace");

    switch (mode)
    {
        case RSSMX_VAL_ANALYSIS_MODE_FREQUENCY:
            viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_MATH_FREQUENCY_X, xAxis),
                    4, "X Axis");

            viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_MATH_FREQUENCY_Y, yAxis),
                    5, "Y Axis");
            break;
        case RSSMX_VAL_ANALYSIS_MODE_POWER:
            viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_MATH_POWER_X, xAxis),
                    4, "X Axis");

            viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_MATH_POWER_Y, yAxis),
                    5, "Y Axis");
            break;
        case RSSMX_VAL_ANALYSIS_MODE_TIME:
            viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_MATH_TIME_X, xAxis),
                    4, "X Axis");

            viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_MATH_TIME_Y, yAxis),
                    5, "Y Axis");
            break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, mode), 3, "Mode");
            break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Determines the source of a trace for display in frequency measurement
/// HIFN  mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Determines the trace that the configuration will apply to.
/// HIPAR mode/Determines the power analysis mode that the settings will be applied
/// HIPAR mode/to.
/// HIPAR source/Determines the source of a trace for display in different measurement
/// HIPAR source/modes.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisSource(ViSession instrSession,
                                                     ViInt32   trace,
                                                     ViInt32   mode,
                                                     ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mode, RSSMX_VAL_ANALYSIS_MODE_FREQUENCY, RSSMX_VAL_ANALYSIS_MODE_TIME),
            3, "Mode");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSSMX_ATTR_POWER_ANALYSIS_FREQUENCY_SOURCE,
            "Trace", trace - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trace");

    switch (mode)
    {
        case RSSMX_VAL_ANALYSIS_MODE_FREQUENCY:
            viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_FREQUENCY_SOURCE, source),
                    4, "Source");
            break;
        case RSSMX_VAL_ANALYSIS_MODE_POWER:
            viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_POWER_SOURCE, source),
                    4, "Source");
            break;
        case RSSMX_VAL_ANALYSIS_MODE_TIME:
            viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_TIME_SOURCE, source),
                    4, "Source");
            break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, mode), 3, "Mode");
            break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the number of measurement points of the selected trace of the
/// HIFN  current power analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Determines the trace that the command will apply to.
/// HIPAR dataPoints/Queries the number of measurement points of the selected trace of the
/// HIPAR dataPoints/current power analysis.
ViStatus _VI_FUNC rssmx_QueryPowerAnalysisTraceDataPoints(ViSession instrSession,
                                                          ViInt32   trace,
                                                          ViInt32*  dataPoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rssmx_GetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_TRACE_DATA_POINTS, dataPoints),
            3, "Data Points");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the x-axis values - frequency, power or time values - of the
/// HIFN  selected trace of the current power analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Determines the trace that the command will apply to.
/// HIPAR arraySize/Size of array passed to 'Data'.
/// HIPAR dataXValues/Returns an array of the x-axis values - frequency, power or time
/// HIPAR dataXValues/values - of the selected trace of the current power analysis.
/// HIPAR dataCount/Returns number of values read from instrument. If the value returned
/// HIPAR dataCount/is larger then 'Array Size', then the response stored in 'Data' is not
/// HIPAR dataCount/complete. Resize 'Data' array to accomodate all values and call into
/// HIPAR dataCount/the function again.
ViStatus _VI_FUNC rssmx_QueryPowerAnalysisTraceDataX(ViSession instrSession,
                                                     ViInt32   trace,
                                                     ViUInt32  arraySize,
                                                     ViReal64  dataXValues[],
                                                     ViInt32*  dataCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":TRAC%ld:SWE:DATA:XVAL?", trace);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, arraySize, dataXValues, dataCount));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the measurement (y-axis) values of the selected trace of the
/// HIFN  current power analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Determines the trace that the command will apply to.
/// HIPAR arraySize/Size of array passed to 'Data'.
/// HIPAR dataYValues/Returns an array of the measurement (y-axis) values of the selected
/// HIPAR dataYValues/trace of the current power analysis.
/// HIPAR dataCount/Returns number of values read from instrument. If the value returned
/// HIPAR dataCount/is larger then 'Array Size', then the response stored in 'Data' is not
/// HIPAR dataCount/complete. Resize 'Data' array to accomodate all values and call into
/// HIPAR dataCount/the function again.
ViStatus _VI_FUNC rssmx_QueryPowerAnalysisTraceDataY(ViSession instrSession,
                                                     ViInt32   trace,
                                                     ViUInt32  arraySize,
                                                     ViReal64  dataYValues[],
                                                     ViInt32*  dataCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":TRAC%ld:SWE:DATA:YVAL?", trace);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, arraySize, dataYValues, dataCount));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  For a given x-axis value, queries the measurement (y-axis) value of
/// HIFN  the selected trace of the current power analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Determines the trace that the command will apply to.
/// HIPAR xValue/The x-axis value to query the measurement (y-axis) value of.
/// HIPAR yValue/Measurement (y-axis) value of the given x-axis value of the current
/// HIPAR yValue/power analysis.
ViStatus _VI_FUNC rssmx_QueryPowerAnalysisYValue(ViSession instrSession,
                                                 ViInt32   trace,
                                                 ViReal64  xValue,
                                                 ViReal64* yValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":TRAC%ld:SWE:DATA:YSV? %lF", trace, xValue);
    checkErr(rssmx_QueryViReal64(instrSession, cmd, yValue));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects power versus frequency measurement (frequency response), power
/// HIFN  vs power measurement (power sweep, AM/AM) or power vs. time
/// HIFN  measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Selects power versus frequency measurement (frequency response), power
/// HIPAR mode/vs power measurement (power sweep, AM/AM) or power vs. time
/// HIPAR mode/measurement.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisMeasurementMode(
                            ViSession instrSession,
                            ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_MEASUREMENT_MODE, mode),
            2, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects single or continuous mode for power analysis (all measurement
/// HIFN  modes).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR execution/Selects single or continuous mode for power analysis (all measurement
/// HIPAR execution/modes).
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisMeasurementExecution(
                            ViSession instrSession,
                            ViInt32   execution)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_MEASUREMENT_EXECUTION, execution),
            2, "Execution");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures power versus frequency measurement options.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR minimum/Sets the start frequency for the frequency mode.
/// HIPAR maximum/Sets the stop frequency for the frequency mode.
/// HIPAR steps/Sets the number of measurement steps for the frequency mode.
/// HIPAR timing/Selects the mode in terms of speed and precision of the response of a
/// HIPAR timing/measurement.
/// HIPAR spacing/Selects the spacing for the frequency power analysis.
/// HIPAR execution/Selects single or continuous mode for measurement mode frequency in
/// HIPAR execution/power analysis.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisFrequencyMode(ViSession instrSession,
                                                            ViReal64  minimum,
                                                            ViReal64  maximum,
                                                            ViInt32   steps,
                                                            ViInt32   timing,
                                                            ViInt32   spacing,
                                                            ViInt32   execution)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_FREQUENCY_MIN, minimum),
            2, "Minimum");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_FREQUENCY_MAX, maximum),
            3, "Maximum");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_FREQUENCY_STEPS, steps),
            4, "Steps");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_FREQUENCY_TIMING, timing),
            5, "Timing");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_FREQUENCY_SPACING, spacing),
            6, "Spacing");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_FREQUENCY_EXECUTION, execution),
            7, "Execution");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures power versus power measurement options.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR minimum/Sets the start level for the power versus power measurement.
/// HIPAR maximum/Sets the stop level for the power versus power measurement.
/// HIPAR steps/Sets the number of measurement steps for the power versus power
/// HIPAR steps/measurement.
/// HIPAR timing/Selects the timing mode of the measurement.
/// HIPAR execution/Selects single or continuous mode for measurement mode power in power
/// HIPAR execution/analysis.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisPowerMode(ViSession instrSession,
                                                        ViReal64  minimum,
                                                        ViReal64  maximum,
                                                        ViInt32   steps,
                                                        ViInt32   timing,
                                                        ViInt32   execution)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_POWER_MIN, minimum),
            2, "Minimum");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_POWER_MAX, maximum),
            3, "Maximum");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_POWER_STEPS, steps),
            4, "Steps");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_POWER_TIMING, timing),
            5, "Timing");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_POWER_EXECUTION, execution),
            6, "Execution");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures power versus time measurement options.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR minimum/Sets the start time for the power versus time measurement. Value 0
/// HIPAR minimum/defines the trigger point. By choosing a negative time value, the trace
/// HIPAR minimum/can be shifted in the diagram. It is possible, that the measurement
/// HIPAR minimum/cannot be performed over the complete time range because of limitations
/// HIPAR minimum/due to sensor settings. In this case, an error message is output.
/// HIPAR maximum/Sets the stop time for the power versus time measurement.
/// HIPAR steps/Sets the number of measurement steps for the power versus time
/// HIPAR steps/measurement. Value 0 defines the trigger point.
/// HIPAR average/Selects the averaging factor in time mode. The count number determines
/// HIPAR average/how many measurement cycles are used to form a measurement result.
/// HIPAR average/Higher averaging counts reduce noise but increase the measurement time.
/// HIPAR average/Averaging requires a stable trigger event so that the measurement
/// HIPAR average/cycles have the same timing.
/// HIPAR execution/Selects single or continuous mode for measurement mode time in power
/// HIPAR execution/analysis.
/// HIPAR triggerEvents/Determines, whether the measurement data processing starts with a
/// HIPAR triggerEvents/trigger event in one of the sensors (Logical OR), or whether all
/// HIPAR triggerEvents/channels have to be triggered (logical AND). Each sensor evaluates a
/// HIPAR triggerEvents/trigger event according to its setting independently. This function
/// HIPAR triggerEvents/supports the internal or external trigger modes with multi-channel time
/// HIPAR triggerEvents/measurements.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisTimeMode(ViSession instrSession,
                                                       ViReal64  minimum,
                                                       ViReal64  maximum,
                                                       ViInt32   steps,
                                                       ViInt32   average,
                                                       ViInt32   execution,
                                                       ViInt32   triggerEvents)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_TIME_MIN, minimum),
            2, "Minimum");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_TIME_MAX, maximum),
            3, "Maximum");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_TIME_STEPS, steps),
            4, "Steps");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_TIME_AVERAGE, average),
            5, "Average");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_TIME_EXECUTION, execution),
            6, "Execution");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_TIME_TRIGGER_EVENTS, triggerEvents),
            7, "Trigger Events");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures visual settings for the power analysis diagram in all
/// HIFN  analysis modes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gridEnabled/Indicates a grid in the diagram.
/// HIPAR backgroundColor/Defines the background color of the measurement diagram. The selected
/// HIPAR backgroundColor/color applies also to the hardcopy of the diagram.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisDiagramGraphicalSettings(
                            ViSession instrSession,
                            ViBoolean gridEnabled,
                            ViInt32   backgroundColor)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_GRID_ENABLED, gridEnabled),
            2, "Grid Enabled");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_BACKGROUND_COLOR, backgroundColor),
            3, "Background Color");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures options for the power analysis diagram display in all
/// HIFN  analysis modes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR standardViewEnabled/Selects the standard view, i.e. diagram and buttons but no lists are
/// HIPAR standardViewEnabled/displayed and also stored in the hardcopy file.
/// HIPAR markerViewEnabled/Activates the indication of the markers and the marker list in the
/// HIPAR markerViewEnabled/measurement diagram and in the hardcopy file.
/// HIPAR pulseDataViewEnabled/Activates the indication of the pulse data below the measurement
/// HIPAR pulseDataViewEnabled/diagram and storing the data in the hardcopy file.
/// HIPAR fullscreenEnabled/Selects fullscreen display of the measurement diagram on the display
/// HIPAR fullscreenEnabled/and in the hardcopy file.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisDiagramView(ViSession instrSession,
                                                          ViBoolean standardViewEnabled,
                                                          ViBoolean markerViewEnabled,
                                                          ViBoolean pulseDataViewEnabled,
                                                          ViBoolean fullscreenEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_STANDARD_VIEW_ENABLED, standardViewEnabled),
            2, "Standard View Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_MARKER_VIEW_ENABLED, markerViewEnabled),
            3, "Marker View Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_PULSE_DATA_VIEW_ENABLED, pulseDataViewEnabled),
            4, "Pulse Data View Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_FULLSCREEN_ENABLED, fullscreenEnabled),
            5, "Fullscreen Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures options for the power analysis diagram in the given
/// HIFN  measurement mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Determines the power analysis mode that the settings will be applied
/// HIPAR mode/to.
/// HIPAR minLevel/Sets the minimum value for the y axis of the measurement diagram.
/// HIPAR maxLevel/Sets the maximum value for the y axis of the measurement diagram.
/// HIPAR autoScale/Activates autoscaling of the Y axis of the diagram.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisDiagramScale(ViSession instrSession,
                                                           ViInt32   mode,
                                                           ViReal64  minLevel,
                                                           ViReal64  maxLevel,
                                                           ViInt32   autoScale)
{
    ViStatus error = VI_SUCCESS;
    ViAttr   arrMinLevelAttr[] = {
             RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_FREQUENCY_MIN,
             RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_POWER_MIN,
             RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_TIME_MIN
             };
    ViAttr   arrMaxLevelAttr[] = {
             RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_FREQUENCY_MAX,
             RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_POWER_MAX,
             RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_TIME_MAX
             };
    ViAttr   arrAutoScaleAttr[] = {
             RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_FREQUENCY_AUTO_SCALE,
             RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_POWER_AUTO_SCALE,
             RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_TIME_AUTO_SCALE
             };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mode, RSSMX_VAL_ANALYSIS_MODE_FREQUENCY, RSSMX_VAL_ANALYSIS_MODE_TIME),
            2, "Mode");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, arrMinLevelAttr[mode], minLevel),
            3, "Min Level");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, NULL, arrMaxLevelAttr[mode], maxLevel),
            4, "Max Level");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, arrAutoScaleAttr[mode], autoScale),
            4, "Auto Scale");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Resets the Y scale to suitable values after the use of auto scaling in
/// HIFN  the expanding mode. For this mode, the scale might get expanded because
/// HIFN  of temporarily high-power values. The reset function resets the diagram
/// HIFN  in such a way that it matches smaller power values again.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Determines the power analysis mode in which the auto scale will be
/// HIPAR mode/reset.
ViStatus _VI_FUNC rssmx_ResetPowerAnalysisDiagramAutoScale(ViSession instrSession,
                                                           ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViAttr   arrResetAttr[] = {
             RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_FREQUENCY_AUTO_SCALE_RESET,
             RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_POWER_AUTO_SCALE_RESET,
             RSSMX_ATTR_POWER_ANALYSIS_DIAGRAM_TIME_AUTO_SCALE_RESET
             };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mode, RSSMX_VAL_ANALYSIS_MODE_FREQUENCY, RSSMX_VAL_ANALYSIS_MODE_TIME),
            2, "Mode");

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, arrResetAttr[mode], NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates th eindication of the time gate borders and values in the
/// HIFN  measurement diagram and in the hardcopy file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR indicationEnabled/Activates th eindication of the time gate borders and values in the
/// HIPAR indicationEnabled/measurement diagram and in the hardcopy file.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisGateIndicationEnabled(
                            ViSession instrSession,
                            ViBoolean indicationEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_POWER_ANALYSIS_GATE_INDICATION_ENABLED, indicationEnabled),
            2, "Indication Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures settings for time gated measurements of peak and average
/// HIFN  power.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gateTrace/Selects the trace for time gated measurement. Both gates are assigned
/// HIPAR gateTrace/to the same trace.
/// HIPAR enabled/Activates the gate settings for the selected trace. The measurement is
/// HIPAR enabled/started with RSSMX_ATTR_POWER_ANALYSIS_INITIATE. Both gates are active
/// HIPAR enabled/at one time.
/// HIPAR gate1Start/Sets the start time of gate 1 in seconds.
/// HIPAR gate1Stop/Sets the start time of gate 1 in seconds.
/// HIPAR gate2Start/Sets the start time of gate 2 in seconds.
/// HIPAR gate2Stop/Sets the start time of gate 2 in seconds.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisGateMode(ViSession instrSession,
                                                       ViInt32   gateTrace,
                                                       ViBoolean enabled,
                                                       ViReal64  gate1Start,
                                                       ViReal64  gate1Stop,
                                                       ViReal64  gate2Start,
                                                       ViReal64  gate2Stop)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, "Gate1", RSSMX_ATTR_POWER_ANALYSIS_GATE_TRACE, gateTrace),
            2, "Gate Trace");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, "Gate1", RSSMX_ATTR_POWER_ANALYSIS_GATE_ENABLED, enabled),
            3, "Enabled");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, "Gate1", RSSMX_ATTR_POWER_ANALYSIS_GATE_START, gate1Start),
            4, "Gate 1 Start");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, "Gate1", RSSMX_ATTR_POWER_ANALYSIS_GATE_STOP, gate1Stop),
            5, "Gate 1 Stop");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, "Gate2", RSSMX_ATTR_POWER_ANALYSIS_GATE_START, gate2Start),
            6, "Gate 2 Start");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, "Gate2", RSSMX_ATTR_POWER_ANALYSIS_GATE_STOP, gate2Stop),
            7, "Gate 2 Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the average power value of the time gated measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gate/Selects the gate to query the average power value of the time gated
/// HIPAR gate/measurement.
/// HIPAR average/Queries the average power value of the time gated measurement.
ViStatus _VI_FUNC rssmx_QueryPowerAnalysisGateAverage(ViSession instrSession,
                                                      ViInt32   gate,
                                                      ViReal64* average)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, gate, 1, 2),
            2, "Gate");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "GATE%ld", gate);

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_GATE_AVERAGE, average),
            3, "Average");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the average power value of the time gated measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gate/Selects the gate to query the maximum power value of the time gated
/// HIPAR gate/measurement.
/// HIPAR maximum/Queries the average power value of the time gated measurement.
ViStatus _VI_FUNC rssmx_QueryPowerAnalysisGateMaximum(ViSession instrSession,
                                                      ViInt32   gate,
                                                      ViReal64* maximum)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, gate, 1, 2),
            2, "Gate");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "GATE%ld", gate);

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_GATE_MAXIMUM, maximum),
            3, "Maximum");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configure settings for the level offset at the sensor input for the
/// HIFN  given measurement mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sensor/Selects the sensor input to configure level offset settings.
/// HIPAR mode/Determines the power analysis mode that the settings will be applied
/// HIPAR mode/to.
/// HIPAR offsetEnabled/Activates a level offset at the sensor input.
/// HIPAR offset/Defines the level offset at the sensor input in dB.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisSensorLevelOffset(
                            ViSession instrSession,
                            ViInt32   sensor,
                            ViInt32   mode,
                            ViBoolean offsetEnabled,
                            ViReal64  offset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];
    ViAttr   arrOffsetEnabledAttr[] = {
             RSSMX_ATTR_POWER_ANALYSIS_SENSOR_FREQUENCY_OFFSET_ENABLED,
             RSSMX_ATTR_POWER_ANALYSIS_SENSOR_POWER_OFFSET_ENABLED,
             RSSMX_ATTR_POWER_ANALYSIS_SENSOR_TIME_OFFSET_ENABLED
             };
    ViAttr   arrOffsetAttr[] = {
             RSSMX_ATTR_POWER_ANALYSIS_SENSOR_FREQUENCY_OFFSET,
             RSSMX_ATTR_POWER_ANALYSIS_SENSOR_POWER_OFFSET,
             RSSMX_ATTR_POWER_ANALYSIS_SENSOR_TIME_OFFSET
             };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sensor, 1, 4),
            2, "Sensor");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "SENS%ld", sensor);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mode, RSSMX_VAL_ANALYSIS_MODE_FREQUENCY, RSSMX_VAL_ANALYSIS_MODE_TIME),
            3, "Mode");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, arrOffsetEnabledAttr[mode], offsetEnabled),
            4, "Offset Enabled");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, arrOffsetAttr[mode], offset),
            5, "Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configure settings for the use of a frequency range for the power
/// HIFN  measurement that is different to the set signal generator frequency
/// HIFN  range for power vs. frequency measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sensor/Selects the sensor input to configure separate frequency settings.
/// HIPAR useSeparateFreq/Activates the use of a frequency range for the power vs. frequency
/// HIPAR useSeparateFreq/measurement that is different to the set signal generator frequency
/// HIPAR useSeparateFreq/range.
/// HIPAR separateFreqStart/Sets the start frequency for the frequency power analysis with
/// HIPAR separateFreqStart/separate frequencies.
/// HIPAR separateFreqStop/Sets the stop frequency for the frequency power analysis with separate
/// HIPAR separateFreqStop/frequencies.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisSensorFrequencySeparateFreq(
                            ViSession instrSession,
                            ViInt32   sensor,
                            ViBoolean useSeparateFreq,
                            ViReal64  separateFreqStart,
                            ViReal64  separateFreqStop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sensor, 1, 4),
            2, "Sensor");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "SENS%ld", sensor);

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_SENSOR_FREQUENCY_USE_SEPARATE_FREQ, useSeparateFreq),
            3, "Use Separate Freq");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_SENSOR_FREQUENCY_SEPARATE_FREQ_START, separateFreqStart),
            4, "Separate Freq Start");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_SENSOR_FREQUENCY_SEPARATE_FREQ_STOP, separateFreqStop),
            5, "Separate Freq Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configure settings for the use of a different frequency other than the
/// HIFN  set signal generator frequency for power vs. power measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sensor/Selects the sensor input to configure separate frequency settings.
/// HIPAR useSeparateFreq/Activates the use of a different frequency for the power vs. power
/// HIPAR useSeparateFreq/measurement.
/// HIPAR separateFreq/Defines the separate frequency used for power vs. power measurement.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisSensorPowerSeparateFreq(
                            ViSession instrSession,
                            ViInt32   sensor,
                            ViBoolean useSeparateFreq,
                            ViReal64  separateFreq)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sensor, 1, 4),
            2, "Sensor");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "SENS%ld", sensor);

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_SENSOR_POWER_USE_SEPARATE_FREQ, useSeparateFreq),
            3, "Use Separate Freq");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_SENSOR_POWER_SEPARATE_FREQ, separateFreq),
            4, "Separate Freq");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configure settings for the use of a different frequency other than the
/// HIFN  set signal generator frequency for power vs. time measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sensor/Selects the sensor input to configure separate frequency settings.
/// HIPAR useSeparateFreq/Activates the use of a different frequency for the power vs. time
/// HIPAR useSeparateFreq/measurement.
/// HIPAR separateFreq/Defines the separate frequency used for power vs. time measurement.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisSensorTimeSeparateFreq(
                            ViSession instrSession,
                            ViInt32   sensor,
                            ViBoolean useSeparateFreq,
                            ViReal64  separateFreq)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sensor, 1, 4),
            2, "Sensor");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "SENS%ld", sensor);

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_SENSOR_TIME_USE_SEPARATE_FREQ, useSeparateFreq),
            3, "Use Separate Freq");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_SENSOR_TIME_SEPARATE_FREQ, separateFreq),
            4, "Separate Freq");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables/disables the indication of all pulse data of the selected
/// HIFN  trace. The parameters to be indicated can be selected with the
/// HIFN  TRAC:SWE:MEAS:.commands. Only six parameters are indicated at one time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the input to configure.
/// HIPAR allIndicationsEnabled/Enables/disables the indication of all pulse data of the selected
/// HIPAR allIndicationsEnabled/trace.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisPulseDataAllIndicationsEnabled(
                            ViSession instrSession,
                            ViInt32   trace,
                            ViBoolean allIndicationsEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_DATA_ALL_INDICATIONS_ENABLED, allIndicationsEnabled),
            3, "All Indications Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures pulse data analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the input to configure.
/// HIPAR enabled/Enables pulse data analysis.
/// HIPAR base/Selects how the threshold parameters for pulse analysis are
/// HIPAR base/calculated.
/// HIPAR distal/Queries the upper threshold level of the overall pulse level. The
/// HIPAR distal/distal power defines the end of the rising edge and the start of the
/// HIPAR distal/falling edge of the pulse.
/// HIPAR mesial/Sets the medial reference level in terms of percentage of the overall
/// HIPAR mesial/pulse level (power or voltage related). This level is used to define
/// HIPAR mesial/pulse width and pulse period.
/// HIPAR proximal/Sets the lower reference level in terms of percentage of the overall
/// HIPAR proximal/pulse level. The proximal power defines the start of the rising edge
/// HIPAR proximal/and the end of the falling edge of the pulse.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisPulseData(ViSession instrSession,
                                                        ViInt32   trace,
                                                        ViBoolean enabled,
                                                        ViInt32   base,
                                                        ViReal64  distal,
                                                        ViReal64  mesial,
                                                        ViReal64  proximal)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_DATA_ENABLED, enabled),
            3, "Enabled");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_DATA_BASE, base),
            4, "Base");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_DATA_DISTAL, distal),
            5, "Distal");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_DATA_MESIAL, mesial),
            6, "Mesial");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_DATA_PROXIMAL, proximal),
            7, "Proximal");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries pulse data analysis calculated threshold parameters for the
/// HIFN  given trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the input to configure.
/// HIPAR baseCalculated/Queries how the threshold parameters are calculated.
/// HIPAR distalCalculated/Queries the upper threshold level of the overall pulse level. The
/// HIPAR distalCalculated/distal power defines the end of the rising edge and the start of the
/// HIPAR distalCalculated/falling edge of the pulse.
/// HIPAR mesialCalculated/Queries the medial threshold level of the overall pulse level. This
/// HIPAR mesialCalculated/level is used to define the pulse width and pulse period.
/// HIPAR proximalCalculated/Queries the lower medial threshold level of the overall pulse level.
/// HIPAR proximalCalculated/The proximal power defines the start of the rising edge and the end of
/// HIPAR proximalCalculated/the falling edge of the pulse.
ViStatus _VI_FUNC rssmx_QueryPowerAnalysisPulseDataCalculated(
                            ViSession instrSession,
                            ViInt32   trace,
                            ViInt32*  baseCalculated,
                            ViReal64* distalCalculated,
                            ViReal64* mesialCalculated,
                            ViReal64* proximalCalculated)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rssmx_GetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_DATA_BASE_CALCULATED, baseCalculated),
            3, "Base Calculated");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_DATA_DISTAL_CALCULATED, distalCalculated),
            4, "Distal Calculated");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_DATA_MESIAL_CALCULATED, mesialCalculated),
            5, "Mesial Calculated");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_DATA_PROXIMAL_CALCULATED, proximalCalculated),
            6, "Proximal Calculated");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects pulse parameters which are indicated in the display and
/// HIFN  hardcopy file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the input to configure.
/// HIPAR dutyCycleEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR dutyCycleEnabled/hardcopy file.
/// HIPAR pulseWidthEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR pulseWidthEnabled/hardcopy file.
/// HIPAR pulsePeriodEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR pulsePeriodEnabled/hardcopy file.
/// HIPAR pulseOffTimeEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR pulseOffTimeEnabled/hardcopy file.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisPulseDataNotifications(
                            ViSession instrSession,
                            ViInt32   trace,
                            ViBoolean dutyCycleEnabled,
                            ViBoolean pulseWidthEnabled,
                            ViBoolean pulsePeriodEnabled,
                            ViBoolean pulseOffTimeEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_NOTIFICATION_DUTY_CYCLE_ENABLED, dutyCycleEnabled),
            3, "Duty Cycle Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_NOTIFICATION_PULSE_WIDTH_ENABLED, pulseWidthEnabled),
            4, "Pulse Width Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_NOTIFICATION_PULSE_PERIOD_ENABLED, pulsePeriodEnabled),
            5, "Pulse Period Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_NOTIFICATION_PULSE_OFF_TIME_ENABLED, pulseOffTimeEnabled),
            6, "Pulse Off Time Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the measured pulse parameter values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the input to configure.
/// HIPAR dutyCycle/Queries the measured pulse parameter values.
/// HIPAR pulseWidth/Queries the measured pulse parameter values.
/// HIPAR pulsePeriod/Queries the measured pulse parameter values.
/// HIPAR pulseOffTime/Queries the measured pulse parameter values.
/// HIPAR pulseState/Queries the measured pulse parameter values.
ViStatus _VI_FUNC rssmx_QueryPowerAnalysisPulseMeasurements(ViSession  instrSession,
                                                            ViInt32    trace,
                                                            ViReal64*  dutyCycle,
                                                            ViReal64*  pulseWidth,
                                                            ViReal64*  pulsePeriod,
                                                            ViReal64*  pulseOffTime,
                                                            ViBoolean* pulseState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_NOTIFICATION_DUTY_CYCLE, dutyCycle),
            3, "Duty Cycle");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_NOTIFICATION_PULSE_WIDTH, pulseWidth),
            4, "Pulse Width");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_NOTIFICATION_PULSE_PERIOD, pulsePeriod),
            5, "Pulse Period");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_NOTIFICATION_PULSE_OFF_TIME, pulseOffTime),
            6, "Pulse OffTime");

    viCheckParm(rssmx_GetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_NOTIFICATION_PULSE_STATE, pulseState),
            7, "Pulse State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects pulse parameters which are indicated in the display and
/// HIFN  hardcopy file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the input to configure.
/// HIPAR transitionRiseTimeEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR transitionRiseTimeEnabled/hardcopy file.
/// HIPAR transitionFallTimeEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR transitionFallTimeEnabled/hardcopy file.
/// HIPAR transitionStartTimeEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR transitionStartTimeEnabled/hardcopy file.
/// HIPAR transitionStopTimeEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR transitionStopTimeEnabled/hardcopy file.
/// HIPAR overshootRisingEdgeEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR overshootRisingEdgeEnabled/hardcopy file.
/// HIPAR overshootFallingEdgeEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR overshootFallingEdgeEnabled/hardcopy file.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisTransitionTimesNotifications(
                            ViSession instrSession,
                            ViInt32   trace,
                            ViBoolean transitionRiseTimeEnabled,
                            ViBoolean transitionFallTimeEnabled,
                            ViBoolean transitionStartTimeEnabled,
                            ViBoolean transitionStopTimeEnabled,
                            ViBoolean overshootRisingEdgeEnabled,
                            ViBoolean overshootFallingEdgeEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_TRANSITION_RISE_TIME_ENABLED, transitionRiseTimeEnabled),
            3, "Transition Rise Time Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_TRANSITION_FALL_TIME_ENABLED, transitionFallTimeEnabled),
            4, "Transition Fall Time Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_TRANSITION_START_TIME_ENABLED, transitionStartTimeEnabled),
            5, "Transition Start Time Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_TRANSITION_STOP_TIME_ENABLED, transitionStopTimeEnabled),
            6, "Transition Stop Time Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_TRANSITION_OVERSHOOT_RISING_EDGE_ENABLED, overshootRisingEdgeEnabled),
            7, "Overshoot Rising Edge Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_TRANSITION_OVERSHOOT_FALLING_EDGE_ENABLED, overshootFallingEdgeEnabled),
            8, "Overshoot Falling Edge Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the measured pulse parameter values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the input to configure.
/// HIPAR riseTime/Queries the measured pulse parameter values.
/// HIPAR fallTime/Queries the measured pulse parameter values.
/// HIPAR startTime/Queries the measured pulse parameter values.
/// HIPAR stopTime/Queries the measured pulse parameter values.
/// HIPAR overshootRisingEdge/Queries the measured pulse parameter values.
/// HIPAR overshootFallingEdge/Queries the measured pulse parameter values.
ViStatus _VI_FUNC rssmx_QueryPowerAnalysisTransitionTimesMeasurements(
                            ViSession instrSession,
                            ViInt32   trace,
                            ViReal64* riseTime,
                            ViReal64* fallTime,
                            ViReal64* startTime,
                            ViReal64* stopTime,
                            ViReal64* overshootRisingEdge,
                            ViReal64* overshootFallingEdge)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_TRANSITION_RISE_TIME, riseTime),
            3, "Rise Time");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_TRANSITION_FALL_TIME, fallTime),
            4, "Fall Time");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_TRANSITION_START_TIME, startTime),
            5, "Start Time");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_TRANSITION_STOP_TIME, stopTime),
            6, "Stop Time");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_TRANSITION_OVERSHOOT_RISING_EDGE, overshootRisingEdge),
            7, "Overshoot Rising Edge");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_TRANSITION_OVERSHOOT_FALLING_EDGE, overshootFallingEdge),
            8, "Overshoot Falling Edge");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects pulse parameters which are indicated in the display and
/// HIFN  hardcopy file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the input to configure.
/// HIPAR minimalEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR minimalEnabled/hardcopy file.
/// HIPAR peakEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR peakEnabled/hardcopy file.
/// HIPAR averageEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR averageEnabled/hardcopy file.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisSignalPowerNotifications(
                            ViSession instrSession,
                            ViInt32   trace,
                            ViBoolean minimalEnabled,
                            ViBoolean peakEnabled,
                            ViBoolean averageEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_POWER_MINIMAL_ENABLED, minimalEnabled),
            3, "Minimal Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_POWER_PEAK_ENABLED, peakEnabled),
            4, "Peak Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_POWER_AVERAGE_ENABLED, averageEnabled),
            5, "Average Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the measured pulse parameter values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the input to configure.
/// HIPAR minimal/Queries the measured pulse parameter values.
/// HIPAR peak/Queries the measured pulse parameter values.
/// HIPAR average/Queries the measured pulse parameter values.
ViStatus _VI_FUNC rssmx_QueryPowerAnalysisSignalPowerMeasurements(
                            ViSession instrSession,
                            ViInt32   trace,
                            ViReal64* minimal,
                            ViReal64* peak,
                            ViReal64* average)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_POWER_MINIMAL, minimal),
            3, "Minimal");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_POWER_PEAK, peak),
            4, "Peak");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_POWER_AVERAGE, average),
            5, "Average");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects pulse parameters which are indicated in the display and
/// HIFN  hardcopy file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the input to configure.
/// HIPAR topEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR topEnabled/hardcopy file.
/// HIPAR baseEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR baseEnabled/hardcopy file.
/// HIPAR distalEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR distalEnabled/hardcopy file.
/// HIPAR mesialEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR mesialEnabled/hardcopy file.
/// HIPAR proximalEnabled/Selects the pulse parameters which is indicated in the display and
/// HIPAR proximalEnabled/hardcopy file.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisPulsePowerNotifications(
                            ViSession instrSession,
                            ViInt32   trace,
                            ViBoolean topEnabled,
                            ViBoolean baseEnabled,
                            ViBoolean distalEnabled,
                            ViBoolean mesialEnabled,
                            ViBoolean proximalEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_POWER_TOP_ENABLED, topEnabled),
            3, "Top Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_POWER_BASE_ENABLED, baseEnabled),
            4, "Base Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_POWER_DISTAL_ENABLED, distalEnabled),
            5, "Distal Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_POWER_MESIAL_ENABLED, mesialEnabled),
            6, "Mesial Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_POWER_PROXIMAL_ENABLED, proximalEnabled),
            7, "Proximal Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the measured pulse parameter values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the input to configure.
/// HIPAR top/Queries the measured pulse parameter values.
/// HIPAR base/Queries the measured pulse parameter values.
/// HIPAR distal/Queries the measured pulse parameter values.
/// HIPAR mesial/Queries the measured pulse parameter values.
/// HIPAR proximal/Queries the measured pulse parameter values.
ViStatus _VI_FUNC rssmx_QueryPowerAnalysisPulsePowerMeasurements(
                            ViSession instrSession,
                            ViInt32   trace,
                            ViReal64* top,
                            ViReal64* base,
                            ViReal64* distal,
                            ViReal64* mesial,
                            ViReal64* proximal)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 4),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_POWER_TOP, top),
            3, "Top");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_POWER_BASE, base),
            4, "Base");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_POWER_DISTAL, distal),
            5, "Distal");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_POWER_MESIAL, mesial),
            6, "Mesial");

    viCheckParm(rssmx_GetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_PULSE_POWER_PROXIMAL, proximal),
            7, "Proximal");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures trigger settings for a given sensor for power versus time
/// HIFN  measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sensor/Selects the sensor to configure.
/// HIPAR mode/Selects if the measurement is free running (FREE) or starts only after
/// HIPAR mode/a trigger event. The trigger can be applied internally or externally.
/// HIPAR level/Sets the trigger threshold.
/// HIPAR slope/Sets the polarity of the active slope for the trigger signals.
/// HIPAR hysteresis/Sets the hysteresis of the internal trigger threshold. Hysteresis is
/// HIPAR hysteresis/the magnitude (in dB) the trigger signal level must drop below the
/// HIPAR hysteresis/trigger threshold (positive trigger slope) before triggering can occur
/// HIPAR hysteresis/again.
/// HIPAR dropOutTime/Determines the minimum time for which the signal must be below (above)
/// HIPAR dropOutTime/the power level defined by level and hysteresis before triggering can
/// HIPAR dropOutTime/occur again.
ViStatus _VI_FUNC rssmx_ConfigurePowerAnalysisTrigger(ViSession instrSession,
                                                      ViInt32   sensor,
                                                      ViInt32   mode,
                                                      ViReal64  level,
                                                      ViInt32   slope,
                                                      ViReal64  hysteresis,
                                                      ViReal64  dropOutTime)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sensor, 1, 4),
            2, "Sensor");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "SENS%ld", sensor);

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_TRIGGER_MODE, mode),
            3, "Mode");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_TRIGGER_LEVEL, level),
            4, "Level");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_TRIGGER_SLOPE, slope),
            5, "Slope");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_TRIGGER_HYSTERESIS, hysteresis),
            6, "Hysteresis");

    viCheckParm(rssmx_SetAttributeViReal64(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_TRIGGER_DROP_OUT_TIME, dropOutTime),
            7, "Drop Out Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the trigger level, the hysteresis and the dropout time to default
/// HIFN  values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sensor/Selects the sensor to configure.
ViStatus _VI_FUNC rssmx_PowerAnalysisTriggerAutoSet(ViSession instrSession,
                                                    ViInt32   sensor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sensor, 1, 4),
            2, "Sensor");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "SENS%ld", sensor);

    checkErr(rssmx_SetAttributeViString(instrSession, repCap, RSSMX_ATTR_POWER_ANALYSIS_TRIGGER_AUTO_SET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures settings for storing the hardcopy after
/// HIFN  rssmx_ScreenshotExecute (RSSMX_ATTR_SCREENSHOT_EXECUTE) is called.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/Creates or selects a file for storing the hardcopy after
/// HIPAR fileName/rssmx_ScreenshotExecute (RSSMX_ATTR_SCREENSHOT_EXECUTE) is called.
/// HIPAR format/Selects the bitmap graphic format for the screenshot of the power
/// HIPAR format/analysis trace.
/// HIPAR device/Defines the output device.
/// HIPAR size/Sets the size of the hardcopy in number of pixels. The first value of
/// HIPAR size/the size setting defines the width, the second value the height of the
/// HIPAR size/image.
ViStatus _VI_FUNC rssmx_ConfigureScreenshotFileOptions(ViSession instrSession,
                                                       ViString  fileName,
                                                       ViInt32   format,
                                                       ViInt32   device,
                                                       ViInt32   size)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_FILE_NAME, fileName),
            2, "File Name");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_FORMAT, format),
            3, "Format");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_SIZE, size),
            5, "Size");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_DEVICE, device),
            4, "Device");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Triggers the generation of a hardcopy of the current measurement
/// HIFN  diagram. The data is written with the settings selected with
/// HIFN  rssmx_ConfigureScreenshotFileOptions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_ExecuteScreenshot(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_EXECUTE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures options for CSV files and data when saving or reading
/// HIFN  screenshots with rssmx_ExecuteScreenshot
/// HIFN  (RSSMX_ATTR_SCREENSHOT_EXECUTE) or rssmx_ReadScreenshotData.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR orientation/Defines the orientation of the X/Y value pairs.
/// HIPAR columnSeparator/Defines which character is to separate the values, either tabulator,
/// HIPAR columnSeparator/semicolon, comma or blank.
/// HIPAR decimalSeparator/Defines which character is used as the decimal point of the values,
/// HIPAR decimalSeparator/either dot or comma.
/// HIPAR headerEnabled/Defines whether each row (or column depending on the orientation)
/// HIPAR headerEnabled/should be preceded by a header containing information about the trace.
ViStatus _VI_FUNC rssmx_ConfigureScreenshotCSVOptions(ViSession instrSession,
                                                      ViInt32   orientation,
                                                      ViInt32   columnSeparator,
                                                      ViInt32   decimalSeparator,
                                                      ViInt32   headerEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_CSV_ORIENTATION, orientation),
            2, "Orientation");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_CSV_COLUMN_SEPARATOR, columnSeparator),
            3, "Column Separator");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_CSV_DECIMAL_SEPARATOR, decimalSeparator),
            4, "Decimal Separator");

    viCheckParm(rssmx_SetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_CSV_HEADER_ENABLED, headerEnabled),
            5, "Header Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the measurement data directly. The data is transferred to the
/// HIFN  remote client as data stream.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Size of array passed to 'Data'.
/// HIPAR screenshotData/
/// HIPAR bytesRead/Returns number of bytes read from instrument. If the value returned is
/// HIPAR bytesRead/larger then 'Array Size', then the response stored in 'Data' is not
/// HIPAR bytesRead/complete. Resize 'Data' array to accomodate all values and call into
/// HIPAR bytesRead/the function again.
ViStatus _VI_FUNC rssmx_ReadScreenshotData(ViSession instrSession,
                                           ViUInt32  arraySize,
                                           ViChar    screenshotData[],
                                           ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViByte*  ext_buf = NULL;
    ViInt64  bytes_read = 0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryBinaryDataBlock(instrSession, ":SENS:SWE:HCOP:DATA?", VI_FALSE, NULL, &ext_buf, &bytes_read));
    checkErr(rssmx_CheckStatus(instrSession));

    checkErr(RsCore_CopyToUserBufferBinData((ViByte*)screenshotData, arraySize, ext_buf, bytes_read));

    *bytesRead = arraySize < (ViUInt32)bytes_read ? arraySize : (ViUInt32)bytes_read;

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates/deactivates automatic naming of the hardcopy files.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/Activates/deactivates automatic naming of the hardcopy files.
ViStatus _VI_FUNC rssmx_ConfigureScreenshotAutomaticNamingEnabled(
                            ViSession instrSession,
                            ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_AUTOMATIC_NAMING_ENABLED, enabled),
            2, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the file names and location in which the hardcopy files are
/// HIFN  stored if auto naming is activated.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directory/Defines the directory into which the hardcopy files are stored if auto
/// HIPAR directory/naming is activated.
/// HIPAR prefixEnabled/Activates the usage of the prefix in the automatic file name.
/// HIPAR prefix/Sets the prefix part in the automatic file name.
/// HIPAR yearEnabled/Activates the usage of the year in the automatic file name.
/// HIPAR monthEnabled/Activates the usage of the month in the automatic file name.
/// HIPAR dayEnabled/Activates the usage of the day in the automatic file name.
ViStatus _VI_FUNC rssmx_ConfigureScreenshotAutomaticNaming(ViSession instrSession,
                                                           ViString  directory,
                                                           ViBoolean prefixEnabled,
                                                           ViString  prefix,
                                                           ViBoolean yearEnabled,
                                                           ViBoolean monthEnabled,
                                                           ViBoolean dayEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_AUTOMATIC_NAMING_DIRECTORY, directory),
            2, "Directory");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_AUTOMATIC_NAMING_PREFIX_ENABLED, prefixEnabled),
            3, "Prefix Enabled");

    viCheckParm(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_AUTOMATIC_NAMING_PREFIX, prefix),
            4, "Prefix");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_AUTOMATIC_NAMING_YEAR_ENABLED, yearEnabled),
            5, "Year Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_AUTOMATIC_NAMING_MONTH_ENABLED, monthEnabled),
            6, "Month Enabled");

    viCheckParm(rssmx_SetAttributeViBoolean(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_AUTOMATIC_NAMING_DAY_ENABLED, dayEnabled),
            7, "Day Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes all files with extensions bmp , img, png, xpm and csv in the
/// HIFN  directory set for automatic naming.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_ClearScreenshotAutomaticNamingDirectory(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_AUTOMATIC_NAMING_CLEAR_DIRECTORY, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the year, month, and day of the date parts in the automatic
/// HIFN  file name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR year/Queries the year of the date part in the automatic file name.
/// HIPAR month/Queries the day of the date part in the automatic file name.
/// HIPAR day/Queries the day of the date part in the automatic file name.
ViStatus _VI_FUNC rssmx_QueryScreenshotAutomaticNamingDate(ViSession instrSession,
                                                           ViInt32*  year,
                                                           ViInt32*  month,
                                                           ViInt32*  day)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_GetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_AUTOMATIC_NAMING_YEAR, year),
            2, "Year");

    viCheckParm(rssmx_GetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_AUTOMATIC_NAMING_MONTH, month),
            3, "Month");

    viCheckParm(rssmx_GetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_AUTOMATIC_NAMING_DAY, day),
            4, "Day");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the generated number in the automatic file name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR number/Queries the generated number in the automatic file name.
ViStatus _VI_FUNC rssmx_QueryScreenshotAutomaticNamingNumber(ViSession instrSession,
                                                             ViInt32*  number)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_GetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_AUTOMATIC_NAMING_NUMBER, number),
            2, "Number");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the file name generated with the automatic naming settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of array allocated to file name.
/// HIPAR fileName/Queries the file name generated with the automatic naming settings.
ViStatus _VI_FUNC rssmx_QueryScreenshotAutomaticNamingFileName(
                            ViSession instrSession,
                            ViUInt32  bufferSize,
                            ViChar    fileName[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rssmx_GetAttributeViString(instrSession, NULL, RSSMX_ATTR_SCREENSHOT_AUTOMATIC_NAMING_FILE_NAME,
            bufferSize, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function is used to read data from the instrument and write it to
/// HIFN  a user specified file on the host computer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from instrument to
/// HIPAR source/control computer.
/// HIPAR destination/This control defines destination file to which the data transfer from
/// HIPAR destination/instrument to control computer applies.
ViStatus _VI_FUNC rssmx_readToFile(ViSession instrSession,
                                   ViString  source,
                                   ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA? '%s'", source);
    checkErr(RsCore_QueryBinaryDataBlockToFile(instrSession, cmd, destination, RS_VAL_TRUNCATE));

    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function is used to read data from the host computer and write it
/// HIFN  to a user specified file in the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from control computer
/// HIPAR source/to instrument.
/// HIPAR destination/This control defines destination file to which the data transfer from
/// HIPAR destination/control computer to instrument applies.
ViStatus _VI_FUNC rssmx_writeFromFile(ViSession instrSession,
                                      ViString  source,
                                      ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA '%s',", destination);
    checkErr(RsCore_WriteBinaryDataFromFile(instrSession, cmd, source));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function resets the instrument to a known state and sends
/// HIFN  initialization commands to the instrument.  The initialization commands
/// HIFN  set instrument settings such as Headers Off, Short Command form, and
/// HIFN  Data Transfer Binary to the state necessary for the operation of the
/// HIFN  instrument driver.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
ViStatus _VI_FUNC rssmx_reset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  OPC = -1;

    checkErr(RsCore_LockSession(instrSession));

    if (RsCore_Simulating(instrSession) == VI_FALSE)
    {
        checkErr(rssmx_ClearStatus(instrSession));
        checkErr(RsCore_Write(instrSession, "*RST"));
        checkErr(rssmx_QueryOPC(instrSession, &OPC));
    }

    checkErr(rssmx_DefaultInstrSetup(instrSession));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}


/// HIFN  This function runs the instrument's self test routine and returns the
/// HIFN  test result(s).
/// HIFN
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR selfTestResult/This control contains the value returned from the instrument self
/// HIPAR selfTestResult/test.  Zero means success.  For any other code, see the device's
/// HIPAR selfTestResult/operator's manual.
/// HIPAR selfTestMessage/Returns the self-test response string from the instrument. See the
/// HIPAR selfTestMessage/device's operation manual for an explanation of the string's contents.
ViStatus _VI_FUNC rssmx_self_test(ViSession instrSession,
                                  ViInt16*  selfTestResult,
                                  ViChar    selfTestMessage[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, selfTestResult), 2, "Null address for Test Result");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, selfTestMessage), 3, "Null address for Test Message");

    checkErr(RsCore_SelfTest(instrSession, selfTestResult, 48, selfTestMessage));

    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the revision numbers of the instrument driver
/// HIFN  and instrument firmware.
/// HIFN
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR instrumentDriverRevision/Returns the instrument driver software revision numbers in the form of
/// HIPAR instrumentDriverRevision/a string.
/// HIPAR firmwareRevision/Returns the instrument firmware revision numbers in the form of a
/// HIPAR firmwareRevision/string.
ViStatus _VI_FUNC rssmx_revision_query(ViSession instrSession,
                                       ViChar    instrumentDriverRevision[],
                                       ViChar    firmwareRevision[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, instrumentDriverRevision), 2, "Null address for Instrument Driver Revision");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, firmwareRevision), 3, "Null address for Instrument Revision");

    checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_SPECIFIC_DRIVER_REVISION, 0, 256, instrumentDriverRevision));
    checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_INSTRUMENT_FIRMWARE_REVISION, 0, 256, firmwareRevision));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function reads an error code and a message from the instrument's
/// HIFN  error queue.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR errorCode/Returns the error code read from the instrument's error queue.
/// HIPAR errorMessage/Returns the error message string read from the instrument's error
/// HIPAR errorMessage/message queue.
ViStatus _VI_FUNC rssmx_error_query(ViSession instrSession,
                                    ViInt32*  errorCode,
                                    ViChar    errorMessage[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error Code");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorMessage), 3, "Null address for Error Message");

    checkErr(RsCore_ErrorQueryAll(instrSession, errorCode, 1024, errorMessage));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN Returns the list of static error (if any). Static errors are generally more severe than normal error conditions, which can be queried with SYSTem:ERRor[:NEXT]?.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.
/// HIPAR numberOfBytesToRead/Pass the maximum number of bytes to read from the instruments.
/// HIPAR readBuffer/After this function executes, this parameter contains the data that was read from the instrument.
/// HIPAR numBytesRead/Returns the number of bytes actually read from the instrument and stored in the Read Buffer.
ViStatus _VI_FUNC rssmx_SystemStaticError(ViSession instrSession,
                                          ViInt32   bufferSize,
                                          ViChar    buffer[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, 1024),
            2, "Buffer Size");
    viCheckParm(rssmx_GetAttributeViString(instrSession, NULL, RSSMX_ATTR_SYSTEM_STATIC_ERRORS,
            bufferSize, buffer),
            3, "Buffer");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function converts a status code returned by an instrument driver
/// HIFN  function into a user-readable string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR errorCode/Pass the Status parameter that is returned from any of the instrument
/// HIPAR errorCode/driver functions.
/// HIPAR errorMessage/Returns the user-readable message string that corresponds to the
/// HIPAR errorMessage/status code you specify.
ViStatus _VI_FUNC rssmx_error_message(ViSession instrSession,
                                      ViStatus  errorCode,
                                      ViChar    errorMessage[])
{
    return rssmx_utility_error_message(instrSession, errorCode, errorMessage);
}

/// HIFN This function switches ON/OFF various error checkings performed inside of the driver.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR optionChecking/This control switches option checking On or Off.
/// HIPAR rangeChecking/This control enables or disables range checking.
/// HIPAR statusChecking/This control enables or disables instrument state checking
ViStatus _VI_FUNC rssmx_ConfigureErrorChecking(ViSession instrSession,
                                               ViBoolean optionChecking,
                                               ViBoolean rangeChecking,
                                               ViBoolean statusChecking)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->optionChecking = optionChecking;
    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_QUERY_INSTRUMENT_STATUS, 0, statusChecking));
    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_RANGE_CHECK, 0, rangeChecking));

Error:
    return error;
}

/// HIFN  This function clears status.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_ClearStatus(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_ClearStatus(instrSession));
    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the ID Query response string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR IDQueryResponse/Returns the ID Query response string.
ViStatus _VI_FUNC rssmx_IDQueryResponse(ViSession instrSession,
                                        ViChar    IDQueryResponse[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_QueryViString(instrSession, "*IDN?", 256, IDQueryResponse));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Stops further command processing until all commands sent before
/// HIFN  *WAI have been executed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rssmx_ProcessAllPreviousCommands(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_WriteInstrData(instrSession, "*WAI"));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the OPC.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR OPC/Queries the OPC.
ViStatus _VI_FUNC rssmx_QueryOPC(ViSession instrSession,
                                 ViInt32*  OPC)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rssmx_QueryViInt32(instrSession, "*OPC?", OPC));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function specifies the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsspecan_init or
/// HIPAR instrSession/rsspecan_InitWithOptions function.
/// HIPAR VISATimeout/This control sets the timeout value.
ViStatus _VI_FUNC rssmx_SetVISATimeout(ViSession instrSession,
                                       ViUInt32  VISATimeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_SetVisaTimeout(instrSession, VISATimeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function returns the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsspecan_init or
/// HIPAR instrSession/rsspecan_InitWithOptions function.
/// HIPAR VISATimeout/This control gets the timeout value.
ViStatus _VI_FUNC rssmx_GetVISATimeout(ViSession instrSession,
                                       ViUInt32* VISATimeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetVisaTimeout(instrSession, VISATimeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function sets the OPC timeout.
/// HIRET Document return value here.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsspecan_init or
/// HIPAR instrSession/rsspecan_InitWithOptions function.
/// HIPAR timeout/Sets the timeout value.
ViStatus _VI_FUNC rssmx_SetOPCTimeout(ViSession instrSession,
                                      ViInt32   timeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_SetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, (ViInt32) timeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function returns the OPC timeout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsspecan_init or
/// HIPAR instrSession/rsspecan_InitWithOptions function.
/// HIPAR timeout/Returns the timeout value.
ViStatus _VI_FUNC rssmx_GetOPCTimeout(ViSession instrSession,
                                      ViInt32*  timeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, (ViInt32*) timeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function calibrates the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the RsRfSigGen_init or
/// HIPAR instrSession/RsRfSigGen_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR path/The path for which is this function performed.
/// HIPAR timeout/Sets the timeout.
/// HIPAR result/Returns the calibration result.
ViStatus _VI_FUNC rssmx_Calibrate(ViSession instrSession,
                                  ViInt32   timeout,
                                  ViInt32*  result)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  old_timeout = -1;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, timeout, 0, 600000),
            2, "Timeout");

    checkErr(rssmx_GetOPCTimeout(instrSession, &old_timeout));
    checkErr(rssmx_SetOPCTimeout(instrSession, timeout));
    viCheckParm(rssmx_GetAttributeViInt32(instrSession, NULL, RSSMX_ATTR_CALIBRATION_ALL, result),
            3, "Result");

Error:
    if (old_timeout >= 0)
        rssmx_SetOPCTimeout(instrSession, old_timeout);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates volatile mode, so that no user data can be written to the
/// HIFN  internal memory permanently.
/// HIFN
/// HIFN     To enable volatile mode, reboot the instrument. Otherwise the change
/// HIFN  has no effect.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the RsRfSigGen_init or
/// HIPAR instrSession/RsRfSigGen_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR password/Current security password.
/// HIPAR memoryProtectionState/Memory protection state.
ViStatus _VI_FUNC rssmx_SecurityVolatileMode(ViSession instrSession,
                                             ViString  password,
                                             ViBoolean memoryProtectionState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SYST:SEC:VOLM '%s',%s", password, memoryProtectionState ? "ON" : "OFF");
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function sets the Enable, NTransition, and PTransition bits
/// HIFN of the Main status questionable and operating registers.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerOperation/Specifies the operation to perform.
/// HIPAR questionableRegister/This control selects the registers that will be configured.
/// HIPAR enable/This control sets the enable bits of the status register.
/// HIPAR PTransition/This control sets the PTransition bits (edge detectors) of the
/// HIPAR PTransition/status register.
/// HIPAR NTransition/This control sets the NTransition bits (edge detectors) of the
/// HIPAR NTransition/status register.
ViStatus _VI_FUNC rssmx_SetStatusRegister(ViSession instrSession,
                                          ViInt32   registerOperation,
                                          ViInt32   questionableRegister,
                                          ViInt32   enable,
                                          ViInt32   PTransition,
                                          ViInt32   NTransition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    switch (registerOperation)
    {
    case RSSMX_VAL_STAT_REG_PRESET:
        checkErr(rssmx_SetAttributeViString(instrSession, NULL, RSSMX_ATTR_STATUS_PRESET, NULL));
        break;
    case RSSMX_VAL_STAT_REG_QUESTIONABLE:
        switch (questionableRegister)
        {
        case RSSMX_VAL_STAT_REG_MAIN:
            viCheckParm(RsCore_InvalidViInt32Range(instrSession, enable, 0, 65535),
                    4, "Enable");
            viCheckParm(RsCore_InvalidViInt32Range(instrSession, PTransition, 0, 65535),
                    5, "PTransition");
            viCheckParm(RsCore_InvalidViInt32Range(instrSession, NTransition, 0, 65535),
                    6, "NTransition");

            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:QUES:ENAB %ld;PTR %ld;NTR %ld", enable, PTransition, NTransition);
            checkErr(RsCore_Write(instrSession, cmd));

            break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, registerOperation), 3, "Questionable Operation");
        }
        break;
    case RSSMX_VAL_STAT_REG_OPERATION:
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, enable, 0, 65535),
                4, "Enable");
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, PTransition, 0, 65535),
                5, "PTransition");
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, NTransition, 0, 65535),
                6, "NTransition");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:OPER:ENAB %ld;PTR %ld;NTR %ld", enable, PTransition, NTransition);
        checkErr(RsCore_Write(instrSession, cmd));
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, registerOperation), 2, "Register Operation");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function contains the commands for the querying status
/// HIFN reporting system.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerOperation/Specifies the operation to perform.
/// HIPAR questionableRegister/This control selects the registers that will be configured.
/// HIPAR registerPart/Sets the register part.
/// HIPAR registerValue/Returns content of selected register.
ViStatus _VI_FUNC rssmx_GetStatusRegister(ViSession instrSession,
                                          ViInt32   questionableRegister,
                                          ViInt32   registerPart,
                                          ViInt32*  registerValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViString statusRegister[] = {"COND", "EVEN"};

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, registerPart, 0, 1),
            4, "Register Part");

    switch (questionableRegister)
    {
    case RSSMX_VAL_STAT_REG_MAIN:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:QUES:%s?", statusRegister[registerPart]);
        checkErr(RsCore_QueryViInt32(instrSession, cmd, registerValue));
        break;
    case RSSMX_VAL_STAT_REG_OPERATION:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:OPER:%s?", statusRegister[registerPart]);
        checkErr(RsCore_QueryViInt32(instrSession, cmd, registerValue));
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, questionableRegister), 3, "Questionable Operation");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function retrieves and then clears the IVI error information for
/// HIFN  the session or the current execution thread. One exception exists: If
/// HIFN  the BufferSize parameter is 0, the function does not clear the error
/// HIFN  information. By passing 0 for the buffer size, the caller can ascertain
/// HIFN  the buffer size required to get the entire error description string and
/// HIFN  then call the function again with a sufficiently large buffer.
/// HIFN
/// HIFN     If the user specifies a valid IVI session for the instrSession
/// HIFN  parameter, Get Error retrieves and then clears the error information
/// HIFN  for the session.  If the user passes NULL for the instrSession
/// HIFN  parameter, this function retrieves and then clears the error
/// HIFN  information for the current execution thread.  If the instrSession
/// HIFN  parameter is an invalid session, the function does nothing and returns
/// HIFN  an error. Normally, the error information describes the first error
/// HIFN  that occurred since the user last called rssmx_GetError or
/// HIFN  rssmx_ClearError.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR errorCode/Returns the error code for the session or execution thread.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/Description parameter.
/// HIPAR description/Returns the error description for the IVI session or execution thread.
/// HIPAR description/ If there is no description, the function returns an empty string.
ViStatus _VI_FUNC rssmx_GetError(ViSession instrSession,
                                 ViStatus* errorCode,
                                 ViInt32   bufferSize,
                                 ViChar    description[])
{
    ViStatus error = VI_SUCCESS;

    // Lock Session - do not jump to the end, even with invalid instrSession the function continues further
    (void)(RsCore_LockSession(instrSession));

    // Test for nulls and acquire error data
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, description), 4, "Null address for Description");

    checkErr(RsCore_GetErrorCompleteDescription(instrSession, &rssmx_utility_error_message, errorCode, bufferSize, description));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 rssmx_ClearError
 *****************************************************************************/
ViStatus _VI_FUNC rssmx_ClearError(ViSession instrSession)
{
    return RsCore_ClearErrorInfo(instrSession);
}


/*****************************************************************************
 * Function: WriteInstrData Function
 * Purpose:  The function enables the instrument driver user to
 *           write commands directly to the instrument.
 *
 *           Note:  These function bypasses the RS attribute state caching.
 *                  WriteInstrData invalidates the cached values for all
 *                  attributes.
 *****************************************************************************/
ViStatus _VI_FUNC rssmx_WriteInstrData(ViSession instrSession,
                                       ViString  writeBuffer)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    error = RsCore_Write(instrSession, writeBuffer);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function queries the ViBoolean value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR value/Returns the ViBoolean value.
ViStatus _VI_FUNC rssmx_QueryViBoolean(ViSession  instrSession,
                                       ViString   command,
                                       ViBoolean* value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViBoolean(instrSession, command, value));

    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query ViInt32
 * Purpose:  This function queries the ViInt32 value.
 *****************************************************************************/
ViStatus _VI_FUNC rssmx_QueryViInt32(ViSession instrSession,
                                     ViString  command,
                                     ViInt32*  value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViInt32(instrSession, command, value));

    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query ViReal64
 * Purpose:  This function queries the ViReal64 value.
 *****************************************************************************/
ViStatus _VI_FUNC rssmx_QueryViReal64(ViSession instrSession,
                                      ViString  command,
                                      ViReal64* value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViReal64(instrSession, command, value));

    checkErr(rssmx_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/*****************************************************************************
 * Function: Query ViString
 * Purpose:  This function queries the ViString value.
 *****************************************************************************/
ViStatus _VI_FUNC rssmx_QueryViString(ViSession instrSession,
                                      ViString  command,
                                      ViInt32   bufferSize,
                                      ViChar    value[])
{
    ViStatus error = VI_SUCCESS;
    ViChar*  extBuf = NULL;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, command, &extBuf));

    checkErr(rssmx_CheckStatus(instrSession));

    checkErr(RsCore_CopyToUserBufferAsciiData(value, bufferSize, extBuf));

Error:
    if (extBuf)
        free(extBuf);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: rssmx_SetAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to set
 *           attribute values directly.  There are typesafe versions for
 *           ViInt32, ViReal64, ViString, ViBoolean, and ViSession datatypes.
 *****************************************************************************/
ViStatus _VI_FUNC rssmx_SetAttributeViInt32(ViSession instrSession,
                                            ViString  repeatedCapabilityName,
                                            ViAttr    attributeID,
                                            ViInt32   attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViInt32(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

ViStatus _VI_FUNC rssmx_SetAttributeViInt64(ViSession instrSession,
                                            ViString  repeatedCapabilityName,
                                            ViAttr    attributeID,
                                            ViInt64   attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViInt64(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

ViStatus _VI_FUNC rssmx_SetAttributeViReal64(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeID,
                                             ViReal64  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViReal64(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

ViStatus _VI_FUNC rssmx_SetAttributeViString(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeID,
                                             ViString  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViStringOrRawString(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

ViStatus _VI_FUNC rssmx_SetAttributeViBoolean(ViSession instrSession,
                                              ViString  repeatedCapabilityName,
                                              ViAttr    attributeID,
                                              ViBoolean attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViBoolean(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}



/*****************************************************************************
 * Function: rssmx_GetAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to get
 *           attribute values directly.  There are typesafe versions for
 *           ViInt32, ViReal64, ViString, ViBoolean, and ViSession attributes.
 *****************************************************************************/
ViStatus _VI_FUNC rssmx_GetAttributeViInt32(ViSession instrSession,
                                            ViString  repeatedCapabilityName,
                                            ViAttr    attributeID,
                                            ViInt32*  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);
    error = RsCore_GetAttributeViInt32(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

ViStatus _VI_FUNC rssmx_GetAttributeViInt64(ViSession instrSession,
                                            ViString  repeatedCapabilityName,
                                            ViAttr    attributeID,
                                            ViInt64*  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);
    error = RsCore_GetAttributeViInt64(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

ViStatus _VI_FUNC rssmx_GetAttributeViReal64(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeID,
                                             ViReal64* attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViReal64(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

ViStatus _VI_FUNC rssmx_GetAttributeViString(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeID,
                                             ViInt32   bufferSize,
                                             ViChar    attributeValue[])
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViStringOrRawString(instrSession, repeatedCapabilityName, attributeID, RS_VAL_DIRECT_USER_CALL, bufferSize,
        attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

ViStatus _VI_FUNC rssmx_GetAttributeViBoolean(ViSession  instrSession,
                                              ViString   repeatedCapabilityName,
                                              ViAttr     attributeId,
                                              ViBoolean* attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViBoolean(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}



/// HIFN Function used by Hi-level functions to obtain a repCap name from:
/// HIFN - attributeID
/// HIFN - repCapNameID
/// HIFN - 0-based index in the repCapNames
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR repCapNameId/RepCap Name ID.
/// HIPAR index/Zero based index in the repCapNames.
/// HIPAR bufferSize/Pass the number of bytes in the string you allocate for the repCapName.
/// HIPAR repCapName/String returning RepCap name
ViStatus _VI_FUNC rssmx_GetAttributeRepCapName(ViSession instrSession,
                                               ViAttr    attributeId,
                                               ViString  repCapNameId,
                                               ViInt32   index,
                                               ViInt32   bufferSize,
                                               ViChar    repCapName[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, attributeId, repCapNameId, index, bufferSize, repCapName));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Rs_GetAttributeRepCapNameId
 * Purpose:  This function returns the repeated capability id(s) that
 *           belongs to the attribute you specify. More then one id is listed
 *           in comma separated string.
 *****************************************************************************/
ViStatus _VI_FUNC rssmx_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                          ViAttr    attributeID,
                                                          ViInt32   bufferSize,
                                                          ViChar    repeatedCapabilityIds[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
            3, "Buffer Size");

    checkErr(RsCore_GetAttributeRepCapNameIds(instrSession, attributeID, bufferSize, repeatedCapabilityIds));

Error:
    return error;
}

/*****************************************************************************
 * Function: Get Attribute Repeated Capability Id Name(s)
 * Purpose:  This function returns the repeated capability name(s) that
 *           belongs to the attribute and single repeated capability id you
 *           may specify. More then one name is listed in comma separated
 *           string.
 *****************************************************************************/
ViStatus _VI_FUNC rssmx_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViAttr    attributeID,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
            4, "Buffer Size");

    checkErr(RsCore_GetAttributeRepCapNamesAll(instrSession,
        attributeID,
        repeatedCapabilityId,
        bufferSize,
        repeatedCapabilityIdNames));

Error:
    return error;
}


/// HIFN  This function performs the following operations:
/// HIFN
/// HIFN     - Closes the instrument I/O session.
/// HIFN
/// HIFN     - Destroys the instrument driver session and all of its attributes.
/// HIFN
/// HIFN     - Deallocates any memory resources the driver uses.
/// HIFN
/// HIFN     Notes:
/// HIFN
/// HIFN     (1) You must unlock the session before calling rssmx_close.
/// HIFN
/// HIFN     (2) After calling rssmx_close, you cannot use the instrument
/// HIFN  driver again until you call rssmx_init or
/// HIFN  rssmx_InitWithOptions.
/// HIFN
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rssmx_init or
/// HIPAR instrSession/rssmx_InitWithOptions function.  The handle identifies a
/// HIPAR instrSession/particular instrument session.
ViStatus _VI_FUNC rssmx_close(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_ViClose(instrSession));

Error:
    (void)RsCore_Dispose(instrSession);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}
